@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -41,6 +42,11 @@ try:
 except ImportError as error:
     comp_distance = error
 
+try:
+    from ..Methods.Geometry.Arc.plot import plot
+except ImportError as error:
+    plot = error
+
 
 from ._check import InitUnKnowClassError
 
@@ -98,6 +104,15 @@ class Arc(Line):
         )
     else:
         comp_distance = comp_distance
+    # cf Methods.Geometry.Arc.plot
+    if isinstance(plot, ImportError):
+        plot = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use Arc method plot: " + str(plot))
+            )
+        )
+    else:
+        plot = plot
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -147,6 +162,15 @@ class Arc(Line):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from Line
+        S += super(Arc, self).__sizeof__()
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
