@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -290,6 +291,19 @@ class Arc1(Arc):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from Arc
+        S += super(Arc1, self).__sizeof__()
+        S += getsizeof(self.begin)
+        S += getsizeof(self.end)
+        S += getsizeof(self.radius)
+        S += getsizeof(self.is_trigo_direction)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
@@ -297,10 +311,14 @@ class Arc1(Arc):
         Arc1_dict = super(Arc1, self).as_dict()
         if self.begin is None:
             Arc1_dict["begin"] = None
+        elif isinstance(self.begin, float):
+            Arc1_dict["begin"] = self.begin
         else:
             Arc1_dict["begin"] = str(self.begin)
         if self.end is None:
             Arc1_dict["end"] = None
+        elif isinstance(self.end, float):
+            Arc1_dict["end"] = self.end
         else:
             Arc1_dict["end"] = str(self.end)
         Arc1_dict["radius"] = self.radius
