@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import set_array, check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -193,6 +194,17 @@ class CellMat(FrozenClass):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+        S += getsizeof(self.connectivity)
+        S += getsizeof(self.nb_cell)
+        S += getsizeof(self.nb_pt_per_cell)
+        S += getsizeof(self.indice)
+        S += getsizeof(self.interpolation)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
