@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -46,6 +47,11 @@ try:
 except ImportError as error:
     plot = error
 
+try:
+    from ..Methods.Machine.CondType12.plot_schematics import plot_schematics
+except ImportError as error:
+    plot_schematics = error
+
 
 from ._check import InitUnKnowClassError
 from .Material import Material
@@ -120,6 +126,18 @@ class CondType12(Conductor):
         )
     else:
         plot = plot
+    # cf Methods.Machine.CondType12.plot_schematics
+    if isinstance(plot_schematics, ImportError):
+        plot_schematics = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use CondType12 method plot_schematics: "
+                    + str(plot_schematics)
+                )
+            )
+        )
+    else:
+        plot_schematics = plot_schematics
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -212,6 +230,20 @@ class CondType12(Conductor):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from Conductor
+        S += super(CondType12, self).__sizeof__()
+        S += getsizeof(self.Wwire)
+        S += getsizeof(self.Wins_cond)
+        S += getsizeof(self.Nwppc)
+        S += getsizeof(self.Wins_wire)
+        S += getsizeof(self.Kwoh)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
