@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -184,6 +185,18 @@ class CondType21(Conductor):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from Conductor
+        S += super(CondType21, self).__sizeof__()
+        S += getsizeof(self.Hbar)
+        S += getsizeof(self.Wbar)
+        S += getsizeof(self.Wins)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
