@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -111,6 +112,19 @@ class DXFImport(FrozenClass):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+        S += getsizeof(self.file_path)
+        if self.surf_dict is not None:
+            for key, value in self.surf_dict.items():
+                S += getsizeof(value) + getsizeof(key)
+        if self.BC_list is not None:
+            for value in self.BC_list:
+                S += getsizeof(value)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
