@@ -5,32 +5,32 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from ._frozen import FrozenClass
 
-from inspect import getsource
-from cloudpickle import dumps, loads
+from ntpath import basename
+from os.path import isfile
 from ._check import CheckTypeError
+import numpy as np
+import random
 from ._check import InitUnKnowClassError
 
 
 class DataKeeper(FrozenClass):
-    """Abstract class for the multi-simulation"""
+    """Class for defining data to keep on a multi-simulation"""
 
     VERSION = 1
 
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -47,28 +47,16 @@ class DataKeeper(FrozenClass):
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            name = obj.name
-            symbol = obj.symbol
-            unit = obj.unit
-            keeper = obj.keeper
-            error_keeper = obj.error_keeper
-            result = obj.result
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -84,22 +72,20 @@ class DataKeeper(FrozenClass):
                 error_keeper = init_dict["error_keeper"]
             if "result" in list(init_dict.keys()):
                 result = init_dict["result"]
-        # Initialisation by argument
+        # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.name = name
         self.symbol = symbol
         self.unit = unit
         self.keeper = keeper
         self.error_keeper = error_keeper
-        if result == -1:
-            result = []
         self.result = result
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         DataKeeper_str = ""
         if self.parent is None:
@@ -109,22 +95,18 @@ class DataKeeper(FrozenClass):
         DataKeeper_str += 'name = "' + str(self.name) + '"' + linesep
         DataKeeper_str += 'symbol = "' + str(self.symbol) + '"' + linesep
         DataKeeper_str += 'unit = "' + str(self.unit) + '"' + linesep
-        if self._keeper[1] is None:
-            DataKeeper_str += "keeper = " + str(self._keeper[1])
+        if self._keeper_str is not None:
+            DataKeeper_str += "keeper = " + self._keeper_str + linesep
+        elif self._keeper_func is not None:
+            DataKeeper_str += "keeper = " + str(self._keeper_func) + linesep
         else:
-            DataKeeper_str += (
-                "keeper = " + linesep + str(self._keeper[1]) + linesep + linesep
-            )
-        if self._error_keeper[1] is None:
-            DataKeeper_str += "error_keeper = " + str(self._error_keeper[1])
+            DataKeeper_str += "keeper = None" + linesep + linesep
+        if self._error_keeper_str is not None:
+            DataKeeper_str += "error_keeper = " + self._error_keeper_str + linesep
+        elif self._error_keeper_func is not None:
+            DataKeeper_str += "error_keeper = " + str(self._error_keeper_func) + linesep
         else:
-            DataKeeper_str += (
-                "error_keeper = "
-                + linesep
-                + str(self._error_keeper[1])
-                + linesep
-                + linesep
-            )
+            DataKeeper_str += "error_keeper = None" + linesep + linesep
         DataKeeper_str += (
             "result = "
             + linesep
@@ -144,38 +126,47 @@ class DataKeeper(FrozenClass):
             return False
         if other.unit != self.unit:
             return False
-        if other.keeper != self.keeper:
+        if other._keeper_str != self._keeper_str:
             return False
-        if other.error_keeper != self.error_keeper:
+        if other._error_keeper_str != self._error_keeper_str:
             return False
         if other.result != self.result:
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+        S += getsizeof(self.name)
+        S += getsizeof(self.symbol)
+        S += getsizeof(self.unit)
+        S += getsizeof(self._keeper_str)
+        S += getsizeof(self._error_keeper_str)
+        if self.result is not None:
+            for value in self.result:
+                S += getsizeof(value)
+        return S
+
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         DataKeeper_dict = dict()
         DataKeeper_dict["name"] = self.name
         DataKeeper_dict["symbol"] = self.symbol
         DataKeeper_dict["unit"] = self.unit
-        if self.keeper is None:
+        if self._keeper_str is not None:
+            DataKeeper_dict["keeper"] = self._keeper_str
+        else:
             DataKeeper_dict["keeper"] = None
+        if self._error_keeper_str is not None:
+            DataKeeper_dict["error_keeper"] = self._error_keeper_str
         else:
-            DataKeeper_dict["keeper"] = [
-                dumps(self._keeper[0]).decode("ISO-8859-2"),
-                self._keeper[1],
-            ]
-        if self.error_keeper is None:
             DataKeeper_dict["error_keeper"] = None
-        else:
-            DataKeeper_dict["error_keeper"] = [
-                dumps(self._error_keeper[0]).decode("ISO-8859-2"),
-                self._error_keeper[1],
-            ]
-        DataKeeper_dict["result"] = self.result
-        # The class name is added to the dict fordeserialisation purpose
+        DataKeeper_dict["result"] = (
+            self.result.copy() if self.result is not None else None
+        )
+        # The class name is added to the dict for deserialisation purpose
         DataKeeper_dict["__class__"] = "DataKeeper"
         return DataKeeper_dict
 
@@ -245,23 +236,28 @@ class DataKeeper(FrozenClass):
 
     def _get_keeper(self):
         """getter of keeper"""
-        return self._keeper[0]
+        return self._keeper_func
 
     def _set_keeper(self, value):
         """setter of keeper"""
-        try:
-            check_var("keeper", value, "list")
-        except CheckTypeError:
-            check_var("keeper", value, "function")
-        if isinstance(value, list):  # Load function from saved dict
-            self._keeper = [loads(value[0].encode("ISO-8859-2")), value[1]]
-        elif value is None:
-            self._keeper = [None, None]
+        if value is None:
+            self._keeper_str = None
+            self._keeper_func = None
+        elif isinstance(value, str) and "lambda" in value:
+            self._keeper_str = value
+            self._keeper_func = eval(value)
+        elif isinstance(value, str) and isfile(value) and value[-3:] == ".py":
+            self._keeper_str = value
+            f = open(value, "r")
+            exec(f.read(), globals())
+            self._keeper_func = eval(basename(value[:-3]))
         elif callable(value):
-            self._keeper = [value, getsource(value)]
+            self._keeper_str = None
+            self._keeper_func = value
         else:
-            raise TypeError(
-                "Expected function or list from a saved file, got: " + str(type(value))
+            raise CheckTypeError(
+                "For property keeper Expected function or str (path to python file or lambda), got: "
+                + str(type(value))
             )
 
     keeper = property(
@@ -275,23 +271,28 @@ class DataKeeper(FrozenClass):
 
     def _get_error_keeper(self):
         """getter of error_keeper"""
-        return self._error_keeper[0]
+        return self._error_keeper_func
 
     def _set_error_keeper(self, value):
         """setter of error_keeper"""
-        try:
-            check_var("error_keeper", value, "list")
-        except CheckTypeError:
-            check_var("error_keeper", value, "function")
-        if isinstance(value, list):  # Load function from saved dict
-            self._error_keeper = [loads(value[0].encode("ISO-8859-2")), value[1]]
-        elif value is None:
-            self._error_keeper = [None, None]
+        if value is None:
+            self._error_keeper_str = None
+            self._error_keeper_func = None
+        elif isinstance(value, str) and "lambda" in value:
+            self._error_keeper_str = value
+            self._error_keeper_func = eval(value)
+        elif isinstance(value, str) and isfile(value) and value[-3:] == ".py":
+            self._error_keeper_str = value
+            f = open(value, "r")
+            exec(f.read(), globals())
+            self._error_keeper_func = eval(basename(value[:-3]))
         elif callable(value):
-            self._error_keeper = [value, getsource(value)]
+            self._error_keeper_str = None
+            self._error_keeper_func = value
         else:
-            raise TypeError(
-                "Expected function or list from a saved file, got: " + str(type(value))
+            raise CheckTypeError(
+                "For property error_keeper Expected function or str (path to python file or lambda), got: "
+                + str(type(value))
             )
 
     error_keeper = property(
@@ -309,6 +310,8 @@ class DataKeeper(FrozenClass):
 
     def _set_result(self, value):
         """setter of result"""
+        if type(value) is int and value == -1:
+            value = list()
         check_var("result", value, "list")
         self._result = value
 
