@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -188,6 +189,22 @@ class EEC_PMSM(EEC):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from EEC
+        S += super(EEC_PMSM, self).__sizeof__()
+        S += getsizeof(self.indmag)
+        S += getsizeof(self.fluxlink)
+        if self.parameters is not None:
+            for key, value in self.parameters.items():
+                S += getsizeof(value) + getsizeof(key)
+        S += getsizeof(self.freq0)
+        S += getsizeof(self.drive)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
