@@ -5,10 +5,14 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from ._frozen import FrozenClass
 
 # Import all class method
@@ -34,7 +38,7 @@ from .EEC import EEC
 
 
 class Electrical(FrozenClass):
-    """Electric module abstract object"""
+    """Electric module object for electrical equivalent circuit simulation"""
 
     VERSION = 1
 
@@ -70,78 +74,44 @@ class Electrical(FrozenClass):
         )
     else:
         comp_torque = comp_torque
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
-    def __init__(self, eec=None, init_dict=None, init_str=None):
+    def __init__(
+        self, eec=None, logger_name="Pyleecan.Electrical", init_dict=None, init_str=None
+    ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if eec == -1:
-            eec = EEC()
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            eec = obj.eec
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
             if "eec" in list(init_dict.keys()):
                 eec = init_dict["eec"]
-        # Initialisation by argument
+            if "logger_name" in list(init_dict.keys()):
+                logger_name = init_dict["logger_name"]
+        # Set the properties (value check and convertion are done in setter)
         self.parent = None
-        # eec can be None, a EEC object or a dict
-        if isinstance(eec, dict):
-            # Check that the type is correct (including daughter)
-            class_name = eec.get("__class__")
-            if class_name not in ["EEC", "EEC_PMSM"]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for eec"
-                )
-            # Dynamic import to call the correct constructor
-            module = __import__("pyleecan.Classes." + class_name, fromlist=[class_name])
-            class_obj = getattr(module, class_name)
-            self.eec = class_obj(init_dict=eec)
-        elif isinstance(eec, str):
-            from ..Functions.load import load
-
-            eec = load(eec)
-            # Check that the type is correct (including daughter)
-            class_name = eec.__class__.__name__
-            if class_name not in ["EEC", "EEC_PMSM"]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for eec"
-                )
-            self.eec = eec
-        else:
-            self.eec = eec
+        self.eec = eec
+        self.logger_name = logger_name
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         Electrical_str = ""
         if self.parent is None:
@@ -153,6 +123,7 @@ class Electrical(FrozenClass):
             Electrical_str += "eec = " + tmp
         else:
             Electrical_str += "eec = None" + linesep + linesep
+        Electrical_str += 'logger_name = "' + str(self.logger_name) + '"' + linesep
         return Electrical_str
 
     def __eq__(self, other):
@@ -162,18 +133,28 @@ class Electrical(FrozenClass):
             return False
         if other.eec != self.eec:
             return False
+        if other.logger_name != self.logger_name:
+            return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+        S += getsizeof(self.eec)
+        S += getsizeof(self.logger_name)
+        return S
+
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         Electrical_dict = dict()
         if self.eec is None:
             Electrical_dict["eec"] = None
         else:
             Electrical_dict["eec"] = self.eec.as_dict()
-        # The class name is added to the dict fordeserialisation purpose
+        Electrical_dict["logger_name"] = self.logger_name
+        # The class name is added to the dict for deserialisation purpose
         Electrical_dict["__class__"] = "Electrical"
         return Electrical_dict
 
@@ -182,6 +163,7 @@ class Electrical(FrozenClass):
 
         if self.eec is not None:
             self.eec._set_None()
+        self.logger_name = None
 
     def _get_eec(self):
         """getter of eec"""
@@ -189,6 +171,13 @@ class Electrical(FrozenClass):
 
     def _set_eec(self, value):
         """setter of eec"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class("pyleecan.Classes", value.get("__class__"), "eec")
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = EEC()
         check_var("eec", value, "EEC")
         self._eec = value
 
@@ -203,3 +192,21 @@ class Electrical(FrozenClass):
         :Type: EEC
         """,
     )
+
+    def _get_logger_name(self):
+        """getter of logger_name"""
+        return self._logger_name
+
+    def _set_logger_name(self, value):
+        """setter of logger_name"""
+        check_var("logger_name", value, "str")
+        self._logger_name = value
+
+    logger_name = property(
+        fget=_get_logger_name,
+        fset=_set_logger_name,
+        doc=u"""Name of the logger to use
+
+        :Type: str
+        """,
+    )
