@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -63,6 +64,12 @@ class FluxLink(FrozenClass):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
@@ -73,3 +80,4 @@ class FluxLink(FrozenClass):
 
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
+        pass
