@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -16,6 +17,11 @@ from .HoleMag import HoleMag
 
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
+try:
+    from ..Methods.Slot.HoleM50._comp_point_coordinate import _comp_point_coordinate
+except ImportError as error:
+    _comp_point_coordinate = error
+
 try:
     from ..Methods.Slot.HoleM50.build_geometry import build_geometry
 except ImportError as error:
@@ -56,6 +62,11 @@ try:
 except ImportError as error:
     comp_surface_magnet_id = error
 
+try:
+    from ..Methods.Slot.HoleM50.plot_schematics import plot_schematics
+except ImportError as error:
+    plot_schematics = error
+
 
 from ._check import InitUnKnowClassError
 from .Magnet import Magnet
@@ -69,6 +80,18 @@ class HoleM50(HoleMag):
     IS_SYMMETRICAL = 1
 
     # Check ImportError to remove unnecessary dependencies in unused method
+    # cf Methods.Slot.HoleM50._comp_point_coordinate
+    if isinstance(_comp_point_coordinate, ImportError):
+        _comp_point_coordinate = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use HoleM50 method _comp_point_coordinate: "
+                    + str(_comp_point_coordinate)
+                )
+            )
+        )
+    else:
+        _comp_point_coordinate = _comp_point_coordinate
     # cf Methods.Slot.HoleM50.build_geometry
     if isinstance(build_geometry, ImportError):
         build_geometry = property(
@@ -148,6 +171,17 @@ class HoleM50(HoleMag):
         )
     else:
         comp_surface_magnet_id = comp_surface_magnet_id
+    # cf Methods.Slot.HoleM50.plot_schematics
+    if isinstance(plot_schematics, ImportError):
+        plot_schematics = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use HoleM50 method plot_schematics: " + str(plot_schematics)
+                )
+            )
+        )
+    else:
+        plot_schematics = plot_schematics
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -297,6 +331,27 @@ class HoleM50(HoleMag):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from HoleMag
+        S += super(HoleM50, self).__sizeof__()
+        S += getsizeof(self.H0)
+        S += getsizeof(self.W0)
+        S += getsizeof(self.H1)
+        S += getsizeof(self.W1)
+        S += getsizeof(self.H2)
+        S += getsizeof(self.W2)
+        S += getsizeof(self.H3)
+        S += getsizeof(self.W3)
+        S += getsizeof(self.H4)
+        S += getsizeof(self.W4)
+        S += getsizeof(self.magnet_0)
+        S += getsizeof(self.magnet_1)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
