@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -16,6 +17,11 @@ from .HoleMag import HoleMag
 
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
+try:
+    from ..Methods.Slot.HoleM52._comp_point_coordinate import _comp_point_coordinate
+except ImportError as error:
+    _comp_point_coordinate = error
+
 try:
     from ..Methods.Slot.HoleM52.build_geometry import build_geometry
 except ImportError as error:
@@ -41,6 +47,11 @@ try:
 except ImportError as error:
     comp_surface = error
 
+try:
+    from ..Methods.Slot.HoleM52.comp_surface_magnet_id import comp_surface_magnet_id
+except ImportError as error:
+    comp_surface_magnet_id = error
+
 try:
     from ..Methods.Slot.HoleM52.comp_W1 import comp_W1
 except ImportError as error:
@@ -51,16 +62,16 @@ try:
 except ImportError as error:
     has_magnet = error
 
+try:
+    from ..Methods.Slot.HoleM52.plot_schematics import plot_schematics
+except ImportError as error:
+    plot_schematics = error
+
 try:
     from ..Methods.Slot.HoleM52.remove_magnet import remove_magnet
 except ImportError as error:
     remove_magnet = error
 
-try:
-    from ..Methods.Slot.HoleM52.comp_surface_magnet_id import comp_surface_magnet_id
-except ImportError as error:
-    comp_surface_magnet_id = error
-
 
 from ._check import InitUnKnowClassError
 from .Magnet import Magnet
@@ -74,6 +85,18 @@ class HoleM52(HoleMag):
     IS_SYMMETRICAL = 1
 
     # Check ImportError to remove unnecessary dependencies in unused method
+    # cf Methods.Slot.HoleM52._comp_point_coordinate
+    if isinstance(_comp_point_coordinate, ImportError):
+        _comp_point_coordinate = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use HoleM52 method _comp_point_coordinate: "
+                    + str(_comp_point_coordinate)
+                )
+            )
+        )
+    else:
+        _comp_point_coordinate = _comp_point_coordinate
     # cf Methods.Slot.HoleM52.build_geometry
     if isinstance(build_geometry, ImportError):
         build_geometry = property(
@@ -123,6 +146,18 @@ class HoleM52(HoleMag):
         )
     else:
         comp_surface = comp_surface
+    # cf Methods.Slot.HoleM52.comp_surface_magnet_id
+    if isinstance(comp_surface_magnet_id, ImportError):
+        comp_surface_magnet_id = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use HoleM52 method comp_surface_magnet_id: "
+                    + str(comp_surface_magnet_id)
+                )
+            )
+        )
+    else:
+        comp_surface_magnet_id = comp_surface_magnet_id
     # cf Methods.Slot.HoleM52.comp_W1
     if isinstance(comp_W1, ImportError):
         comp_W1 = property(
@@ -141,6 +176,17 @@ class HoleM52(HoleMag):
         )
     else:
         has_magnet = has_magnet
+    # cf Methods.Slot.HoleM52.plot_schematics
+    if isinstance(plot_schematics, ImportError):
+        plot_schematics = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use HoleM52 method plot_schematics: " + str(plot_schematics)
+                )
+            )
+        )
+    else:
+        plot_schematics = plot_schematics
     # cf Methods.Slot.HoleM52.remove_magnet
     if isinstance(remove_magnet, ImportError):
         remove_magnet = property(
@@ -152,18 +198,6 @@ class HoleM52(HoleMag):
         )
     else:
         remove_magnet = remove_magnet
-    # cf Methods.Slot.HoleM52.comp_surface_magnet_id
-    if isinstance(comp_surface_magnet_id, ImportError):
-        comp_surface_magnet_id = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use HoleM52 method comp_surface_magnet_id: "
-                    + str(comp_surface_magnet_id)
-                )
-            )
-        )
-    else:
-        comp_surface_magnet_id = comp_surface_magnet_id
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -267,6 +301,21 @@ class HoleM52(HoleMag):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from HoleMag
+        S += super(HoleM52, self).__sizeof__()
+        S += getsizeof(self.H0)
+        S += getsizeof(self.W0)
+        S += getsizeof(self.H1)
+        S += getsizeof(self.W3)
+        S += getsizeof(self.H2)
+        S += getsizeof(self.magnet_0)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
