@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -16,6 +17,11 @@ from .Hole import Hole
 
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
+try:
+    from ..Methods.Slot.HoleM54._comp_point_coordinate import _comp_point_coordinate
+except ImportError as error:
+    _comp_point_coordinate = error
+
 try:
     from ..Methods.Slot.HoleM54.build_geometry import build_geometry
 except ImportError as error:
@@ -36,6 +42,11 @@ try:
 except ImportError as error:
     comp_surface = error
 
+try:
+    from ..Methods.Slot.HoleM54.plot_schematics import plot_schematics
+except ImportError as error:
+    plot_schematics = error
+
 
 from ._check import InitUnKnowClassError
 from .Material import Material
@@ -48,6 +59,18 @@ class HoleM54(Hole):
     IS_SYMMETRICAL = 1
 
     # Check ImportError to remove unnecessary dependencies in unused method
+    # cf Methods.Slot.HoleM54._comp_point_coordinate
+    if isinstance(_comp_point_coordinate, ImportError):
+        _comp_point_coordinate = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use HoleM54 method _comp_point_coordinate: "
+                    + str(_comp_point_coordinate)
+                )
+            )
+        )
+    else:
+        _comp_point_coordinate = _comp_point_coordinate
     # cf Methods.Slot.HoleM54.build_geometry
     if isinstance(build_geometry, ImportError):
         build_geometry = property(
@@ -88,6 +111,17 @@ class HoleM54(Hole):
         )
     else:
         comp_surface = comp_surface
+    # cf Methods.Slot.HoleM54.plot_schematics
+    if isinstance(plot_schematics, ImportError):
+        plot_schematics = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use HoleM54 method plot_schematics: " + str(plot_schematics)
+                )
+            )
+        )
+    else:
+        plot_schematics = plot_schematics
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -173,6 +207,19 @@ class HoleM54(Hole):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from Hole
+        S += super(HoleM54, self).__sizeof__()
+        S += getsizeof(self.H0)
+        S += getsizeof(self.H1)
+        S += getsizeof(self.W0)
+        S += getsizeof(self.R1)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
