@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -16,6 +17,11 @@ from .HoleMag import HoleMag
 
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
+try:
+    from ..Methods.Slot.HoleM58._comp_point_coordinate import _comp_point_coordinate
+except ImportError as error:
+    _comp_point_coordinate = error
+
 try:
     from ..Methods.Slot.HoleM58.build_geometry import build_geometry
 except ImportError as error:
@@ -32,9 +38,9 @@ except ImportError as error:
     comp_radius = error
 
 try:
-    from ..Methods.Slot.HoleM58.remove_magnet import remove_magnet
+    from ..Methods.Slot.HoleM58.comp_surface_magnet_id import comp_surface_magnet_id
 except ImportError as error:
-    remove_magnet = error
+    comp_surface_magnet_id = error
 
 try:
     from ..Methods.Slot.HoleM58.has_magnet import has_magnet
@@ -42,9 +48,14 @@ except ImportError as error:
     has_magnet = error
 
 try:
-    from ..Methods.Slot.HoleM58.comp_surface_magnet_id import comp_surface_magnet_id
+    from ..Methods.Slot.HoleM58.plot_schematics import plot_schematics
 except ImportError as error:
-    comp_surface_magnet_id = error
+    plot_schematics = error
+
+try:
+    from ..Methods.Slot.HoleM58.remove_magnet import remove_magnet
+except ImportError as error:
+    remove_magnet = error
 
 
 from ._check import InitUnKnowClassError
@@ -59,6 +70,18 @@ class HoleM58(HoleMag):
     IS_SYMMETRICAL = 1
 
     # Check ImportError to remove unnecessary dependencies in unused method
+    # cf Methods.Slot.HoleM58._comp_point_coordinate
+    if isinstance(_comp_point_coordinate, ImportError):
+        _comp_point_coordinate = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use HoleM58 method _comp_point_coordinate: "
+                    + str(_comp_point_coordinate)
+                )
+            )
+        )
+    else:
+        _comp_point_coordinate = _comp_point_coordinate
     # cf Methods.Slot.HoleM58.build_geometry
     if isinstance(build_geometry, ImportError):
         build_geometry = property(
@@ -88,26 +111,6 @@ class HoleM58(HoleMag):
         )
     else:
         comp_radius = comp_radius
-    # cf Methods.Slot.HoleM58.remove_magnet
-    if isinstance(remove_magnet, ImportError):
-        remove_magnet = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use HoleM58 method remove_magnet: " + str(remove_magnet)
-                )
-            )
-        )
-    else:
-        remove_magnet = remove_magnet
-    # cf Methods.Slot.HoleM58.has_magnet
-    if isinstance(has_magnet, ImportError):
-        has_magnet = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use HoleM58 method has_magnet: " + str(has_magnet))
-            )
-        )
-    else:
-        has_magnet = has_magnet
     # cf Methods.Slot.HoleM58.comp_surface_magnet_id
     if isinstance(comp_surface_magnet_id, ImportError):
         comp_surface_magnet_id = property(
@@ -120,6 +123,37 @@ class HoleM58(HoleMag):
         )
     else:
         comp_surface_magnet_id = comp_surface_magnet_id
+    # cf Methods.Slot.HoleM58.has_magnet
+    if isinstance(has_magnet, ImportError):
+        has_magnet = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use HoleM58 method has_magnet: " + str(has_magnet))
+            )
+        )
+    else:
+        has_magnet = has_magnet
+    # cf Methods.Slot.HoleM58.plot_schematics
+    if isinstance(plot_schematics, ImportError):
+        plot_schematics = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use HoleM58 method plot_schematics: " + str(plot_schematics)
+                )
+            )
+        )
+    else:
+        plot_schematics = plot_schematics
+    # cf Methods.Slot.HoleM58.remove_magnet
+    if isinstance(remove_magnet, ImportError):
+        remove_magnet = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use HoleM58 method remove_magnet: " + str(remove_magnet)
+                )
+            )
+        )
+    else:
+        remove_magnet = remove_magnet
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -244,6 +278,24 @@ class HoleM58(HoleMag):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from HoleMag
+        S += super(HoleM58, self).__sizeof__()
+        S += getsizeof(self.H0)
+        S += getsizeof(self.W0)
+        S += getsizeof(self.H1)
+        S += getsizeof(self.W1)
+        S += getsizeof(self.H2)
+        S += getsizeof(self.W2)
+        S += getsizeof(self.W3)
+        S += getsizeof(self.R0)
+        S += getsizeof(self.magnet_0)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
