@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -146,6 +147,25 @@ class ImportData(FrozenClass):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+        if self.axes is not None:
+            for value in self.axes:
+                S += getsizeof(value)
+        S += getsizeof(self.field)
+        S += getsizeof(self.unit)
+        S += getsizeof(self.name)
+        S += getsizeof(self.symbol)
+        if self.normalizations is not None:
+            for key, value in self.normalizations.items():
+                S += getsizeof(value) + getsizeof(key)
+        if self.symmetries is not None:
+            for key, value in self.symmetries.items():
+                S += getsizeof(value) + getsizeof(key)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
@@ -155,7 +175,10 @@ class ImportData(FrozenClass):
         else:
             ImportData_dict["axes"] = list()
             for obj in self.axes:
-                ImportData_dict["axes"].append(obj.as_dict())
+                if obj is not None:
+                    ImportData_dict["axes"].append(obj.as_dict())
+                else:
+                    ImportData_dict["axes"].append(None)
         if self.field is None:
             ImportData_dict["field"] = None
         else:
@@ -176,8 +199,7 @@ class ImportData(FrozenClass):
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
-        for obj in self.axes:
-            obj._set_None()
+        self.axes = None
         if self.field is not None:
             self.field._set_None()
         self.unit = None
@@ -203,6 +225,8 @@ class ImportData(FrozenClass):
                         "pyleecan.Classes", obj.get("__class__"), "axes"
                     )
                     value[ii] = class_obj(init_dict=obj)
+                if value[ii] is not None:
+                    value[ii].parent = self
         if value == -1:
             value = list()
         check_var("axes", value, "[ImportData]")
