@@ -5,10 +5,14 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from .ImportMatrix import ImportMatrix
 
 # Import all class method
@@ -57,41 +61,25 @@ class ImportGenMatrixSin(ImportMatrix):
         )
     else:
         init_vector = init_vector
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
-    def __init__(
-        self, sin_list=list(), is_transpose=False, init_dict=None, init_str=None
-    ):
+    def __init__(self, sin_list=-1, is_transpose=False, init_dict=None, init_str=None):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            sin_list = obj.sin_list
-            is_transpose = obj.is_transpose
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -99,28 +87,15 @@ class ImportGenMatrixSin(ImportMatrix):
                 sin_list = init_dict["sin_list"]
             if "is_transpose" in list(init_dict.keys()):
                 is_transpose = init_dict["is_transpose"]
-        # Initialisation by argument
-        # sin_list can be None or a list of ImportGenVectSin object
-        self.sin_list = list()
-        if type(sin_list) is list:
-            for obj in sin_list:
-                if obj is None:  # Default value
-                    self.sin_list.append(ImportGenVectSin())
-                elif isinstance(obj, dict):
-                    self.sin_list.append(ImportGenVectSin(init_dict=obj))
-                else:
-                    self.sin_list.append(obj)
-        elif sin_list is None:
-            self.sin_list = list()
-        else:
-            self.sin_list = sin_list
+        # Set the properties (value check and convertion are done in setter)
+        self.sin_list = sin_list
         # Call ImportMatrix init
         super(ImportGenMatrixSin, self).__init__(is_transpose=is_transpose)
         # The class is frozen (in ImportMatrix init), for now it's impossible to
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         ImportGenMatrixSin_str = ""
         # Get the properties inherited from ImportMatrix
@@ -147,16 +122,33 @@ class ImportGenMatrixSin(ImportMatrix):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from ImportMatrix
+        S += super(ImportGenMatrixSin, self).__sizeof__()
+        if self.sin_list is not None:
+            for value in self.sin_list:
+                S += getsizeof(value)
+        return S
+
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         # Get the properties inherited from ImportMatrix
         ImportGenMatrixSin_dict = super(ImportGenMatrixSin, self).as_dict()
-        ImportGenMatrixSin_dict["sin_list"] = list()
-        for obj in self.sin_list:
-            ImportGenMatrixSin_dict["sin_list"].append(obj.as_dict())
-        # The class name is added to the dict fordeserialisation purpose
+        if self.sin_list is None:
+            ImportGenMatrixSin_dict["sin_list"] = None
+        else:
+            ImportGenMatrixSin_dict["sin_list"] = list()
+            for obj in self.sin_list:
+                if obj is not None:
+                    ImportGenMatrixSin_dict["sin_list"].append(obj.as_dict())
+                else:
+                    ImportGenMatrixSin_dict["sin_list"].append(None)
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         ImportGenMatrixSin_dict["__class__"] = "ImportGenMatrixSin"
         return ImportGenMatrixSin_dict
@@ -164,27 +156,34 @@ class ImportGenMatrixSin(ImportMatrix):
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
-        for obj in self.sin_list:
-            obj._set_None()
+        self.sin_list = None
         # Set to None the properties inherited from ImportMatrix
         super(ImportGenMatrixSin, self)._set_None()
 
     def _get_sin_list(self):
         """getter of sin_list"""
-        for obj in self._sin_list:
-            if obj is not None:
-                obj.parent = self
+        if self._sin_list is not None:
+            for obj in self._sin_list:
+                if obj is not None:
+                    obj.parent = self
         return self._sin_list
 
     def _set_sin_list(self, value):
         """setter of sin_list"""
+        if type(value) is list:
+            for ii, obj in enumerate(value):
+                if type(obj) is dict:
+                    class_obj = import_class(
+                        "pyleecan.Classes", obj.get("__class__"), "sin_list"
+                    )
+                    value[ii] = class_obj(init_dict=obj)
+                if value[ii] is not None:
+                    value[ii].parent = self
+        if value == -1:
+            value = list()
         check_var("sin_list", value, "[ImportGenVectSin]")
         self._sin_list = value
 
-        for obj in self._sin_list:
-            if obj is not None:
-                obj.parent = self
-
     sin_list = property(
         fget=_get_sin_list,
         fset=_set_sin_list,
