@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -137,6 +138,21 @@ class ImportGenToothSaw(ImportMatrix):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from ImportMatrix
+        S += super(ImportGenToothSaw, self).__sizeof__()
+        S += getsizeof(self.type_signal)
+        S += getsizeof(self.f)
+        S += getsizeof(self.A)
+        S += getsizeof(self.N)
+        S += getsizeof(self.Tf)
+        S += getsizeof(self.Dt)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
