@@ -5,10 +5,14 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from .ImportMatrix import ImportMatrix
 
 # Import all class method
@@ -69,15 +73,9 @@ class ImportGenVectLin(ImportMatrix):
         )
     else:
         get_data = get_data
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -93,27 +91,16 @@ class ImportGenVectLin(ImportMatrix):
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            start = obj.start
-            stop = obj.stop
-            num = obj.num
-            endpoint = obj.endpoint
-            is_transpose = obj.is_transpose
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -127,7 +114,7 @@ class ImportGenVectLin(ImportMatrix):
                 endpoint = init_dict["endpoint"]
             if "is_transpose" in list(init_dict.keys()):
                 is_transpose = init_dict["is_transpose"]
-        # Initialisation by argument
+        # Set the properties (value check and convertion are done in setter)
         self.start = start
         self.stop = stop
         self.num = num
@@ -138,7 +125,7 @@ class ImportGenVectLin(ImportMatrix):
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         ImportGenVectLin_str = ""
         # Get the properties inherited from ImportMatrix
@@ -168,9 +155,21 @@ class ImportGenVectLin(ImportMatrix):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from ImportMatrix
+        S += super(ImportGenVectLin, self).__sizeof__()
+        S += getsizeof(self.start)
+        S += getsizeof(self.stop)
+        S += getsizeof(self.num)
+        S += getsizeof(self.endpoint)
+        return S
+
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         # Get the properties inherited from ImportMatrix
         ImportGenVectLin_dict = super(ImportGenVectLin, self).as_dict()
@@ -178,7 +177,7 @@ class ImportGenVectLin(ImportMatrix):
         ImportGenVectLin_dict["stop"] = self.stop
         ImportGenVectLin_dict["num"] = self.num
         ImportGenVectLin_dict["endpoint"] = self.endpoint
-        # The class name is added to the dict fordeserialisation purpose
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         ImportGenVectLin_dict["__class__"] = "ImportGenVectLin"
         return ImportGenVectLin_dict
