@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -118,6 +119,17 @@ class ImportVectorField(FrozenClass):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+        if self.components is not None:
+            for key, value in self.components.items():
+                S += getsizeof(value) + getsizeof(key)
+        S += getsizeof(self.name)
+        S += getsizeof(self.symbol)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
@@ -127,7 +139,10 @@ class ImportVectorField(FrozenClass):
         else:
             ImportVectorField_dict["components"] = dict()
             for key, obj in self.components.items():
-                ImportVectorField_dict["components"][key] = obj.as_dict()
+                if obj is not None:
+                    ImportVectorField_dict["components"][key] = obj.as_dict()
+                else:
+                    ImportVectorField_dict["components"][key] = None
         ImportVectorField_dict["name"] = self.name
         ImportVectorField_dict["symbol"] = self.symbol
         # The class name is added to the dict for deserialisation purpose
@@ -137,8 +152,7 @@ class ImportVectorField(FrozenClass):
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
-        for key, obj in self.components.items():
-            obj._set_None()
+        self.components = None
         self.name = None
         self.symbol = None
 
