@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -323,6 +324,19 @@ class LamHole(Lamination):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from Lamination
+        S += super(LamHole, self).__sizeof__()
+        if self.hole is not None:
+            for value in self.hole:
+                S += getsizeof(value)
+        S += getsizeof(self.bore)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
@@ -333,7 +347,10 @@ class LamHole(Lamination):
         else:
             LamHole_dict["hole"] = list()
             for obj in self.hole:
-                LamHole_dict["hole"].append(obj.as_dict())
+                if obj is not None:
+                    LamHole_dict["hole"].append(obj.as_dict())
+                else:
+                    LamHole_dict["hole"].append(None)
         if self.bore is None:
             LamHole_dict["bore"] = None
         else:
@@ -346,8 +363,7 @@ class LamHole(Lamination):
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
-        for obj in self.hole:
-            obj._set_None()
+        self.hole = None
         if self.bore is not None:
             self.bore._set_None()
         # Set to None the properties inherited from Lamination
@@ -370,6 +386,8 @@ class LamHole(Lamination):
                         "pyleecan.Classes", obj.get("__class__"), "hole"
                     )
                     value[ii] = class_obj(init_dict=obj)
+                if value[ii] is not None:
+                    value[ii].parent = self
         if value == -1:
             value = list()
         check_var("hole", value, "[Hole]")
