@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import set_array, check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -295,6 +296,19 @@ class LamSlotMulti(Lamination):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from Lamination
+        S += super(LamSlotMulti, self).__sizeof__()
+        if self.slot_list is not None:
+            for value in self.slot_list:
+                S += getsizeof(value)
+        S += getsizeof(self.alpha)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
@@ -305,7 +319,10 @@ class LamSlotMulti(Lamination):
         else:
             LamSlotMulti_dict["slot_list"] = list()
             for obj in self.slot_list:
-                LamSlotMulti_dict["slot_list"].append(obj.as_dict())
+                if obj is not None:
+                    LamSlotMulti_dict["slot_list"].append(obj.as_dict())
+                else:
+                    LamSlotMulti_dict["slot_list"].append(None)
         if self.alpha is None:
             LamSlotMulti_dict["alpha"] = None
         else:
@@ -318,8 +335,7 @@ class LamSlotMulti(Lamination):
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
-        for obj in self.slot_list:
-            obj._set_None()
+        self.slot_list = None
         self.alpha = None
         # Set to None the properties inherited from Lamination
         super(LamSlotMulti, self)._set_None()
@@ -341,6 +357,8 @@ class LamSlotMulti(Lamination):
                         "pyleecan.Classes", obj.get("__class__"), "slot_list"
                     )
                     value[ii] = class_obj(init_dict=obj)
+                if value[ii] is not None:
+                    value[ii].parent = self
         if value == -1:
             value = list()
         check_var("slot_list", value, "[Slot]")
