@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -489,6 +490,27 @@ class Lamination(FrozenClass):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+        S += getsizeof(self.L1)
+        S += getsizeof(self.mat_type)
+        S += getsizeof(self.Nrvd)
+        S += getsizeof(self.Wrvd)
+        S += getsizeof(self.Kf1)
+        S += getsizeof(self.is_internal)
+        S += getsizeof(self.Rint)
+        S += getsizeof(self.Rext)
+        S += getsizeof(self.is_stator)
+        if self.axial_vent is not None:
+            for value in self.axial_vent:
+                S += getsizeof(value)
+        if self.notch is not None:
+            for value in self.notch:
+                S += getsizeof(value)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
@@ -510,13 +532,19 @@ class Lamination(FrozenClass):
         else:
             Lamination_dict["axial_vent"] = list()
             for obj in self.axial_vent:
-                Lamination_dict["axial_vent"].append(obj.as_dict())
+                if obj is not None:
+                    Lamination_dict["axial_vent"].append(obj.as_dict())
+                else:
+                    Lamination_dict["axial_vent"].append(None)
         if self.notch is None:
             Lamination_dict["notch"] = None
         else:
             Lamination_dict["notch"] = list()
             for obj in self.notch:
-                Lamination_dict["notch"].append(obj.as_dict())
+                if obj is not None:
+                    Lamination_dict["notch"].append(obj.as_dict())
+                else:
+                    Lamination_dict["notch"].append(None)
         # The class name is added to the dict for deserialisation purpose
         Lamination_dict["__class__"] = "Lamination"
         return Lamination_dict
@@ -534,10 +562,8 @@ class Lamination(FrozenClass):
         self.Rint = None
         self.Rext = None
         self.is_stator = None
-        for obj in self.axial_vent:
-            obj._set_None()
-        for obj in self.notch:
-            obj._set_None()
+        self.axial_vent = None
+        self.notch = None
 
     def _get_L1(self):
         """getter of L1"""
@@ -738,6 +764,8 @@ class Lamination(FrozenClass):
                         "pyleecan.Classes", obj.get("__class__"), "axial_vent"
                     )
                     value[ii] = class_obj(init_dict=obj)
+                if value[ii] is not None:
+                    value[ii].parent = self
         if value == -1:
             value = list()
         check_var("axial_vent", value, "[Hole]")
@@ -769,6 +797,8 @@ class Lamination(FrozenClass):
                         "pyleecan.Classes", obj.get("__class__"), "notch"
                     )
                     value[ii] = class_obj(init_dict=obj)
+                if value[ii] is not None:
+                    value[ii].parent = self
         if value == -1:
             value = list()
         check_var("notch", value, "[Notch]")
