@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -42,9 +43,14 @@ except ImportError as error:
     get_path_save = error
 
 try:
-    from ..Methods.Simulation.MagElmer.comp_time_angle import comp_time_angle
+    from ..Methods.Simulation.MagElmer.comp_axes import comp_axes
 except ImportError as error:
-    comp_time_angle = error
+    comp_axes = error
+
+try:
+    from ..Methods.Simulation.MagElmer.gen_elmer_mesh import gen_elmer_mesh
+except ImportError as error:
+    gen_elmer_mesh = error
 
 
 from ._check import InitUnKnowClassError
@@ -113,17 +119,26 @@ class MagElmer(Magnetics):
         )
     else:
         get_path_save = get_path_save
-    # cf Methods.Simulation.MagElmer.comp_time_angle
-    if isinstance(comp_time_angle, ImportError):
-        comp_time_angle = property(
+    # cf Methods.Simulation.MagElmer.comp_axes
+    if isinstance(comp_axes, ImportError):
+        comp_axes = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use MagElmer method comp_axes: " + str(comp_axes))
+            )
+        )
+    else:
+        comp_axes = comp_axes
+    # cf Methods.Simulation.MagElmer.gen_elmer_mesh
+    if isinstance(gen_elmer_mesh, ImportError):
+        gen_elmer_mesh = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use MagElmer method comp_time_angle: " + str(comp_time_angle)
+                    "Can't use MagElmer method gen_elmer_mesh: " + str(gen_elmer_mesh)
                 )
             )
         )
     else:
-        comp_time_angle = comp_time_angle
+        gen_elmer_mesh = gen_elmer_mesh
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -136,7 +151,6 @@ class MagElmer(Magnetics):
         Kgeo_fineness=1,
         file_name="",
         FEA_dict=-1,
-        angle_stator=0,
         is_get_mesh=False,
         is_save_FEA=False,
         transform_list=-1,
@@ -153,6 +167,9 @@ class MagElmer(Magnetics):
         type_BH_rotor=0,
         is_periodicity_t=False,
         is_periodicity_a=False,
+        angle_stator_shift=0,
+        angle_rotor_shift=0,
+        logger_name="Pyleecan.Magnetics",
         init_dict=None,
         init_str=None,
     ):
@@ -179,8 +196,6 @@ class MagElmer(Magnetics):
                 file_name = init_dict["file_name"]
             if "FEA_dict" in list(init_dict.keys()):
                 FEA_dict = init_dict["FEA_dict"]
-            if "angle_stator" in list(init_dict.keys()):
-                angle_stator = init_dict["angle_stator"]
             if "is_get_mesh" in list(init_dict.keys()):
                 is_get_mesh = init_dict["is_get_mesh"]
             if "is_save_FEA" in list(init_dict.keys()):
@@ -213,12 +228,17 @@ class MagElmer(Magnetics):
                 is_periodicity_t = init_dict["is_periodicity_t"]
             if "is_periodicity_a" in list(init_dict.keys()):
                 is_periodicity_a = init_dict["is_periodicity_a"]
+            if "angle_stator_shift" in list(init_dict.keys()):
+                angle_stator_shift = init_dict["angle_stator_shift"]
+            if "angle_rotor_shift" in list(init_dict.keys()):
+                angle_rotor_shift = init_dict["angle_rotor_shift"]
+            if "logger_name" in list(init_dict.keys()):
+                logger_name = init_dict["logger_name"]
         # Set the properties (value check and convertion are done in setter)
         self.Kmesh_fineness = Kmesh_fineness
         self.Kgeo_fineness = Kgeo_fineness
         self.file_name = file_name
         self.FEA_dict = FEA_dict
-        self.angle_stator = angle_stator
         self.is_get_mesh = is_get_mesh
         self.is_save_FEA = is_save_FEA
         self.transform_list = transform_list
@@ -237,6 +257,9 @@ class MagElmer(Magnetics):
             type_BH_rotor=type_BH_rotor,
             is_periodicity_t=is_periodicity_t,
             is_periodicity_a=is_periodicity_a,
+            angle_stator_shift=angle_stator_shift,
+            angle_rotor_shift=angle_rotor_shift,
+            logger_name=logger_name,
         )
         # The class is frozen (in Magnetics init), for now it's impossible to
         # add new properties
@@ -251,7 +274,6 @@ class MagElmer(Magnetics):
         MagElmer_str += "Kgeo_fineness = " + str(self.Kgeo_fineness) + linesep
         MagElmer_str += 'file_name = "' + str(self.file_name) + '"' + linesep
         MagElmer_str += "FEA_dict = " + str(self.FEA_dict) + linesep
-        MagElmer_str += "angle_stator = " + str(self.angle_stator) + linesep
         MagElmer_str += "is_get_mesh = " + str(self.is_get_mesh) + linesep
         MagElmer_str += "is_save_FEA = " + str(self.is_save_FEA) + linesep
         MagElmer_str += (
@@ -293,8 +315,6 @@ class MagElmer(Magnetics):
             return False
         if other.FEA_dict != self.FEA_dict:
             return False
-        if other.angle_stator != self.angle_stator:
-            return False
         if other.is_get_mesh != self.is_get_mesh:
             return False
         if other.is_save_FEA != self.is_save_FEA:
@@ -311,6 +331,30 @@ class MagElmer(Magnetics):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from Magnetics
+        S += super(MagElmer, self).__sizeof__()
+        S += getsizeof(self.Kmesh_fineness)
+        S += getsizeof(self.Kgeo_fineness)
+        S += getsizeof(self.file_name)
+        if self.FEA_dict is not None:
+            for key, value in self.FEA_dict.items():
+                S += getsizeof(value) + getsizeof(key)
+        S += getsizeof(self.is_get_mesh)
+        S += getsizeof(self.is_save_FEA)
+        if self.transform_list is not None:
+            for value in self.transform_list:
+                S += getsizeof(value)
+        S += getsizeof(self.rotor_dxf)
+        S += getsizeof(self.stator_dxf)
+        S += getsizeof(self.import_file)
+        S += getsizeof(self.nb_worker)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
@@ -322,7 +366,6 @@ class MagElmer(Magnetics):
         MagElmer_dict["FEA_dict"] = (
             self.FEA_dict.copy() if self.FEA_dict is not None else None
         )
-        MagElmer_dict["angle_stator"] = self.angle_stator
         MagElmer_dict["is_get_mesh"] = self.is_get_mesh
         MagElmer_dict["is_save_FEA"] = self.is_save_FEA
         MagElmer_dict["transform_list"] = (
@@ -350,7 +393,6 @@ class MagElmer(Magnetics):
         self.Kgeo_fineness = None
         self.file_name = None
         self.FEA_dict = None
-        self.angle_stator = None
         self.is_get_mesh = None
         self.is_save_FEA = None
         self.transform_list = None
@@ -437,24 +479,6 @@ class MagElmer(Magnetics):
         """,
     )
 
-    def _get_angle_stator(self):
-        """getter of angle_stator"""
-        return self._angle_stator
-
-    def _set_angle_stator(self, value):
-        """setter of angle_stator"""
-        check_var("angle_stator", value, "float")
-        self._angle_stator = value
-
-    angle_stator = property(
-        fget=_get_angle_stator,
-        fset=_set_angle_stator,
-        doc=u"""Angular position shift of the stator
-
-        :Type: float
-        """,
-    )
-
     def _get_is_get_mesh(self):
         """getter of is_get_mesh"""
         return self._is_get_mesh
