@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -14,139 +15,15 @@ from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
 from ._frozen import FrozenClass
 
-# Import all class method
-# Try/catch to remove unnecessary dependencies in unused method
-try:
-    from ..Methods.Machine.Magnet.comp_angle_opening import comp_angle_opening
-except ImportError as error:
-    comp_angle_opening = error
-
-try:
-    from ..Methods.Machine.Magnet.comp_height import comp_height
-except ImportError as error:
-    comp_height = error
-
-try:
-    from ..Methods.Machine.Magnet.comp_mass import comp_mass
-except ImportError as error:
-    comp_mass = error
-
-try:
-    from ..Methods.Machine.Magnet.comp_ratio_opening import comp_ratio_opening
-except ImportError as error:
-    comp_ratio_opening = error
-
-try:
-    from ..Methods.Machine.Magnet.comp_surface import comp_surface
-except ImportError as error:
-    comp_surface = error
-
-try:
-    from ..Methods.Machine.Magnet.comp_volume import comp_volume
-except ImportError as error:
-    comp_volume = error
-
-try:
-    from ..Methods.Machine.Magnet.is_outwards import is_outwards
-except ImportError as error:
-    is_outwards = error
-
-try:
-    from ..Methods.Machine.Magnet.plot import plot
-except ImportError as error:
-    plot = error
-
-
 from ._check import InitUnKnowClassError
 from .Material import Material
 
 
 class Magnet(FrozenClass):
-    """abstract class of magnets"""
+    """Magnet class"""
 
     VERSION = 1
 
-    # Check ImportError to remove unnecessary dependencies in unused method
-    # cf Methods.Machine.Magnet.comp_angle_opening
-    if isinstance(comp_angle_opening, ImportError):
-        comp_angle_opening = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use Magnet method comp_angle_opening: "
-                    + str(comp_angle_opening)
-                )
-            )
-        )
-    else:
-        comp_angle_opening = comp_angle_opening
-    # cf Methods.Machine.Magnet.comp_height
-    if isinstance(comp_height, ImportError):
-        comp_height = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use Magnet method comp_height: " + str(comp_height))
-            )
-        )
-    else:
-        comp_height = comp_height
-    # cf Methods.Machine.Magnet.comp_mass
-    if isinstance(comp_mass, ImportError):
-        comp_mass = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use Magnet method comp_mass: " + str(comp_mass))
-            )
-        )
-    else:
-        comp_mass = comp_mass
-    # cf Methods.Machine.Magnet.comp_ratio_opening
-    if isinstance(comp_ratio_opening, ImportError):
-        comp_ratio_opening = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use Magnet method comp_ratio_opening: "
-                    + str(comp_ratio_opening)
-                )
-            )
-        )
-    else:
-        comp_ratio_opening = comp_ratio_opening
-    # cf Methods.Machine.Magnet.comp_surface
-    if isinstance(comp_surface, ImportError):
-        comp_surface = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use Magnet method comp_surface: " + str(comp_surface)
-                )
-            )
-        )
-    else:
-        comp_surface = comp_surface
-    # cf Methods.Machine.Magnet.comp_volume
-    if isinstance(comp_volume, ImportError):
-        comp_volume = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use Magnet method comp_volume: " + str(comp_volume))
-            )
-        )
-    else:
-        comp_volume = comp_volume
-    # cf Methods.Machine.Magnet.is_outwards
-    if isinstance(is_outwards, ImportError):
-        is_outwards = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use Magnet method is_outwards: " + str(is_outwards))
-            )
-        )
-    else:
-        is_outwards = is_outwards
-    # cf Methods.Machine.Magnet.plot
-    if isinstance(plot, ImportError):
-        plot = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use Magnet method plot: " + str(plot))
-            )
-        )
-    else:
-        plot = plot
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -221,6 +98,15 @@ class Magnet(FrozenClass):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+        S += getsizeof(self.mat_type)
+        S += getsizeof(self.type_magnetization)
+        S += getsizeof(self.Lmag)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
