@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -72,6 +73,7 @@ class MatMagnetics(FrozenClass):
         alpha_Br=0,
         Wlam=0,
         BH_curve=-1,
+        LossData=-1,
         init_dict=None,
         init_str=None,
     ):
@@ -102,6 +104,8 @@ class MatMagnetics(FrozenClass):
                 Wlam = init_dict["Wlam"]
             if "BH_curve" in list(init_dict.keys()):
                 BH_curve = init_dict["BH_curve"]
+            if "LossData" in list(init_dict.keys()):
+                LossData = init_dict["LossData"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.mur_lin = mur_lin
@@ -110,6 +114,7 @@ class MatMagnetics(FrozenClass):
         self.alpha_Br = alpha_Br
         self.Wlam = Wlam
         self.BH_curve = BH_curve
+        self.LossData = LossData
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -134,6 +139,11 @@ class MatMagnetics(FrozenClass):
             MatMagnetics_str += "BH_curve = " + tmp
         else:
             MatMagnetics_str += "BH_curve = None" + linesep + linesep
+        if self.LossData is not None:
+            tmp = self.LossData.__str__().replace(linesep, linesep + "\t").rstrip("\t")
+            MatMagnetics_str += "LossData = " + tmp
+        else:
+            MatMagnetics_str += "LossData = None" + linesep + linesep
         return MatMagnetics_str
 
     def __eq__(self, other):
@@ -153,8 +163,23 @@ class MatMagnetics(FrozenClass):
             return False
         if other.BH_curve != self.BH_curve:
             return False
+        if other.LossData != self.LossData:
+            return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+        S += getsizeof(self.mur_lin)
+        S += getsizeof(self.Hc)
+        S += getsizeof(self.Brm20)
+        S += getsizeof(self.alpha_Br)
+        S += getsizeof(self.Wlam)
+        S += getsizeof(self.BH_curve)
+        S += getsizeof(self.LossData)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
@@ -168,6 +193,10 @@ class MatMagnetics(FrozenClass):
             MatMagnetics_dict["BH_curve"] = None
         else:
             MatMagnetics_dict["BH_curve"] = self.BH_curve.as_dict()
+        if self.LossData is None:
+            MatMagnetics_dict["LossData"] = None
+        else:
+            MatMagnetics_dict["LossData"] = self.LossData.as_dict()
         # The class name is added to the dict for deserialisation purpose
         MatMagnetics_dict["__class__"] = "MatMagnetics"
         return MatMagnetics_dict
@@ -182,6 +211,8 @@ class MatMagnetics(FrozenClass):
         self.Wlam = None
         if self.BH_curve is not None:
             self.BH_curve._set_None()
+        if self.LossData is not None:
+            self.LossData._set_None()
 
     def _get_mur_lin(self):
         """getter of mur_lin"""
@@ -309,3 +340,37 @@ class MatMagnetics(FrozenClass):
         :Type: ImportMatrix
         """,
     )
+
+    def _get_LossData(self):
+        """getter of LossData"""
+        return self._LossData
+
+    def _set_LossData(self, value):
+        """setter of LossData"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, ndarray):
+            value = ImportMatrixVal(value=value)
+        elif isinstance(value, list):
+            value = ImportMatrixVal(value=array(value))
+        elif value == -1:
+            value = ImportMatrix()
+        elif isinstance(value, dict):
+            class_obj = import_class(
+                "pyleecan.Classes", value.get("__class__"), "LossData"
+            )
+            value = class_obj(init_dict=value)
+        check_var("LossData", value, "ImportMatrix")
+        self._LossData = value
+
+        if self._LossData is not None:
+            self._LossData.parent = self
+
+    LossData = property(
+        fget=_get_LossData,
+        fset=_set_LossData,
+        doc=u"""specific loss data value triplets, i.e. B, f, P
+
+        :Type: ImportMatrix
+        """,
+    )
