@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -143,6 +144,22 @@ class MatStructural(FrozenClass):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+        S += getsizeof(self.rho)
+        S += getsizeof(self.Ex)
+        S += getsizeof(self.Ey)
+        S += getsizeof(self.Ez)
+        S += getsizeof(self.nu_xy)
+        S += getsizeof(self.nu_xz)
+        S += getsizeof(self.nu_yz)
+        S += getsizeof(self.Gxz)
+        S += getsizeof(self.Gxy)
+        S += getsizeof(self.Gyz)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
