@@ -5,15 +5,21 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from .ParamExplorer import ParamExplorer
 
-from inspect import getsource
-from cloudpickle import dumps, loads
+from ntpath import basename
+from os.path import isfile
 from ._check import CheckTypeError
+import numpy as np
+import random
 from ._check import InitUnKnowClassError
 
 
@@ -22,15 +28,9 @@ class OptiDesignVar(ParamExplorer):
 
     VERSION = 1
 
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -48,29 +48,16 @@ class OptiDesignVar(ParamExplorer):
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            type_var = obj.type_var
-            space = obj.space
-            get_value = obj.get_value
-            name = obj.name
-            symbol = obj.symbol
-            unit = obj.unit
-            setter = obj.setter
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -88,10 +75,8 @@ class OptiDesignVar(ParamExplorer):
                 unit = init_dict["unit"]
             if "setter" in list(init_dict.keys()):
                 setter = init_dict["setter"]
-        # Initialisation by argument
+        # Set the properties (value check and convertion are done in setter)
         self.type_var = type_var
-        if space == -1:
-            space = []
         self.space = space
         self.get_value = get_value
         # Call ParamExplorer init
@@ -102,7 +87,7 @@ class OptiDesignVar(ParamExplorer):
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         OptiDesignVar_str = ""
         # Get the properties inherited from ParamExplorer
@@ -114,12 +99,12 @@ class OptiDesignVar(ParamExplorer):
             + str(self.space).replace(linesep, linesep + "\t")
             + linesep
         )
-        if self._get_value[1] is None:
-            OptiDesignVar_str += "get_value = " + str(self._get_value[1])
+        if self._get_value_str is not None:
+            OptiDesignVar_str += "get_value = " + self._get_value_str + linesep
+        elif self._get_value_func is not None:
+            OptiDesignVar_str += "get_value = " + str(self._get_value_func) + linesep
         else:
-            OptiDesignVar_str += (
-                "get_value = " + linesep + str(self._get_value[1]) + linesep + linesep
-            )
+            OptiDesignVar_str += "get_value = None" + linesep + linesep
         return OptiDesignVar_str
 
     def __eq__(self, other):
@@ -135,26 +120,38 @@ class OptiDesignVar(ParamExplorer):
             return False
         if other.space != self.space:
             return False
-        if other.get_value != self.get_value:
+        if other._get_value_str != self._get_value_str:
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from ParamExplorer
+        S += super(OptiDesignVar, self).__sizeof__()
+        S += getsizeof(self.type_var)
+        if self.space is not None:
+            for value in self.space:
+                S += getsizeof(value)
+        S += getsizeof(self._get_value_str)
+        return S
+
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         # Get the properties inherited from ParamExplorer
         OptiDesignVar_dict = super(OptiDesignVar, self).as_dict()
         OptiDesignVar_dict["type_var"] = self.type_var
-        OptiDesignVar_dict["space"] = self.space
-        if self.get_value is None:
-            OptiDesignVar_dict["get_value"] = None
+        OptiDesignVar_dict["space"] = (
+            self.space.copy() if self.space is not None else None
+        )
+        if self._get_value_str is not None:
+            OptiDesignVar_dict["get_value"] = self._get_value_str
         else:
-            OptiDesignVar_dict["get_value"] = [
-                dumps(self._get_value[0]).decode("ISO-8859-2"),
-                self._get_value[1],
-            ]
-        # The class name is added to the dict fordeserialisation purpose
+            OptiDesignVar_dict["get_value"] = None
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         OptiDesignVar_dict["__class__"] = "OptiDesignVar"
         return OptiDesignVar_dict
@@ -192,6 +189,8 @@ class OptiDesignVar(ParamExplorer):
 
     def _set_space(self, value):
         """setter of space"""
+        if type(value) is int and value == -1:
+            value = list()
         check_var("space", value, "list")
         self._space = value
 
@@ -206,23 +205,28 @@ class OptiDesignVar(ParamExplorer):
 
     def _get_get_value(self):
         """getter of get_value"""
-        return self._get_value[0]
+        return self._get_value_func
 
     def _set_get_value(self, value):
         """setter of get_value"""
-        try:
-            check_var("get_value", value, "list")
-        except CheckTypeError:
-            check_var("get_value", value, "function")
-        if isinstance(value, list):  # Load function from saved dict
-            self._get_value = [loads(value[0].encode("ISO-8859-2")), value[1]]
-        elif value is None:
-            self._get_value = [None, None]
+        if value is None:
+            self._get_value_str = None
+            self._get_value_func = None
+        elif isinstance(value, str) and "lambda" in value:
+            self._get_value_str = value
+            self._get_value_func = eval(value)
+        elif isinstance(value, str) and isfile(value) and value[-3:] == ".py":
+            self._get_value_str = value
+            f = open(value, "r")
+            exec(f.read(), globals())
+            self._get_value_func = eval(basename(value[:-3]))
         elif callable(value):
-            self._get_value = [value, getsource(value)]
+            self._get_value_str = None
+            self._get_value_func = value
         else:
-            raise TypeError(
-                "Expected function or list from a saved file, got: " + str(type(value))
+            raise CheckTypeError(
+                "For property get_value Expected function or str (path to python file or lambda), got: "
+                + str(type(value))
             )
 
     get_value = property(
