@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -161,6 +162,22 @@ class OptiGenAlg(OptiSolver):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from OptiSolver
+        S += super(OptiGenAlg, self).__sizeof__()
+        S += getsizeof(self._selector_str)
+        S += getsizeof(self._crossover_str)
+        S += getsizeof(self._mutator_str)
+        S += getsizeof(self.p_cross)
+        S += getsizeof(self.p_mutate)
+        S += getsizeof(self.size_pop)
+        S += getsizeof(self.nb_gen)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
