@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -22,8 +23,9 @@ import random
 from ._check import InitUnKnowClassError
 from .Simulation import Simulation
 from .OptiDesignVar import OptiDesignVar
-from .DataKeeper import DataKeeper
+from .OptiObjective import OptiObjective
 from .OptiConstraint import OptiConstraint
+from .DataKeeper import DataKeeper
 
 
 class OptiProblem(FrozenClass):
@@ -172,6 +174,27 @@ class OptiProblem(FrozenClass):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+        S += getsizeof(self.simu)
+        if self.design_var is not None:
+            for value in self.design_var:
+                S += getsizeof(value)
+        if self.obj_func is not None:
+            for value in self.obj_func:
+                S += getsizeof(value)
+        S += getsizeof(self._eval_func_str)
+        if self.constraint is not None:
+            for value in self.constraint:
+                S += getsizeof(value)
+        S += getsizeof(self._preprocessing_str)
+        if self.datakeeper_list is not None:
+            for value in self.datakeeper_list:
+                S += getsizeof(value)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
@@ -185,13 +208,19 @@ class OptiProblem(FrozenClass):
         else:
             OptiProblem_dict["design_var"] = list()
             for obj in self.design_var:
-                OptiProblem_dict["design_var"].append(obj.as_dict())
+                if obj is not None:
+                    OptiProblem_dict["design_var"].append(obj.as_dict())
+                else:
+                    OptiProblem_dict["design_var"].append(None)
         if self.obj_func is None:
             OptiProblem_dict["obj_func"] = None
         else:
             OptiProblem_dict["obj_func"] = list()
             for obj in self.obj_func:
-                OptiProblem_dict["obj_func"].append(obj.as_dict())
+                if obj is not None:
+                    OptiProblem_dict["obj_func"].append(obj.as_dict())
+                else:
+                    OptiProblem_dict["obj_func"].append(None)
         if self._eval_func_str is not None:
             OptiProblem_dict["eval_func"] = self._eval_func_str
         else:
@@ -201,7 +230,10 @@ class OptiProblem(FrozenClass):
         else:
             OptiProblem_dict["constraint"] = list()
             for obj in self.constraint:
-                OptiProblem_dict["constraint"].append(obj.as_dict())
+                if obj is not None:
+                    OptiProblem_dict["constraint"].append(obj.as_dict())
+                else:
+                    OptiProblem_dict["constraint"].append(None)
         if self._preprocessing_str is not None:
             OptiProblem_dict["preprocessing"] = self._preprocessing_str
         else:
@@ -211,7 +243,10 @@ class OptiProblem(FrozenClass):
         else:
             OptiProblem_dict["datakeeper_list"] = list()
             for obj in self.datakeeper_list:
-                OptiProblem_dict["datakeeper_list"].append(obj.as_dict())
+                if obj is not None:
+                    OptiProblem_dict["datakeeper_list"].append(obj.as_dict())
+                else:
+                    OptiProblem_dict["datakeeper_list"].append(None)
         # The class name is added to the dict for deserialisation purpose
         OptiProblem_dict["__class__"] = "OptiProblem"
         return OptiProblem_dict
@@ -221,16 +256,12 @@ class OptiProblem(FrozenClass):
 
         if self.simu is not None:
             self.simu._set_None()
-        for obj in self.design_var:
-            obj._set_None()
-        for obj in self.obj_func:
-            obj._set_None()
+        self.design_var = None
+        self.obj_func = None
         self.eval_func = None
-        for obj in self.constraint:
-            obj._set_None()
+        self.constraint = None
         self.preprocessing = None
-        for obj in self.datakeeper_list:
-            obj._set_None()
+        self.datakeeper_list = None
 
     def _get_simu(self):
         """getter of simu"""
@@ -277,6 +308,8 @@ class OptiProblem(FrozenClass):
                         "pyleecan.Classes", obj.get("__class__"), "design_var"
                     )
                     value[ii] = class_obj(init_dict=obj)
+                if value[ii] is not None:
+                    value[ii].parent = self
         if value == -1:
             value = list()
         check_var("design_var", value, "[OptiDesignVar]")
@@ -308,9 +341,11 @@ class OptiProblem(FrozenClass):
                         "pyleecan.Classes", obj.get("__class__"), "obj_func"
                     )
                     value[ii] = class_obj(init_dict=obj)
+                if value[ii] is not None:
+                    value[ii].parent = self
         if value == -1:
             value = list()
-        check_var("obj_func", value, "[DataKeeper]")
+        check_var("obj_func", value, "[OptiObjective]")
         self._obj_func = value
 
     obj_func = property(
@@ -318,7 +353,7 @@ class OptiProblem(FrozenClass):
         fset=_set_obj_func,
         doc=u"""List of objective functions
 
-        :Type: [DataKeeper]
+        :Type: [OptiObjective]
         """,
     )
 
@@ -374,6 +409,8 @@ class OptiProblem(FrozenClass):
                         "pyleecan.Classes", obj.get("__class__"), "constraint"
                     )
                     value[ii] = class_obj(init_dict=obj)
+                if value[ii] is not None:
+                    value[ii].parent = self
         if value == -1:
             value = list()
         check_var("constraint", value, "[OptiConstraint]")
@@ -440,6 +477,8 @@ class OptiProblem(FrozenClass):
                         "pyleecan.Classes", obj.get("__class__"), "datakeeper_list"
                     )
                     value[ii] = class_obj(init_dict=obj)
+                if value[ii] is not None:
+                    value[ii].parent = self
         if value == -1:
             value = list()
         check_var("datakeeper_list", value, "[DataKeeper]")
