@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import set_array, check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -31,9 +32,15 @@ try:
 except ImportError as error:
     get_Us = error
 
+try:
+    from ..Methods.Output.OutElec.comp_I_mag import comp_I_mag
+except ImportError as error:
+    comp_I_mag = error
+
 
 from numpy import array, array_equal
 from ._check import InitUnKnowClassError
+from .OutInternal import OutInternal
 
 
 class OutElec(FrozenClass):
@@ -69,6 +76,15 @@ class OutElec(FrozenClass):
         )
     else:
         get_Us = get_Us
+    # cf Methods.Output.OutElec.comp_I_mag
+    if isinstance(comp_I_mag, ImportError):
+        comp_I_mag = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use OutElec method comp_I_mag: " + str(comp_I_mag))
+            )
+        )
+    else:
+        comp_I_mag = comp_I_mag
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -84,7 +100,7 @@ class OutElec(FrozenClass):
         angle_rotor=None,
         N0=None,
         angle_rotor_initial=0,
-        logger_name="Pyleecan.OutElec",
+        logger_name="Pyleecan.Electrical",
         Tem_av_ref=None,
         Id_ref=None,
         Iq_ref=None,
@@ -94,6 +110,7 @@ class OutElec(FrozenClass):
         Pj_losses=None,
         Pem_av_ref=None,
         Us=None,
+        internal=None,
         init_dict=None,
         init_str=None,
     ):
@@ -146,6 +163,8 @@ class OutElec(FrozenClass):
                 Pem_av_ref = init_dict["Pem_av_ref"]
             if "Us" in list(init_dict.keys()):
                 Us = init_dict["Us"]
+            if "internal" in list(init_dict.keys()):
+                internal = init_dict["internal"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.Time = Time
@@ -165,6 +184,7 @@ class OutElec(FrozenClass):
         self.Pj_losses = Pj_losses
         self.Pem_av_ref = Pem_av_ref
         self.Us = Us
+        self.internal = internal
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -202,6 +222,11 @@ class OutElec(FrozenClass):
         OutElec_str += "Pj_losses = " + str(self.Pj_losses) + linesep
         OutElec_str += "Pem_av_ref = " + str(self.Pem_av_ref) + linesep
         OutElec_str += "Us = " + str(self.Us) + linesep + linesep
+        if self.internal is not None:
+            tmp = self.internal.__str__().replace(linesep, linesep + "\t").rstrip("\t")
+            OutElec_str += "internal = " + tmp
+        else:
+            OutElec_str += "internal = None" + linesep + linesep
         return OutElec_str
 
     def __eq__(self, other):
@@ -243,8 +268,34 @@ class OutElec(FrozenClass):
             return False
         if other.Us != self.Us:
             return False
+        if other.internal != self.internal:
+            return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+        S += getsizeof(self.Time)
+        S += getsizeof(self.Angle)
+        S += getsizeof(self.Is)
+        S += getsizeof(self.Ir)
+        S += getsizeof(self.angle_rotor)
+        S += getsizeof(self.N0)
+        S += getsizeof(self.angle_rotor_initial)
+        S += getsizeof(self.logger_name)
+        S += getsizeof(self.Tem_av_ref)
+        S += getsizeof(self.Id_ref)
+        S += getsizeof(self.Iq_ref)
+        S += getsizeof(self.felec)
+        S += getsizeof(self.Ud_ref)
+        S += getsizeof(self.Uq_ref)
+        S += getsizeof(self.Pj_losses)
+        S += getsizeof(self.Pem_av_ref)
+        S += getsizeof(self.Us)
+        S += getsizeof(self.internal)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
@@ -284,6 +335,10 @@ class OutElec(FrozenClass):
             OutElec_dict["Us"] = None
         else:
             OutElec_dict["Us"] = self.Us.as_dict()
+        if self.internal is None:
+            OutElec_dict["internal"] = None
+        else:
+            OutElec_dict["internal"] = self.internal.as_dict()
         # The class name is added to the dict for deserialisation purpose
         OutElec_dict["__class__"] = "OutElec"
         return OutElec_dict
@@ -308,6 +363,8 @@ class OutElec(FrozenClass):
         self.Pj_losses = None
         self.Pem_av_ref = None
         self.Us = None
+        if self.internal is not None:
+            self.internal._set_None()
 
     def _get_Time(self):
         """getter of Time"""
@@ -384,7 +441,7 @@ class OutElec(FrozenClass):
     Is = property(
         fget=_get_Is,
         fset=_set_Is,
-        doc=u"""Stator currents as a function of time (each column correspond to one phase)
+        doc=u"""Stator currents DataTime object
 
         :Type: SciDataTool.Classes.DataND.DataND
         """,
@@ -666,3 +723,33 @@ class OutElec(FrozenClass):
         :Type: SciDataTool.Classes.DataND.DataND
         """,
     )
+
+    def _get_internal(self):
+        """getter of internal"""
+        return self._internal
+
+    def _set_internal(self, value):
+        """setter of internal"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "pyleecan.Classes", value.get("__class__"), "internal"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = OutInternal()
+        check_var("internal", value, "OutInternal")
+        self._internal = value
+
+        if self._internal is not None:
+            self._internal.parent = self
+
+    internal = property(
+        fget=_get_internal,
+        fset=_set_internal,
+        doc=u"""OutInternal object containg outputs related to a specific model
+
+        :Type: OutInternal
+        """,
+    )
