@@ -5,8 +5,9 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
-from ._check import set_array, check_var, raise_
+from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
 from ..Functions.copy import copy
@@ -14,9 +15,32 @@ from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
 from ._frozen import FrozenClass
 
-from numpy import array, array_equal
+# Import all class method
+# Try/catch to remove unnecessary dependencies in unused method
+try:
+    from ..Methods.Output.OutMag.store import store
+except ImportError as error:
+    store = error
+
+try:
+    from ..Methods.Output.OutMag.clean import clean
+except ImportError as error:
+    clean = error
+
+try:
+    from ..Methods.Output.OutMag.comp_emf import comp_emf
+except ImportError as error:
+    comp_emf = error
+
+try:
+    from ..Methods.Output.OutMag.get_demag import get_demag
+except ImportError as error:
+    get_demag = error
+
+
 from ._check import InitUnKnowClassError
 from .MeshSolution import MeshSolution
+from .OutInternal import OutInternal
 
 
 class OutMag(FrozenClass):
@@ -24,6 +48,43 @@ class OutMag(FrozenClass):
 
     VERSION = 1
 
+    # Check ImportError to remove unnecessary dependencies in unused method
+    # cf Methods.Output.OutMag.store
+    if isinstance(store, ImportError):
+        store = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use OutMag method store: " + str(store))
+            )
+        )
+    else:
+        store = store
+    # cf Methods.Output.OutMag.clean
+    if isinstance(clean, ImportError):
+        clean = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use OutMag method clean: " + str(clean))
+            )
+        )
+    else:
+        clean = clean
+    # cf Methods.Output.OutMag.comp_emf
+    if isinstance(comp_emf, ImportError):
+        comp_emf = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use OutMag method comp_emf: " + str(comp_emf))
+            )
+        )
+    else:
+        comp_emf = comp_emf
+    # cf Methods.Output.OutMag.get_demag
+    if isinstance(get_demag, ImportError):
+        get_demag = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use OutMag method get_demag: " + str(get_demag))
+            )
+        )
+    else:
+        get_demag = get_demag
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -40,10 +101,12 @@ class OutMag(FrozenClass):
         Tem_rip_norm=None,
         Tem_rip_pp=None,
         Phi_wind_stator=None,
+        Phi_wind=None,
         emf=None,
         meshsolution=-1,
-        FEA_dict=None,
-        logger_name="Pyleecan.OutMag",
+        logger_name="Pyleecan.Magnetics",
+        internal=None,
+        Rag=None,
         init_dict=None,
         init_str=None,
     ):
@@ -78,14 +141,18 @@ class OutMag(FrozenClass):
                 Tem_rip_pp = init_dict["Tem_rip_pp"]
             if "Phi_wind_stator" in list(init_dict.keys()):
                 Phi_wind_stator = init_dict["Phi_wind_stator"]
+            if "Phi_wind" in list(init_dict.keys()):
+                Phi_wind = init_dict["Phi_wind"]
             if "emf" in list(init_dict.keys()):
                 emf = init_dict["emf"]
             if "meshsolution" in list(init_dict.keys()):
                 meshsolution = init_dict["meshsolution"]
-            if "FEA_dict" in list(init_dict.keys()):
-                FEA_dict = init_dict["FEA_dict"]
             if "logger_name" in list(init_dict.keys()):
                 logger_name = init_dict["logger_name"]
+            if "internal" in list(init_dict.keys()):
+                internal = init_dict["internal"]
+            if "Rag" in list(init_dict.keys()):
+                Rag = init_dict["Rag"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.Time = Time
@@ -96,10 +163,12 @@ class OutMag(FrozenClass):
         self.Tem_rip_norm = Tem_rip_norm
         self.Tem_rip_pp = Tem_rip_pp
         self.Phi_wind_stator = Phi_wind_stator
+        self.Phi_wind = Phi_wind
         self.emf = emf
         self.meshsolution = meshsolution
-        self.FEA_dict = FEA_dict
         self.logger_name = logger_name
+        self.internal = internal
+        self.Rag = Rag
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -122,13 +191,8 @@ class OutMag(FrozenClass):
         OutMag_str += (
             "Phi_wind_stator = " + str(self.Phi_wind_stator) + linesep + linesep
         )
-        OutMag_str += (
-            "emf = "
-            + linesep
-            + str(self.emf).replace(linesep, linesep + "\t")
-            + linesep
-            + linesep
-        )
+        OutMag_str += "Phi_wind = " + str(self.Phi_wind) + linesep + linesep
+        OutMag_str += "emf = " + str(self.emf) + linesep + linesep
         if self.meshsolution is not None:
             tmp = (
                 self.meshsolution.__str__()
@@ -138,8 +202,13 @@ class OutMag(FrozenClass):
             OutMag_str += "meshsolution = " + tmp
         else:
             OutMag_str += "meshsolution = None" + linesep + linesep
-        OutMag_str += "FEA_dict = " + str(self.FEA_dict) + linesep
         OutMag_str += 'logger_name = "' + str(self.logger_name) + '"' + linesep
+        if self.internal is not None:
+            tmp = self.internal.__str__().replace(linesep, linesep + "\t").rstrip("\t")
+            OutMag_str += "internal = " + tmp
+        else:
+            OutMag_str += "internal = None" + linesep + linesep
+        OutMag_str += "Rag = " + str(self.Rag) + linesep
         return OutMag_str
 
     def __eq__(self, other):
@@ -163,16 +232,42 @@ class OutMag(FrozenClass):
             return False
         if other.Phi_wind_stator != self.Phi_wind_stator:
             return False
-        if not array_equal(other.emf, self.emf):
+        if other.Phi_wind != self.Phi_wind:
+            return False
+        if other.emf != self.emf:
             return False
         if other.meshsolution != self.meshsolution:
             return False
-        if other.FEA_dict != self.FEA_dict:
-            return False
         if other.logger_name != self.logger_name:
             return False
+        if other.internal != self.internal:
+            return False
+        if other.Rag != self.Rag:
+            return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+        S += getsizeof(self.Time)
+        S += getsizeof(self.Angle)
+        S += getsizeof(self.B)
+        S += getsizeof(self.Tem)
+        S += getsizeof(self.Tem_av)
+        S += getsizeof(self.Tem_rip_norm)
+        S += getsizeof(self.Tem_rip_pp)
+        S += getsizeof(self.Phi_wind_stator)
+        if self.Phi_wind is not None:
+            for key, value in self.Phi_wind.items():
+                S += getsizeof(value) + getsizeof(key)
+        S += getsizeof(self.emf)
+        S += getsizeof(self.meshsolution)
+        S += getsizeof(self.logger_name)
+        S += getsizeof(self.internal)
+        S += getsizeof(self.Rag)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
@@ -200,18 +295,29 @@ class OutMag(FrozenClass):
             OutMag_dict["Phi_wind_stator"] = None
         else:
             OutMag_dict["Phi_wind_stator"] = self.Phi_wind_stator.as_dict()
+        if self.Phi_wind is None:
+            OutMag_dict["Phi_wind"] = None
+        else:
+            OutMag_dict["Phi_wind"] = dict()
+            for key, obj in self.Phi_wind.items():
+                if obj is not None:
+                    OutMag_dict["Phi_wind"][key] = obj.as_dict()
+                else:
+                    OutMag_dict["Phi_wind"][key] = None
         if self.emf is None:
             OutMag_dict["emf"] = None
         else:
-            OutMag_dict["emf"] = self.emf.tolist()
+            OutMag_dict["emf"] = self.emf.as_dict()
         if self.meshsolution is None:
             OutMag_dict["meshsolution"] = None
         else:
             OutMag_dict["meshsolution"] = self.meshsolution.as_dict()
-        OutMag_dict["FEA_dict"] = (
-            self.FEA_dict.copy() if self.FEA_dict is not None else None
-        )
         OutMag_dict["logger_name"] = self.logger_name
+        if self.internal is None:
+            OutMag_dict["internal"] = None
+        else:
+            OutMag_dict["internal"] = self.internal.as_dict()
+        OutMag_dict["Rag"] = self.Rag
         # The class name is added to the dict for deserialisation purpose
         OutMag_dict["__class__"] = "OutMag"
         return OutMag_dict
@@ -227,11 +333,14 @@ class OutMag(FrozenClass):
         self.Tem_rip_norm = None
         self.Tem_rip_pp = None
         self.Phi_wind_stator = None
+        self.Phi_wind = None
         self.emf = None
         if self.meshsolution is not None:
             self.meshsolution._set_None()
-        self.FEA_dict = None
         self.logger_name = None
+        if self.internal is not None:
+            self.internal._set_None()
+        self.Rag = None
 
     def _get_Time(self):
         """getter of Time"""
@@ -306,7 +415,7 @@ class OutMag(FrozenClass):
     B = property(
         fget=_get_B,
         fset=_set_B,
-        doc=u"""Airgap flux density components
+        doc=u"""Airgap flux density VectorField object
 
         :Type: SciDataTool.Classes.VectorField.VectorField
         """,
@@ -333,7 +442,7 @@ class OutMag(FrozenClass):
     Tem = property(
         fget=_get_Tem,
         fset=_set_Tem,
-        doc=u"""Electromagnetic torque
+        doc=u"""Electromagnetic torque DataTime object
 
         :Type: SciDataTool.Classes.DataND.DataND
         """,
@@ -414,34 +523,67 @@ class OutMag(FrozenClass):
     Phi_wind_stator = property(
         fget=_get_Phi_wind_stator,
         fset=_set_Phi_wind_stator,
-        doc=u"""Stator winding flux
+        doc=u"""Stator winding flux DataTime object
 
         :Type: SciDataTool.Classes.DataTime.DataTime
         """,
     )
 
+    def _get_Phi_wind(self):
+        """getter of Phi_wind"""
+        if self._Phi_wind is not None:
+            for key, obj in self._Phi_wind.items():
+                if obj is not None:
+                    obj.parent = self
+        return self._Phi_wind
+
+    def _set_Phi_wind(self, value):
+        """setter of Phi_wind"""
+        if type(value) is dict:
+            for key, obj in value.items():
+                if type(obj) is dict:
+                    class_obj = import_class(
+                        "SciDataTool.Classes", obj.get("__class__"), "Phi_wind"
+                    )
+                    value[key] = class_obj(init_dict=obj)
+        if type(value) is int and value == -1:
+            value = dict()
+        check_var("Phi_wind", value, "{DataTime}")
+        self._Phi_wind = value
+
+    Phi_wind = property(
+        fget=_get_Phi_wind,
+        fset=_set_Phi_wind,
+        doc=u"""Dict of lamination winding fluxlinkage DataTime objects
+
+        :Type: {SciDataTool.Classes.DataTime.DataTime}
+        """,
+    )
+
     def _get_emf(self):
         """getter of emf"""
         return self._emf
 
     def _set_emf(self, value):
         """setter of emf"""
-        if type(value) is int and value == -1:
-            value = array([])
-        elif type(value) is list:
-            try:
-                value = array(value)
-            except:
-                pass
-        check_var("emf", value, "ndarray")
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "emf"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = DataTime()
+        check_var("emf", value, "DataTime")
         self._emf = value
 
     emf = property(
         fget=_get_emf,
         fset=_set_emf,
-        doc=u"""Electromotive force
+        doc=u"""Electromotive force DataTime object
 
-        :Type: ndarray
+        :Type: SciDataTool.Classes.DataTime.DataTime
         """,
     )
 
@@ -475,26 +617,6 @@ class OutMag(FrozenClass):
         """,
     )
 
-    def _get_FEA_dict(self):
-        """getter of FEA_dict"""
-        return self._FEA_dict
-
-    def _set_FEA_dict(self, value):
-        """setter of FEA_dict"""
-        if type(value) is int and value == -1:
-            value = dict()
-        check_var("FEA_dict", value, "dict")
-        self._FEA_dict = value
-
-    FEA_dict = property(
-        fget=_get_FEA_dict,
-        fset=_set_FEA_dict,
-        doc=u"""Dictionnary containing the main FEA parameter
-
-        :Type: dict
-        """,
-    )
-
     def _get_logger_name(self):
         """getter of logger_name"""
         return self._logger_name
@@ -512,3 +634,51 @@ class OutMag(FrozenClass):
         :Type: str
         """,
     )
+
+    def _get_internal(self):
+        """getter of internal"""
+        return self._internal
+
+    def _set_internal(self, value):
+        """setter of internal"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "pyleecan.Classes", value.get("__class__"), "internal"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = OutInternal()
+        check_var("internal", value, "OutInternal")
+        self._internal = value
+
+        if self._internal is not None:
+            self._internal.parent = self
+
+    internal = property(
+        fget=_get_internal,
+        fset=_set_internal,
+        doc=u"""OutInternal object containg outputs related to a specific model
+
+        :Type: OutInternal
+        """,
+    )
+
+    def _get_Rag(self):
+        """getter of Rag"""
+        return self._Rag
+
+    def _set_Rag(self, value):
+        """setter of Rag"""
+        check_var("Rag", value, "float")
+        self._Rag = value
+
+    Rag = property(
+        fget=_get_Rag,
+        fset=_set_Rag,
+        doc=u"""Radius value for air-gap computation
+
+        :Type: float
+        """,
+    )
