@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -46,6 +47,16 @@ try:
 except ImportError as error:
     is_inside = error
 
+try:
+    from ..Methods.Mesh.RefTriangle3.get_cell_area import get_cell_area
+except ImportError as error:
+    get_cell_area = error
+
+try:
+    from ..Methods.Mesh.RefTriangle3.get_normal import get_normal
+except ImportError as error:
+    get_normal = error
+
 
 from ._check import InitUnKnowClassError
 
@@ -123,6 +134,28 @@ class RefTriangle3(RefCell):
         )
     else:
         is_inside = is_inside
+    # cf Methods.Mesh.RefTriangle3.get_cell_area
+    if isinstance(get_cell_area, ImportError):
+        get_cell_area = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use RefTriangle3 method get_cell_area: " + str(get_cell_area)
+                )
+            )
+        )
+    else:
+        get_cell_area = get_cell_area
+    # cf Methods.Mesh.RefTriangle3.get_normal
+    if isinstance(get_normal, ImportError):
+        get_normal = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use RefTriangle3 method get_normal: " + str(get_normal)
+                )
+            )
+        )
+    else:
+        get_normal = get_normal
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -172,6 +205,15 @@ class RefTriangle3(RefCell):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from RefCell
+        S += super(RefTriangle3, self).__sizeof__()
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
