@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -12,7 +13,7 @@ from ..Functions.save import save
 from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
-from .SlotWind import SlotWind
+from .Slot import Slot
 
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
@@ -27,20 +28,15 @@ except ImportError as error:
     build_geometry = error
 
 try:
-    from ..Methods.Slot.SlotW24.build_geometry_wind import build_geometry_wind
+    from ..Methods.Slot.SlotW24.build_geometry_active import build_geometry_active
 except ImportError as error:
-    build_geometry_wind = error
+    build_geometry_active = error
 
 try:
     from ..Methods.Slot.SlotW24.check import check
 except ImportError as error:
     check = error
 
-try:
-    from ..Methods.Slot.SlotW24.comp_alphas import comp_alphas
-except ImportError as error:
-    comp_alphas = error
-
 try:
     from ..Methods.Slot.SlotW24.comp_angle_opening import comp_angle_opening
 except ImportError as error:
@@ -52,9 +48,9 @@ except ImportError as error:
     comp_height = error
 
 try:
-    from ..Methods.Slot.SlotW24.comp_height_wind import comp_height_wind
+    from ..Methods.Slot.SlotW24.comp_height_active import comp_height_active
 except ImportError as error:
-    comp_height_wind = error
+    comp_height_active = error
 
 try:
     from ..Methods.Slot.SlotW24.comp_surface import comp_surface
@@ -62,20 +58,25 @@ except ImportError as error:
     comp_surface = error
 
 try:
-    from ..Methods.Slot.SlotW24.comp_surface_wind import comp_surface_wind
+    from ..Methods.Slot.SlotW24.comp_surface_active import comp_surface_active
 except ImportError as error:
-    comp_surface_wind = error
+    comp_surface_active = error
 
 try:
-    from ..Methods.Slot.SlotW24.get_surface_wind import get_surface_wind
+    from ..Methods.Slot.SlotW24.get_surface_active import get_surface_active
 except ImportError as error:
-    get_surface_wind = error
+    get_surface_active = error
+
+try:
+    from ..Methods.Slot.SlotW24.plot_schematics import plot_schematics
+except ImportError as error:
+    plot_schematics = error
 
 
 from ._check import InitUnKnowClassError
 
 
-class SlotW24(SlotWind):
+class SlotW24(Slot):
 
     VERSION = 1
     IS_SYMMETRICAL = 1
@@ -104,18 +105,18 @@ class SlotW24(SlotWind):
         )
     else:
         build_geometry = build_geometry
-    # cf Methods.Slot.SlotW24.build_geometry_wind
-    if isinstance(build_geometry_wind, ImportError):
-        build_geometry_wind = property(
+    # cf Methods.Slot.SlotW24.build_geometry_active
+    if isinstance(build_geometry_active, ImportError):
+        build_geometry_active = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use SlotW24 method build_geometry_wind: "
-                    + str(build_geometry_wind)
+                    "Can't use SlotW24 method build_geometry_active: "
+                    + str(build_geometry_active)
                 )
             )
         )
     else:
-        build_geometry_wind = build_geometry_wind
+        build_geometry_active = build_geometry_active
     # cf Methods.Slot.SlotW24.check
     if isinstance(check, ImportError):
         check = property(
@@ -125,15 +126,6 @@ class SlotW24(SlotWind):
         )
     else:
         check = check
-    # cf Methods.Slot.SlotW24.comp_alphas
-    if isinstance(comp_alphas, ImportError):
-        comp_alphas = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use SlotW24 method comp_alphas: " + str(comp_alphas))
-            )
-        )
-    else:
-        comp_alphas = comp_alphas
     # cf Methods.Slot.SlotW24.comp_angle_opening
     if isinstance(comp_angle_opening, ImportError):
         comp_angle_opening = property(
@@ -155,18 +147,18 @@ class SlotW24(SlotWind):
         )
     else:
         comp_height = comp_height
-    # cf Methods.Slot.SlotW24.comp_height_wind
-    if isinstance(comp_height_wind, ImportError):
-        comp_height_wind = property(
+    # cf Methods.Slot.SlotW24.comp_height_active
+    if isinstance(comp_height_active, ImportError):
+        comp_height_active = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use SlotW24 method comp_height_wind: "
-                    + str(comp_height_wind)
+                    "Can't use SlotW24 method comp_height_active: "
+                    + str(comp_height_active)
                 )
             )
         )
     else:
-        comp_height_wind = comp_height_wind
+        comp_height_active = comp_height_active
     # cf Methods.Slot.SlotW24.comp_surface
     if isinstance(comp_surface, ImportError):
         comp_surface = property(
@@ -178,30 +170,41 @@ class SlotW24(SlotWind):
         )
     else:
         comp_surface = comp_surface
-    # cf Methods.Slot.SlotW24.comp_surface_wind
-    if isinstance(comp_surface_wind, ImportError):
-        comp_surface_wind = property(
+    # cf Methods.Slot.SlotW24.comp_surface_active
+    if isinstance(comp_surface_active, ImportError):
+        comp_surface_active = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use SlotW24 method comp_surface_wind: "
-                    + str(comp_surface_wind)
+                    "Can't use SlotW24 method comp_surface_active: "
+                    + str(comp_surface_active)
                 )
             )
         )
     else:
-        comp_surface_wind = comp_surface_wind
-    # cf Methods.Slot.SlotW24.get_surface_wind
-    if isinstance(get_surface_wind, ImportError):
-        get_surface_wind = property(
+        comp_surface_active = comp_surface_active
+    # cf Methods.Slot.SlotW24.get_surface_active
+    if isinstance(get_surface_active, ImportError):
+        get_surface_active = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use SlotW24 method get_surface_wind: "
-                    + str(get_surface_wind)
+                    "Can't use SlotW24 method get_surface_active: "
+                    + str(get_surface_active)
                 )
             )
         )
     else:
-        get_surface_wind = get_surface_wind
+        get_surface_active = get_surface_active
+    # cf Methods.Slot.SlotW24.plot_schematics
+    if isinstance(plot_schematics, ImportError):
+        plot_schematics = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use SlotW24 method plot_schematics: " + str(plot_schematics)
+                )
+            )
+        )
+    else:
+        plot_schematics = plot_schematics
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -233,16 +236,16 @@ class SlotW24(SlotWind):
         # Set the properties (value check and convertion are done in setter)
         self.W3 = W3
         self.H2 = H2
-        # Call SlotWind init
+        # Call Slot init
         super(SlotW24, self).__init__(Zs=Zs)
-        # The class is frozen (in SlotWind init), for now it's impossible to
+        # The class is frozen (in Slot init), for now it's impossible to
         # add new properties
 
     def __str__(self):
         """Convert this object in a readeable string (for print)"""
 
         SlotW24_str = ""
-        # Get the properties inherited from SlotWind
+        # Get the properties inherited from Slot
         SlotW24_str += super(SlotW24, self).__str__()
         SlotW24_str += "W3 = " + str(self.W3) + linesep
         SlotW24_str += "H2 = " + str(self.H2) + linesep
@@ -254,7 +257,7 @@ class SlotW24(SlotWind):
         if type(other) != type(self):
             return False
 
-        # Check the properties inherited from SlotWind
+        # Check the properties inherited from Slot
         if not super(SlotW24, self).__eq__(other):
             return False
         if other.W3 != self.W3:
@@ -263,10 +266,21 @@ class SlotW24(SlotWind):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from Slot
+        S += super(SlotW24, self).__sizeof__()
+        S += getsizeof(self.W3)
+        S += getsizeof(self.H2)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
-        # Get the properties inherited from SlotWind
+        # Get the properties inherited from Slot
         SlotW24_dict = super(SlotW24, self).as_dict()
         SlotW24_dict["W3"] = self.W3
         SlotW24_dict["H2"] = self.H2
@@ -280,7 +294,7 @@ class SlotW24(SlotWind):
 
         self.W3 = None
         self.H2 = None
-        # Set to None the properties inherited from SlotWind
+        # Set to None the properties inherited from Slot
         super(SlotW24, self)._set_None()
 
     def _get_W3(self):
