@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -12,7 +13,7 @@ from ..Functions.save import save
 from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
-from .SlotWind import SlotWind
+from .Slot import Slot
 
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
@@ -27,9 +28,9 @@ except ImportError as error:
     build_geometry = error
 
 try:
-    from ..Methods.Slot.SlotW61.build_geometry_wind import build_geometry_wind
+    from ..Methods.Slot.SlotW61.build_geometry_active import build_geometry_active
 except ImportError as error:
-    build_geometry_wind = error
+    build_geometry_active = error
 
 try:
     from ..Methods.Slot.SlotW61.check import check
@@ -47,9 +48,9 @@ except ImportError as error:
     comp_height = error
 
 try:
-    from ..Methods.Slot.SlotW61.comp_height_wind import comp_height_wind
+    from ..Methods.Slot.SlotW61.comp_height_active import comp_height_active
 except ImportError as error:
-    comp_height_wind = error
+    comp_height_active = error
 
 try:
     from ..Methods.Slot.SlotW61.comp_surface import comp_surface
@@ -57,20 +58,20 @@ except ImportError as error:
     comp_surface = error
 
 try:
-    from ..Methods.Slot.SlotW61.comp_surface_wind import comp_surface_wind
+    from ..Methods.Slot.SlotW61.comp_surface_active import comp_surface_active
 except ImportError as error:
-    comp_surface_wind = error
+    comp_surface_active = error
 
 try:
-    from ..Methods.Slot.SlotW61.get_surface_wind import get_surface_wind
+    from ..Methods.Slot.SlotW61.get_surface_active import get_surface_active
 except ImportError as error:
-    get_surface_wind = error
+    get_surface_active = error
 
 
 from ._check import InitUnKnowClassError
 
 
-class SlotW61(SlotWind):
+class SlotW61(Slot):
 
     VERSION = 1
     IS_SYMMETRICAL = 0
@@ -99,18 +100,18 @@ class SlotW61(SlotWind):
         )
     else:
         build_geometry = build_geometry
-    # cf Methods.Slot.SlotW61.build_geometry_wind
-    if isinstance(build_geometry_wind, ImportError):
-        build_geometry_wind = property(
+    # cf Methods.Slot.SlotW61.build_geometry_active
+    if isinstance(build_geometry_active, ImportError):
+        build_geometry_active = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use SlotW61 method build_geometry_wind: "
-                    + str(build_geometry_wind)
+                    "Can't use SlotW61 method build_geometry_active: "
+                    + str(build_geometry_active)
                 )
             )
         )
     else:
-        build_geometry_wind = build_geometry_wind
+        build_geometry_active = build_geometry_active
     # cf Methods.Slot.SlotW61.check
     if isinstance(check, ImportError):
         check = property(
@@ -141,18 +142,18 @@ class SlotW61(SlotWind):
         )
     else:
         comp_height = comp_height
-    # cf Methods.Slot.SlotW61.comp_height_wind
-    if isinstance(comp_height_wind, ImportError):
-        comp_height_wind = property(
+    # cf Methods.Slot.SlotW61.comp_height_active
+    if isinstance(comp_height_active, ImportError):
+        comp_height_active = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use SlotW61 method comp_height_wind: "
-                    + str(comp_height_wind)
+                    "Can't use SlotW61 method comp_height_active: "
+                    + str(comp_height_active)
                 )
             )
         )
     else:
-        comp_height_wind = comp_height_wind
+        comp_height_active = comp_height_active
     # cf Methods.Slot.SlotW61.comp_surface
     if isinstance(comp_surface, ImportError):
         comp_surface = property(
@@ -164,30 +165,30 @@ class SlotW61(SlotWind):
         )
     else:
         comp_surface = comp_surface
-    # cf Methods.Slot.SlotW61.comp_surface_wind
-    if isinstance(comp_surface_wind, ImportError):
-        comp_surface_wind = property(
+    # cf Methods.Slot.SlotW61.comp_surface_active
+    if isinstance(comp_surface_active, ImportError):
+        comp_surface_active = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use SlotW61 method comp_surface_wind: "
-                    + str(comp_surface_wind)
+                    "Can't use SlotW61 method comp_surface_active: "
+                    + str(comp_surface_active)
                 )
             )
         )
     else:
-        comp_surface_wind = comp_surface_wind
-    # cf Methods.Slot.SlotW61.get_surface_wind
-    if isinstance(get_surface_wind, ImportError):
-        get_surface_wind = property(
+        comp_surface_active = comp_surface_active
+    # cf Methods.Slot.SlotW61.get_surface_active
+    if isinstance(get_surface_active, ImportError):
+        get_surface_active = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use SlotW61 method get_surface_wind: "
-                    + str(get_surface_wind)
+                    "Can't use SlotW61 method get_surface_active: "
+                    + str(get_surface_active)
                 )
             )
         )
     else:
-        get_surface_wind = get_surface_wind
+        get_surface_active = get_surface_active
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -254,16 +255,16 @@ class SlotW61(SlotWind):
         self.H3 = H3
         self.H4 = H4
         self.W3 = W3
-        # Call SlotWind init
+        # Call Slot init
         super(SlotW61, self).__init__(Zs=Zs)
-        # The class is frozen (in SlotWind init), for now it's impossible to
+        # The class is frozen (in Slot init), for now it's impossible to
         # add new properties
 
     def __str__(self):
         """Convert this object in a readeable string (for print)"""
 
         SlotW61_str = ""
-        # Get the properties inherited from SlotWind
+        # Get the properties inherited from Slot
         SlotW61_str += super(SlotW61, self).__str__()
         SlotW61_str += "W0 = " + str(self.W0) + linesep
         SlotW61_str += "W1 = " + str(self.W1) + linesep
@@ -282,7 +283,7 @@ class SlotW61(SlotWind):
         if type(other) != type(self):
             return False
 
-        # Check the properties inherited from SlotWind
+        # Check the properties inherited from Slot
         if not super(SlotW61, self).__eq__(other):
             return False
         if other.W0 != self.W0:
@@ -305,10 +306,28 @@ class SlotW61(SlotWind):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from Slot
+        S += super(SlotW61, self).__sizeof__()
+        S += getsizeof(self.W0)
+        S += getsizeof(self.W1)
+        S += getsizeof(self.W2)
+        S += getsizeof(self.H0)
+        S += getsizeof(self.H1)
+        S += getsizeof(self.H2)
+        S += getsizeof(self.H3)
+        S += getsizeof(self.H4)
+        S += getsizeof(self.W3)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
-        # Get the properties inherited from SlotWind
+        # Get the properties inherited from Slot
         SlotW61_dict = super(SlotW61, self).as_dict()
         SlotW61_dict["W0"] = self.W0
         SlotW61_dict["W1"] = self.W1
@@ -336,7 +355,7 @@ class SlotW61(SlotWind):
         self.H3 = None
         self.H4 = None
         self.W3 = None
-        # Set to None the properties inherited from SlotWind
+        # Set to None the properties inherited from Slot
         super(SlotW61, self)._set_None()
 
     def _get_W0(self):
