@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -22,9 +23,14 @@ except ImportError as error:
     get_field = error
 
 try:
-    from ..Methods.Mesh.SolutionVector.get_axis import get_axis
+    from ..Methods.Mesh.SolutionVector.get_axes_list import get_axes_list
 except ImportError as error:
-    get_axis = error
+    get_axes_list = error
+
+try:
+    from ..Methods.Mesh.SolutionVector.get_solution import get_solution
+except ImportError as error:
+    get_solution = error
 
 
 from ._check import InitUnKnowClassError
@@ -47,17 +53,29 @@ class SolutionVector(Solution):
         )
     else:
         get_field = get_field
-    # cf Methods.Mesh.SolutionVector.get_axis
-    if isinstance(get_axis, ImportError):
-        get_axis = property(
+    # cf Methods.Mesh.SolutionVector.get_axes_list
+    if isinstance(get_axes_list, ImportError):
+        get_axes_list = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use SolutionVector method get_axis: " + str(get_axis)
+                    "Can't use SolutionVector method get_axes_list: "
+                    + str(get_axes_list)
                 )
             )
         )
     else:
-        get_axis = get_axis
+        get_axes_list = get_axes_list
+    # cf Methods.Mesh.SolutionVector.get_solution
+    if isinstance(get_solution, ImportError):
+        get_solution = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use SolutionVector method get_solution: " + str(get_solution)
+                )
+            )
+        )
+    else:
+        get_solution = get_solution
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -127,6 +145,16 @@ class SolutionVector(Solution):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from Solution
+        S += super(SolutionVector, self).__sizeof__()
+        S += getsizeof(self.field)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
