@@ -5,10 +5,14 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from .Surface import Surface
 
 # Import all class method
@@ -172,42 +176,27 @@ class SurfLine(Surface):
         )
     else:
         comp_point_ref = comp_point_ref
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
     def __init__(
-        self, line_list=list(), point_ref=0, label="", init_dict=None, init_str=None
+        self, line_list=-1, point_ref=0, label="", init_dict=None, init_str=None
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            line_list = obj.line_list
-            point_ref = obj.point_ref
-            label = obj.label
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -217,48 +206,15 @@ class SurfLine(Surface):
                 point_ref = init_dict["point_ref"]
             if "label" in list(init_dict.keys()):
                 label = init_dict["label"]
-        # Initialisation by argument
-        # line_list can be None or a list of Line object
-        self.line_list = list()
-        if type(line_list) is list:
-            for obj in line_list:
-                if obj is None:  # Default value
-                    self.line_list.append(Line())
-                elif isinstance(obj, dict):
-                    # Check that the type is correct (including daughter)
-                    class_name = obj.get("__class__")
-                    if class_name not in [
-                        "Line",
-                        "Arc",
-                        "Arc1",
-                        "Arc2",
-                        "Arc3",
-                        "Segment",
-                    ]:
-                        raise InitUnKnowClassError(
-                            "Unknow class name "
-                            + class_name
-                            + " in init_dict for line_list"
-                        )
-                    # Dynamic import to call the correct constructor
-                    module = __import__(
-                        "pyleecan.Classes." + class_name, fromlist=[class_name]
-                    )
-                    class_obj = getattr(module, class_name)
-                    self.line_list.append(class_obj(init_dict=obj))
-                else:
-                    self.line_list.append(obj)
-        elif line_list is None:
-            self.line_list = list()
-        else:
-            self.line_list = line_list
+        # Set the properties (value check and convertion are done in setter)
+        self.line_list = line_list
         # Call Surface init
         super(SurfLine, self).__init__(point_ref=point_ref, label=label)
         # The class is frozen (in Surface init), for now it's impossible to
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         SurfLine_str = ""
         # Get the properties inherited from Surface
@@ -285,16 +241,33 @@ class SurfLine(Surface):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from Surface
+        S += super(SurfLine, self).__sizeof__()
+        if self.line_list is not None:
+            for value in self.line_list:
+                S += getsizeof(value)
+        return S
+
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         # Get the properties inherited from Surface
         SurfLine_dict = super(SurfLine, self).as_dict()
-        SurfLine_dict["line_list"] = list()
-        for obj in self.line_list:
-            SurfLine_dict["line_list"].append(obj.as_dict())
-        # The class name is added to the dict fordeserialisation purpose
+        if self.line_list is None:
+            SurfLine_dict["line_list"] = None
+        else:
+            SurfLine_dict["line_list"] = list()
+            for obj in self.line_list:
+                if obj is not None:
+                    SurfLine_dict["line_list"].append(obj.as_dict())
+                else:
+                    SurfLine_dict["line_list"].append(None)
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         SurfLine_dict["__class__"] = "SurfLine"
         return SurfLine_dict
@@ -302,27 +275,34 @@ class SurfLine(Surface):
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
-        for obj in self.line_list:
-            obj._set_None()
+        self.line_list = None
         # Set to None the properties inherited from Surface
         super(SurfLine, self)._set_None()
 
     def _get_line_list(self):
         """getter of line_list"""
-        for obj in self._line_list:
-            if obj is not None:
-                obj.parent = self
+        if self._line_list is not None:
+            for obj in self._line_list:
+                if obj is not None:
+                    obj.parent = self
         return self._line_list
 
     def _set_line_list(self, value):
         """setter of line_list"""
+        if type(value) is list:
+            for ii, obj in enumerate(value):
+                if type(obj) is dict:
+                    class_obj = import_class(
+                        "pyleecan.Classes", obj.get("__class__"), "line_list"
+                    )
+                    value[ii] = class_obj(init_dict=obj)
+                if value[ii] is not None:
+                    value[ii].parent = self
+        if value == -1:
+            value = list()
         check_var("line_list", value, "[Line]")
         self._line_list = value
 
-        for obj in self._line_list:
-            if obj is not None:
-                obj.parent = self
-
     line_list = property(
         fget=_get_line_list,
         fset=_set_line_list,
