@@ -5,10 +5,14 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from .Winding import Winding
 
 # Import all class method
@@ -58,15 +62,9 @@ class WindingCW2LR(Winding):
         )
     else:
         get_dim_wind = get_dim_wind
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -86,33 +84,16 @@ class WindingCW2LR(Winding):
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if conductor == -1:
-            conductor = Conductor()
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            is_reverse_wind = obj.is_reverse_wind
-            Nslot_shift_wind = obj.Nslot_shift_wind
-            qs = obj.qs
-            Ntcoil = obj.Ntcoil
-            Npcpp = obj.Npcpp
-            type_connection = obj.type_connection
-            p = obj.p
-            Lewout = obj.Lewout
-            conductor = obj.conductor
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -134,7 +115,7 @@ class WindingCW2LR(Winding):
                 Lewout = init_dict["Lewout"]
             if "conductor" in list(init_dict.keys()):
                 conductor = init_dict["conductor"]
-        # Initialisation by argument
+        # Set the properties (value check and convertion are done in setter)
         # Call Winding init
         super(WindingCW2LR, self).__init__(
             is_reverse_wind=is_reverse_wind,
@@ -151,7 +132,7 @@ class WindingCW2LR(Winding):
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         WindingCW2LR_str = ""
         # Get the properties inherited from Winding
@@ -169,13 +150,21 @@ class WindingCW2LR(Winding):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from Winding
+        S += super(WindingCW2LR, self).__sizeof__()
+        return S
+
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         # Get the properties inherited from Winding
         WindingCW2LR_dict = super(WindingCW2LR, self).as_dict()
-        # The class name is added to the dict fordeserialisation purpose
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         WindingCW2LR_dict["__class__"] = "WindingCW2LR"
         return WindingCW2LR_dict
