@@ -5,10 +5,14 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import set_array, check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from .Winding import Winding
 
 # Import all class method
@@ -59,15 +63,9 @@ class WindingUD(Winding):
         )
     else:
         get_dim_wind = get_dim_wind
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -88,34 +86,16 @@ class WindingUD(Winding):
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if conductor == -1:
-            conductor = Conductor()
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            user_wind_mat = obj.user_wind_mat
-            is_reverse_wind = obj.is_reverse_wind
-            Nslot_shift_wind = obj.Nslot_shift_wind
-            qs = obj.qs
-            Ntcoil = obj.Ntcoil
-            Npcpp = obj.Npcpp
-            type_connection = obj.type_connection
-            p = obj.p
-            Lewout = obj.Lewout
-            conductor = obj.conductor
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -139,9 +119,8 @@ class WindingUD(Winding):
                 Lewout = init_dict["Lewout"]
             if "conductor" in list(init_dict.keys()):
                 conductor = init_dict["conductor"]
-        # Initialisation by argument
-        # user_wind_mat can be None, a ndarray or a list
-        set_array(self, "user_wind_mat", user_wind_mat)
+        # Set the properties (value check and convertion are done in setter)
+        self.user_wind_mat = user_wind_mat
         # Call Winding init
         super(WindingUD, self).__init__(
             is_reverse_wind=is_reverse_wind,
@@ -158,7 +137,7 @@ class WindingUD(Winding):
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         WindingUD_str = ""
         # Get the properties inherited from Winding
@@ -185,9 +164,18 @@ class WindingUD(Winding):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from Winding
+        S += super(WindingUD, self).__sizeof__()
+        S += getsizeof(self.user_wind_mat)
+        return S
+
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         # Get the properties inherited from Winding
         WindingUD_dict = super(WindingUD, self).as_dict()
@@ -195,7 +183,7 @@ class WindingUD(Winding):
             WindingUD_dict["user_wind_mat"] = None
         else:
             WindingUD_dict["user_wind_mat"] = self.user_wind_mat.tolist()
-        # The class name is added to the dict fordeserialisation purpose
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         WindingUD_dict["__class__"] = "WindingUD"
         return WindingUD_dict
@@ -213,7 +201,7 @@ class WindingUD(Winding):
 
     def _set_user_wind_mat(self, value):
         """setter of user_wind_mat"""
-        if value is None:
+        if type(value) is int and value == -1:
             value = array([])
         elif type(value) is list:
             try:
