@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
@@ -126,6 +127,11 @@ try:
 except ImportError as error:
     get_pareto_index = error
 
+try:
+    from ..Methods.Output.XOutput.print_memory import print_memory
+except ImportError as error:
+    print_memory = error
+
 
 from ._check import InitUnKnowClassError
 from .ParamExplorer import ParamExplorer
@@ -138,6 +144,7 @@ from .OutMag import OutMag
 from .OutStruct import OutStruct
 from .OutPost import OutPost
 from .OutForce import OutForce
+from .OutLoss import OutLoss
 
 
 class XOutput(Output):
@@ -356,6 +363,17 @@ class XOutput(Output):
         )
     else:
         get_pareto_index = get_pareto_index
+    # cf Methods.Output.XOutput.print_memory
+    if isinstance(print_memory, ImportError):
+        print_memory = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use XOutput method print_memory: " + str(print_memory)
+                )
+            )
+        )
+    else:
+        print_memory = print_memory
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -377,6 +395,7 @@ class XOutput(Output):
         post=-1,
         logger_name="Pyleecan.Output",
         force=-1,
+        loss=-1,
         init_dict=None,
         init_str=None,
     ):
@@ -421,6 +440,8 @@ class XOutput(Output):
                 logger_name = init_dict["logger_name"]
             if "force" in list(init_dict.keys()):
                 force = init_dict["force"]
+            if "loss" in list(init_dict.keys()):
+                loss = init_dict["loss"]
         # Set the properties (value check and convertion are done in setter)
         self.paramexplorer_list = paramexplorer_list
         self.output_list = output_list
@@ -437,6 +458,7 @@ class XOutput(Output):
             post=post,
             logger_name=logger_name,
             force=force,
+            loss=loss,
         )
         # The class is frozen (in Output init), for now it's impossible to
         # add new properties
@@ -495,6 +517,25 @@ class XOutput(Output):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from Output
+        S += super(XOutput, self).__sizeof__()
+        if self.paramexplorer_list is not None:
+            for value in self.paramexplorer_list:
+                S += getsizeof(value)
+        if self.output_list is not None:
+            for value in self.output_list:
+                S += getsizeof(value)
+        if self.xoutput_dict is not None:
+            for key, value in self.xoutput_dict.items():
+                S += getsizeof(value) + getsizeof(key)
+        S += getsizeof(self.nb_simu)
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
@@ -505,19 +546,28 @@ class XOutput(Output):
         else:
             XOutput_dict["paramexplorer_list"] = list()
             for obj in self.paramexplorer_list:
-                XOutput_dict["paramexplorer_list"].append(obj.as_dict())
+                if obj is not None:
+                    XOutput_dict["paramexplorer_list"].append(obj.as_dict())
+                else:
+                    XOutput_dict["paramexplorer_list"].append(None)
         if self.output_list is None:
             XOutput_dict["output_list"] = None
         else:
             XOutput_dict["output_list"] = list()
             for obj in self.output_list:
-                XOutput_dict["output_list"].append(obj.as_dict())
+                if obj is not None:
+                    XOutput_dict["output_list"].append(obj.as_dict())
+                else:
+                    XOutput_dict["output_list"].append(None)
         if self.xoutput_dict is None:
             XOutput_dict["xoutput_dict"] = None
         else:
             XOutput_dict["xoutput_dict"] = dict()
             for key, obj in self.xoutput_dict.items():
-                XOutput_dict["xoutput_dict"][key] = obj.as_dict()
+                if obj is not None:
+                    XOutput_dict["xoutput_dict"][key] = obj.as_dict()
+                else:
+                    XOutput_dict["xoutput_dict"][key] = None
         XOutput_dict["nb_simu"] = self.nb_simu
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
@@ -527,12 +577,9 @@ class XOutput(Output):
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
-        for obj in self.paramexplorer_list:
-            obj._set_None()
-        for obj in self.output_list:
-            obj._set_None()
-        for key, obj in self.xoutput_dict.items():
-            obj._set_None()
+        self.paramexplorer_list = None
+        self.output_list = None
+        self.xoutput_dict = None
         self.nb_simu = None
         # Set to None the properties inherited from Output
         super(XOutput, self)._set_None()
@@ -554,6 +601,8 @@ class XOutput(Output):
                         "pyleecan.Classes", obj.get("__class__"), "paramexplorer_list"
                     )
                     value[ii] = class_obj(init_dict=obj)
+                if value[ii] is not None:
+                    value[ii].parent = self
         if value == -1:
             value = list()
         check_var("paramexplorer_list", value, "[ParamExplorer]")
@@ -585,6 +634,8 @@ class XOutput(Output):
                         "pyleecan.Classes", obj.get("__class__"), "output_list"
                     )
                     value[ii] = class_obj(init_dict=obj)
+                if value[ii] is not None:
+                    value[ii].parent = self
         if value == -1:
             value = list()
         check_var("output_list", value, "[Output]")
