@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
-import femm
 from re import findall
 
 
-def create_FEMM_magnet(label, is_mmf, is_eddies, materials, lam):
+def create_FEMM_magnet(femm, label, is_mmf, is_eddies, materials, lam):
     """Set the material of the magnet in FEMM
 
     Parameters
     ----------
+    femm : FEMMHandler
+        client to send command to a FEMM instance
     label : str
         label of the magnet
     is_mmfr : bool
@@ -23,19 +24,15 @@ def create_FEMM_magnet(label, is_mmf, is_eddies, materials, lam):
     -------
     (str, list)
         property, materials
-    
+
     """
     # some if's and else's to find the correct material parameter from magnet label
+    idx_str = findall(r"_T\d+_", label)[0][2:-1]
     if "HoleMagnet" in label:
-        if "T0" in label:
-            magnet = lam.hole[0].magnet_0
-        elif "T1" in label:
-            magnet = lam.hole[0].magnet_1
-        elif "T2" in label:
-            magnet = lam.hole[0].magnet_2
+        magnet_dict = lam.hole[0].get_magnet_dict()
+        magnet = magnet_dict["magnet_" + idx_str]
     else:
-        idx_str = findall(r"_T\d+_", label)[0][2:-1]
-        magnet = lam.slot.magnet[int(idx_str)]
+        magnet = lam.magnet
         # pole_mag = "_" + label[12] + "_" + label[-4]
 
     rho = magnet.mat_type.elec.rho  # Resistivity at 20°C
