@@ -54,12 +54,20 @@ class SBar(Gen_SBar, QWidget):
         # Set unit name (m ou mm)
         wid_list = [self.unit_Hscr, self.unit_Lscr, self.unit_Lewout]
         for wid in wid_list:
-            wid.setText(gui_option.unit.get_m_name())
+            wid.setText("[" + gui_option.unit.get_m_name() + "]")
+
+        # Update winding qs
+        if (
+            self.machine.rotor.slot.Zs is not None
+            and self.machine.rotor.winding.qs is None
+        ):
+            self.machine.rotor.winding.qs = self.machine.rotor.slot.Zs
 
         # Set materials
         self.w_mat.def_mat = "Copper1"
         self.w_mat.setText("Ring material:")
         self.w_mat.update(self.machine.rotor, "ring_mat", self.matlib)
+        self.w_mat.b_matlib.hide()
 
         # Initialize the GUI with the current machine value
         self.lf_Hscr.setValue(machine.rotor.Hscr)
