@@ -64,68 +64,72 @@ class Ui_SBar(object):
         self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
         self.img_ring = QLabel(self.g_ring)
         self.img_ring.setObjectName(u"img_ring")
-        self.img_ring.setMaximumSize(QSize(300, 300))
+        self.img_ring.setMaximumSize(QSize(16777215, 16777215))
         self.img_ring.setPixmap(QPixmap(u":/images/images/MachineSetup/Bar/Ring.PNG"))
         self.img_ring.setScaledContents(True)
 
         self.horizontalLayout_2.addWidget(self.img_ring)
 
-        self.verticalLayout_3 = QVBoxLayout()
+        self.widget = QWidget(self.g_ring)
+        self.widget.setObjectName(u"widget")
+        self.widget.setMinimumSize(QSize(250, 0))
+        self.widget.setMaximumSize(QSize(250, 16777215))
+        self.verticalLayout_3 = QVBoxLayout(self.widget)
         self.verticalLayout_3.setObjectName(u"verticalLayout_3")
         self.gridLayout = QGridLayout()
         self.gridLayout.setObjectName(u"gridLayout")
-        self.lf_Lewout = FloatEdit(self.g_ring)
+        self.lf_Lewout = FloatEdit(self.widget)
         self.lf_Lewout.setObjectName(u"lf_Lewout")
         self.lf_Lewout.setMinimumSize(QSize(70, 0))
         self.lf_Lewout.setMaximumSize(QSize(100, 20))
 
         self.gridLayout.addWidget(self.lf_Lewout, 2, 1, 1, 1)
 
-        self.unit_Hscr = QLabel(self.g_ring)
+        self.unit_Hscr = QLabel(self.widget)
         self.unit_Hscr.setObjectName(u"unit_Hscr")
         self.unit_Hscr.setMinimumSize(QSize(0, 0))
 
         self.gridLayout.addWidget(self.unit_Hscr, 0, 2, 1, 1)
 
-        self.unit_Lscr = QLabel(self.g_ring)
+        self.unit_Lscr = QLabel(self.widget)
         self.unit_Lscr.setObjectName(u"unit_Lscr")
         self.unit_Lscr.setMinimumSize(QSize(0, 0))
 
         self.gridLayout.addWidget(self.unit_Lscr, 1, 2, 1, 1)
 
-        self.in_Hscr = QLabel(self.g_ring)
+        self.in_Hscr = QLabel(self.widget)
         self.in_Hscr.setObjectName(u"in_Hscr")
         self.in_Hscr.setMinimumSize(QSize(40, 0))
 
         self.gridLayout.addWidget(self.in_Hscr, 0, 0, 1, 1)
 
-        self.lf_Hscr = FloatEdit(self.g_ring)
+        self.lf_Hscr = FloatEdit(self.widget)
         self.lf_Hscr.setObjectName(u"lf_Hscr")
         self.lf_Hscr.setMinimumSize(QSize(70, 0))
         self.lf_Hscr.setMaximumSize(QSize(100, 20))
 
         self.gridLayout.addWidget(self.lf_Hscr, 0, 1, 1, 1)
 
-        self.lf_Lscr = FloatEdit(self.g_ring)
+        self.lf_Lscr = FloatEdit(self.widget)
         self.lf_Lscr.setObjectName(u"lf_Lscr")
         self.lf_Lscr.setMinimumSize(QSize(70, 0))
         self.lf_Lscr.setMaximumSize(QSize(100, 20))
 
         self.gridLayout.addWidget(self.lf_Lscr, 1, 1, 1, 1)
 
-        self.unit_Lewout = QLabel(self.g_ring)
+        self.unit_Lewout = QLabel(self.widget)
         self.unit_Lewout.setObjectName(u"unit_Lewout")
         self.unit_Lewout.setMinimumSize(QSize(0, 0))
 
         self.gridLayout.addWidget(self.unit_Lewout, 2, 2, 1, 1)
 
-        self.in_Lewout = QLabel(self.g_ring)
+        self.in_Lewout = QLabel(self.widget)
         self.in_Lewout.setObjectName(u"in_Lewout")
         self.in_Lewout.setMinimumSize(QSize(40, 0))
 
         self.gridLayout.addWidget(self.in_Lewout, 2, 0, 1, 1)
 
-        self.in_Lscr = QLabel(self.g_ring)
+        self.in_Lscr = QLabel(self.widget)
         self.in_Lscr.setObjectName(u"in_Lscr")
         self.in_Lscr.setMinimumSize(QSize(40, 0))
 
@@ -133,7 +137,7 @@ class Ui_SBar(object):
 
         self.verticalLayout_3.addLayout(self.gridLayout)
 
-        self.w_mat = WMatSelect(self.g_ring)
+        self.w_mat = WMatSelect(self.widget)
         self.w_mat.setObjectName(u"w_mat")
 
         self.verticalLayout_3.addWidget(self.w_mat)
@@ -144,7 +148,7 @@ class Ui_SBar(object):
 
         self.verticalLayout_3.addItem(self.verticalSpacer)
 
-        self.horizontalLayout_2.addLayout(self.verticalLayout_3)
+        self.horizontalLayout_2.addWidget(self.widget)
 
         self.verticalLayout_2.addWidget(self.g_ring)
 
