@@ -19,7 +19,7 @@ class Ui_PHoleM50(object):
     def setupUi(self, PHoleM50):
         if not PHoleM50.objectName():
             PHoleM50.setObjectName(u"PHoleM50")
-        PHoleM50.resize(740, 512)
+        PHoleM50.resize(978, 561)
         PHoleM50.setMinimumSize(QSize(740, 440))
         PHoleM50.setMaximumSize(QSize(16777215, 16777215))
         self.horizontalLayout = QHBoxLayout(PHoleM50)
@@ -28,15 +28,15 @@ class Ui_PHoleM50(object):
         self.verticalLayout_3.setObjectName(u"verticalLayout_3")
         self.img_slot = QLabel(PHoleM50)
         self.img_slot.setObjectName(u"img_slot")
-        sizePolicy = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
+        sizePolicy = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
         sizePolicy.setHeightForWidth(self.img_slot.sizePolicy().hasHeightForWidth())
         self.img_slot.setSizePolicy(sizePolicy)
-        self.img_slot.setMinimumSize(QSize(500, 170))
-        self.img_slot.setMaximumSize(QSize(500, 170))
+        self.img_slot.setMinimumSize(QSize(0, 0))
+        self.img_slot.setMaximumSize(QSize(16777215, 16777215))
         self.img_slot.setPixmap(
-            QPixmap(u":/images/images/MachineSetup/WSlot/Slot_50.PNG")
+            QPixmap(u":/images/images/MachineSetup/SMHoleMag/HoleM50.png")
         )
         self.img_slot.setScaledContents(True)
 
@@ -52,7 +52,7 @@ class Ui_PHoleM50(object):
         )
         self.txt_constraint.setSizePolicy(sizePolicy1)
         self.txt_constraint.setMinimumSize(QSize(200, 0))
-        self.txt_constraint.setMaximumSize(QSize(16777215, 100))
+        self.txt_constraint.setMaximumSize(QSize(16777215, 120))
         self.txt_constraint.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
         self.txt_constraint.setTextInteractionFlags(
             Qt.TextSelectableByKeyboard | Qt.TextSelectableByMouse
@@ -62,181 +62,191 @@ class Ui_PHoleM50(object):
 
         self.horizontalLayout.addLayout(self.verticalLayout_3)
 
-        self.verticalLayout_2 = QVBoxLayout()
+        self.widget = QWidget(PHoleM50)
+        self.widget.setObjectName(u"widget")
+        self.widget.setMinimumSize(QSize(250, 0))
+        self.widget.setMaximumSize(QSize(250, 16777215))
+        self.verticalLayout_2 = QVBoxLayout(self.widget)
         self.verticalLayout_2.setObjectName(u"verticalLayout_2")
         self.gridLayout = QGridLayout()
         self.gridLayout.setObjectName(u"gridLayout")
-        self.unit_W2 = QLabel(PHoleM50)
+        self.unit_W2 = QLabel(self.widget)
         self.unit_W2.setObjectName(u"unit_W2")
 
         self.gridLayout.addWidget(self.unit_W2, 7, 2, 1, 1)
 
-        self.unit_W1 = QLabel(PHoleM50)
+        self.unit_W1 = QLabel(self.widget)
         self.unit_W1.setObjectName(u"unit_W1")
 
         self.gridLayout.addWidget(self.unit_W1, 6, 2, 1, 1)
 
-        self.lf_W0 = FloatEdit(PHoleM50)
+        self.lf_W0 = FloatEdit(self.widget)
         self.lf_W0.setObjectName(u"lf_W0")
 
         self.gridLayout.addWidget(self.lf_W0, 5, 1, 1, 1)
 
-        self.unit_H2 = QLabel(PHoleM50)
+        self.unit_H2 = QLabel(self.widget)
         self.unit_H2.setObjectName(u"unit_H2")
 
         self.gridLayout.addWidget(self.unit_H2, 2, 2, 1, 1)
 
-        self.in_H4 = QLabel(PHoleM50)
+        self.in_H4 = QLabel(self.widget)
         self.in_H4.setObjectName(u"in_H4")
 
         self.gridLayout.addWidget(self.in_H4, 4, 0, 1, 1)
 
-        self.lf_H2 = FloatEdit(PHoleM50)
+        self.lf_H2 = FloatEdit(self.widget)
         self.lf_H2.setObjectName(u"lf_H2")
 
         self.gridLayout.addWidget(self.lf_H2, 2, 1, 1, 1)
 
-        self.lf_H1 = FloatEdit(PHoleM50)
+        self.lf_H1 = FloatEdit(self.widget)
         self.lf_H1.setObjectName(u"lf_H1")
 
         self.gridLayout.addWidget(self.lf_H1, 1, 1, 1, 1)
 
-        self.unit_H1 = QLabel(PHoleM50)
+        self.unit_H1 = QLabel(self.widget)
         self.unit_H1.setObjectName(u"unit_H1")
 
         self.gridLayout.addWidget(self.unit_H1, 1, 2, 1, 1)
 
-        self.lf_H4 = FloatEdit(PHoleM50)
+        self.lf_H4 = FloatEdit(self.widget)
         self.lf_H4.setObjectName(u"lf_H4")
 
         self.gridLayout.addWidget(self.lf_H4, 4, 1, 1, 1)
 
-        self.in_W1 = QLabel(PHoleM50)
+        self.in_W1 = QLabel(self.widget)
         self.in_W1.setObjectName(u"in_W1")
 
         self.gridLayout.addWidget(self.in_W1, 6, 0, 1, 1)
 
-        self.lf_H0 = FloatEdit(PHoleM50)
+        self.lf_H0 = FloatEdit(self.widget)
         self.lf_H0.setObjectName(u"lf_H0")
 
         self.gridLayout.addWidget(self.lf_H0, 0, 1, 1, 1)
 
-        self.unit_H0 = QLabel(PHoleM50)
+        self.unit_H0 = QLabel(self.widget)
         self.unit_H0.setObjectName(u"unit_H0")
 
         self.gridLayout.addWidget(self.unit_H0, 0, 2, 1, 1)
 
-        self.lf_W3 = FloatEdit(PHoleM50)
+        self.lf_W3 = FloatEdit(self.widget)
         self.lf_W3.setObjectName(u"lf_W3")
 
         self.gridLayout.addWidget(self.lf_W3, 8, 1, 1, 1)
 
-        self.in_H1 = QLabel(PHoleM50)
+        self.in_H1 = QLabel(self.widget)
         self.in_H1.setObjectName(u"in_H1")
 
         self.gridLayout.addWidget(self.in_H1, 1, 0, 1, 1)
 
-        self.unit_H4 = QLabel(PHoleM50)
+        self.unit_H4 = QLabel(self.widget)
         self.unit_H4.setObjectName(u"unit_H4")
 
         self.gridLayout.addWidget(self.unit_H4, 4, 2, 1, 1)
 
-        self.in_H3 = QLabel(PHoleM50)
+        self.in_H3 = QLabel(self.widget)
         self.in_H3.setObjectName(u"in_H3")
 
         self.gridLayout.addWidget(self.in_H3, 3, 0, 1, 1)
 
-        self.unit_W0 = QLabel(PHoleM50)
+        self.unit_W0 = QLabel(self.widget)
         self.unit_W0.setObjectName(u"unit_W0")
 
         self.gridLayout.addWidget(self.unit_W0, 5, 2, 1, 1)
 
-        self.in_W2 = QLabel(PHoleM50)
+        self.in_W2 = QLabel(self.widget)
         self.in_W2.setObjectName(u"in_W2")
 
         self.gridLayout.addWidget(self.in_W2, 7, 0, 1, 1)
 
-        self.in_H0 = QLabel(PHoleM50)
+        self.in_H0 = QLabel(self.widget)
         self.in_H0.setObjectName(u"in_H0")
 
         self.gridLayout.addWidget(self.in_H0, 0, 0, 1, 1)
 
-        self.unit_H3 = QLabel(PHoleM50)
+        self.unit_H3 = QLabel(self.widget)
         self.unit_H3.setObjectName(u"unit_H3")
 
         self.gridLayout.addWidget(self.unit_H3, 3, 2, 1, 1)
 
-        self.lf_W1 = FloatEdit(PHoleM50)
+        self.lf_W1 = FloatEdit(self.widget)
         self.lf_W1.setObjectName(u"lf_W1")
 
         self.gridLayout.addWidget(self.lf_W1, 6, 1, 1, 1)
 
-        self.lf_H3 = FloatEdit(PHoleM50)
+        self.lf_H3 = FloatEdit(self.widget)
         self.lf_H3.setObjectName(u"lf_H3")
 
         self.gridLayout.addWidget(self.lf_H3, 3, 1, 1, 1)
 
-        self.unit_W4 = QLabel(PHoleM50)
+        self.unit_W4 = QLabel(self.widget)
         self.unit_W4.setObjectName(u"unit_W4")
 
         self.gridLayout.addWidget(self.unit_W4, 9, 2, 1, 1)
 
-        self.in_W0 = QLabel(PHoleM50)
+        self.in_W0 = QLabel(self.widget)
         self.in_W0.setObjectName(u"in_W0")
 
         self.gridLayout.addWidget(self.in_W0, 5, 0, 1, 1)
 
-        self.in_H2 = QLabel(PHoleM50)
+        self.in_H2 = QLabel(self.widget)
         self.in_H2.setObjectName(u"in_H2")
 
         self.gridLayout.addWidget(self.in_H2, 2, 0, 1, 1)
 
-        self.in_W3 = QLabel(PHoleM50)
+        self.in_W3 = QLabel(self.widget)
         self.in_W3.setObjectName(u"in_W3")
 
         self.gridLayout.addWidget(self.in_W3, 8, 0, 1, 1)
 
-        self.lf_W2 = FloatEdit(PHoleM50)
+        self.lf_W2 = FloatEdit(self.widget)
         self.lf_W2.setObjectName(u"lf_W2")
 
         self.gridLayout.addWidget(self.lf_W2, 7, 1, 1, 1)
 
-        self.lf_W4 = FloatEdit(PHoleM50)
+        self.lf_W4 = FloatEdit(self.widget)
         self.lf_W4.setObjectName(u"lf_W4")
 
         self.gridLayout.addWidget(self.lf_W4, 9, 1, 1, 1)
 
-        self.in_W4 = QLabel(PHoleM50)
+        self.in_W4 = QLabel(self.widget)
         self.in_W4.setObjectName(u"in_W4")
 
         self.gridLayout.addWidget(self.in_W4, 9, 0, 1, 1)
 
-        self.unit_W3 = QLabel(PHoleM50)
+        self.unit_W3 = QLabel(self.widget)
         self.unit_W3.setObjectName(u"unit_W3")
 
         self.gridLayout.addWidget(self.unit_W3, 8, 2, 1, 1)
 
         self.verticalLayout_2.addLayout(self.gridLayout)
 
-        self.w_mat_0 = WMatSelect(PHoleM50)
+        self.w_mat_0 = WMatSelect(self.widget)
         self.w_mat_0.setObjectName(u"w_mat_0")
         self.w_mat_0.setMinimumSize(QSize(100, 0))
 
         self.verticalLayout_2.addWidget(self.w_mat_0)
 
-        self.w_mat_1 = WMatSelect(PHoleM50)
+        self.w_mat_1 = WMatSelect(self.widget)
         self.w_mat_1.setObjectName(u"w_mat_1")
         self.w_mat_1.setMinimumSize(QSize(100, 0))
 
         self.verticalLayout_2.addWidget(self.w_mat_1)
 
-        self.w_mat_2 = WMatSelect(PHoleM50)
+        self.w_mat_2 = WMatSelect(self.widget)
         self.w_mat_2.setObjectName(u"w_mat_2")
         self.w_mat_2.setMinimumSize(QSize(100, 0))
 
         self.verticalLayout_2.addWidget(self.w_mat_2)
 
-        self.g_output = QGroupBox(PHoleM50)
+        self.verticalSpacer = QSpacerItem(
+            20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
+        )
+
+        self.verticalLayout_2.addItem(self.verticalSpacer)
+
+        self.g_output = QGroupBox(self.widget)
         self.g_output.setObjectName(u"g_output")
         self.g_output.setMinimumSize(QSize(200, 0))
         self.verticalLayout = QVBoxLayout(self.g_output)
@@ -261,15 +271,9 @@ class Ui_PHoleM50(object):
 
         self.verticalLayout.addWidget(self.out_W5)
 
-        self.verticalSpacer = QSpacerItem(
-            20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
-        )
-
-        self.verticalLayout.addItem(self.verticalSpacer)
-
         self.verticalLayout_2.addWidget(self.g_output)
 
-        self.horizontalLayout.addLayout(self.verticalLayout_2)
+        self.horizontalLayout.addWidget(self.widget)
 
         QWidget.setTabOrder(self.lf_H0, self.lf_H1)
         QWidget.setTabOrder(self.lf_H1, self.lf_H2)
@@ -296,34 +300,34 @@ class Ui_PHoleM50(object):
                 '<html><head><meta name="qrichtext" content="1" /><style type="text/css">\n'
                 "p, li { white-space: pre-wrap; }\n"
                 "</style></head><body style=\" font-family:'MS Shell Dlg 2'; font-size:7.8pt; font-weight:400; font-style:normal;\">\n"
-                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-size:12pt; font-weight:600; text-decoration: underline;">Constraints :</span></p>\n'
-                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-size:14pt;">H2 &lt; H3</span></p>\n'
-                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-size:14pt;">W1 &lt; W0</span></p>\n'
-                '<p align="center" style=" margin-top:0px'
-                '; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-size:14pt;">H1 &lt; H0 </span></p></body></html>',
+                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:\'MS Shell Dlg 2\'; font-size:12pt; font-weight:600; text-decoration: underline;">Constraints :</span></p>\n'
+                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:\'MS Shell Dlg 2\'; font-size:14pt;">H2 &lt; H3</span></p>\n'
+                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:\'MS Shell Dlg 2'
+                "'; font-size:14pt;\">W1 &lt; W0</span></p>\n"
+                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:\'MS Shell Dlg 2\'; font-size:14pt;">H1 &lt; H0 </span></p></body></html>',
                 None,
             )
         )
         self.unit_W2.setText(QCoreApplication.translate("PHoleM50", u"m", None))
         self.unit_W1.setText(QCoreApplication.translate("PHoleM50", u"m", None))
         self.unit_H2.setText(QCoreApplication.translate("PHoleM50", u"m", None))
-        self.in_H4.setText(QCoreApplication.translate("PHoleM50", u"H4 :", None))
+        self.in_H4.setText(QCoreApplication.translate("PHoleM50", u"H4", None))
         self.unit_H1.setText(QCoreApplication.translate("PHoleM50", u"m", None))
-        self.in_W1.setText(QCoreApplication.translate("PHoleM50", u"W1 :", None))
+        self.in_W1.setText(QCoreApplication.translate("PHoleM50", u"W1", None))
         self.unit_H0.setText(QCoreApplication.translate("PHoleM50", u"m", None))
-        self.in_H1.setText(QCoreApplication.translate("PHoleM50", u"H1 :", None))
+        self.in_H1.setText(QCoreApplication.translate("PHoleM50", u"H1", None))
         self.unit_H4.setText(QCoreApplication.translate("PHoleM50", u"m", None))
-        self.in_H3.setText(QCoreApplication.translate("PHoleM50", u"H3 :", None))
+        self.in_H3.setText(QCoreApplication.translate("PHoleM50", u"H3", None))
         self.unit_W0.setText(QCoreApplication.translate("PHoleM50", u"m", None))
-        self.in_W2.setText(QCoreApplication.translate("PHoleM50", u"W2 :", None))
-        self.in_H0.setText(QCoreApplication.translate("PHoleM50", u"H0 :", None))
+        self.in_W2.setText(QCoreApplication.translate("PHoleM50", u"W2", None))
+        self.in_H0.setText(QCoreApplication.translate("PHoleM50", u"H0", None))
         self.unit_H3.setText(QCoreApplication.translate("PHoleM50", u"m", None))
         self.unit_W4.setText(QCoreApplication.translate("PHoleM50", u"m", None))
-        self.in_W0.setText(QCoreApplication.translate("PHoleM50", u"W0 :", None))
-        self.in_H2.setText(QCoreApplication.translate("PHoleM50", u"H2 :", None))
-        self.in_W3.setText(QCoreApplication.translate("PHoleM50", u"W3 :", None))
+        self.in_W0.setText(QCoreApplication.translate("PHoleM50", u"W0", None))
+        self.in_H2.setText(QCoreApplication.translate("PHoleM50", u"H2", None))
+        self.in_W3.setText(QCoreApplication.translate("PHoleM50", u"W3", None))
         self.lf_W4.setText("")
-        self.in_W4.setText(QCoreApplication.translate("PHoleM50", u"W4 :", None))
+        self.in_W4.setText(QCoreApplication.translate("PHoleM50", u"W4", None))
         self.unit_W3.setText(QCoreApplication.translate("PHoleM50", u"m", None))
         self.g_output.setTitle(QCoreApplication.translate("PHoleM50", u"Output", None))
         self.out_slot_surface.setText(
