@@ -8,7 +8,7 @@ from ......Classes.HoleM53 import HoleM53
 from ......GUI import gui_option
 from ......GUI.Dialog.DMachineSetup.SMHoleMag.PHoleM53.Gen_PHoleM53 import Gen_PHoleM53
 from ......GUI.Dialog.DMatLib.MatLib import MatLib
-from ......Methods.Slot.Slot.check import SlotCheckError
+from ......Methods.Slot.Slot import SlotCheckError
 
 
 class PHoleM53(Gen_PHoleM53, QWidget):
@@ -49,12 +49,17 @@ class PHoleM53(Gen_PHoleM53, QWidget):
         self.lf_H3.unit = "m"
 
         # Set default materials
-        self.w_mat_0.setText("mat_void:")
+        self.w_mat_0.setText("mat_void")
         self.w_mat_0.def_mat = "Air"
-        self.w_mat_1.setText("magnet_0:")
+        self.w_mat_0.is_hide_button = True
+
+        self.w_mat_1.setText("magnet_0")
         self.w_mat_1.def_mat = "Magnet1"
-        self.w_mat_2.setText("magnet_1:")
+        self.w_mat_1.is_hide_button = True
+
+        self.w_mat_2.setText("magnet_1")
         self.w_mat_2.def_mat = "Magnet1"
+        self.w_mat_2.is_hide_button = True
 
         # Set unit name (m ou mm)
         self.u = gui_option.unit
@@ -68,12 +73,12 @@ class PHoleM53(Gen_PHoleM53, QWidget):
             self.unit_H3,
         ]
         for wid in wid_list:
-            wid.setText(self.u.get_m_name())
+            wid.setText("[" + self.u.get_m_name() + "]")
 
         # Adapt GUI with/without magnet
         if hole.magnet_0 is None:  # SyRM
             self.img_slot.setPixmap(
-                QPixmap(":/images/images/MachineSetup/WSlot/Slot_53_no_mag.PNG")
+                QPixmap(":/images/images/MachineSetup/SMHoleMag/HoleM53_no_mag.png")
             )
             self.w_mat_0.update(self.hole, "mat_void", self.matlib)
             self.w_mat_1.hide()
