@@ -9,8 +9,8 @@ from PySide2.QtCore import *
 from PySide2.QtGui import *
 from PySide2.QtWidgets import *
 
-from pyleecan.GUI.Tools.FloatEdit import FloatEdit
-from pyleecan.GUI.Dialog.DMatLib.WMatSelect.WMatSelect import WMatSelect
+from ......GUI.Tools.FloatEdit import FloatEdit
+from ......GUI.Dialog.DMatLib.WMatSelect.WMatSelect import WMatSelect
 
 from pyleecan.GUI.Resources import pyleecan_rc
 
@@ -19,7 +19,7 @@ class Ui_PHoleM58(object):
     def setupUi(self, PHoleM58):
         if not PHoleM58.objectName():
             PHoleM58.setObjectName(u"PHoleM58")
-        PHoleM58.resize(740, 440)
+        PHoleM58.resize(963, 549)
         PHoleM58.setMinimumSize(QSize(740, 440))
         PHoleM58.setMaximumSize(QSize(16777215, 16777215))
         self.horizontalLayout = QHBoxLayout(PHoleM58)
@@ -28,15 +28,15 @@ class Ui_PHoleM58(object):
         self.verticalLayout_3.setObjectName(u"verticalLayout_3")
         self.img_slot = QLabel(PHoleM58)
         self.img_slot.setObjectName(u"img_slot")
-        sizePolicy = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
+        sizePolicy = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
         sizePolicy.setHeightForWidth(self.img_slot.sizePolicy().hasHeightForWidth())
         self.img_slot.setSizePolicy(sizePolicy)
-        self.img_slot.setMinimumSize(QSize(500, 170))
-        self.img_slot.setMaximumSize(QSize(500, 170))
+        self.img_slot.setMinimumSize(QSize(0, 0))
+        self.img_slot.setMaximumSize(QSize(16777215, 16777215))
         self.img_slot.setPixmap(
-            QPixmap(u":/images/images/MachineSetup/WSlot/Slot_58.PNG")
+            QPixmap(u":/images/images/MachineSetup/SMHoleMag/HoleM58.png")
         )
         self.img_slot.setScaledContents(True)
 
@@ -52,7 +52,7 @@ class Ui_PHoleM58(object):
         )
         self.txt_constraint.setSizePolicy(sizePolicy1)
         self.txt_constraint.setMinimumSize(QSize(200, 0))
-        self.txt_constraint.setMaximumSize(QSize(16777215, 100))
+        self.txt_constraint.setMaximumSize(QSize(16777215, 70))
         self.txt_constraint.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
         self.txt_constraint.setTextInteractionFlags(
             Qt.TextSelectableByKeyboard | Qt.TextSelectableByMouse
@@ -60,153 +60,157 @@ class Ui_PHoleM58(object):
 
         self.verticalLayout_3.addWidget(self.txt_constraint)
 
-        self.verticalSpacer_2 = QSpacerItem(
-            20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
-        )
-
-        self.verticalLayout_3.addItem(self.verticalSpacer_2)
-
         self.horizontalLayout.addLayout(self.verticalLayout_3)
 
-        self.verticalLayout_2 = QVBoxLayout()
+        self.widget = QWidget(PHoleM58)
+        self.widget.setObjectName(u"widget")
+        self.widget.setMinimumSize(QSize(250, 0))
+        self.widget.setMaximumSize(QSize(250, 16777215))
+        self.verticalLayout_2 = QVBoxLayout(self.widget)
         self.verticalLayout_2.setObjectName(u"verticalLayout_2")
         self.gridLayout = QGridLayout()
         self.gridLayout.setObjectName(u"gridLayout")
-        self.in_H0 = QLabel(PHoleM58)
+        self.in_H0 = QLabel(self.widget)
         self.in_H0.setObjectName(u"in_H0")
 
         self.gridLayout.addWidget(self.in_H0, 0, 0, 1, 1)
 
-        self.lf_H0 = FloatEdit(PHoleM58)
+        self.lf_H0 = FloatEdit(self.widget)
         self.lf_H0.setObjectName(u"lf_H0")
 
         self.gridLayout.addWidget(self.lf_H0, 0, 1, 1, 1)
 
-        self.unit_R0 = QLabel(PHoleM58)
+        self.unit_R0 = QLabel(self.widget)
         self.unit_R0.setObjectName(u"unit_R0")
 
         self.gridLayout.addWidget(self.unit_R0, 7, 2, 1, 1)
 
-        self.unit_H0 = QLabel(PHoleM58)
+        self.unit_H0 = QLabel(self.widget)
         self.unit_H0.setObjectName(u"unit_H0")
 
         self.gridLayout.addWidget(self.unit_H0, 0, 2, 1, 1)
 
-        self.unit_W2 = QLabel(PHoleM58)
+        self.unit_W2 = QLabel(self.widget)
         self.unit_W2.setObjectName(u"unit_W2")
 
         self.gridLayout.addWidget(self.unit_W2, 5, 2, 1, 1)
 
-        self.unit_W0 = QLabel(PHoleM58)
+        self.unit_W0 = QLabel(self.widget)
         self.unit_W0.setObjectName(u"unit_W0")
 
         self.gridLayout.addWidget(self.unit_W0, 3, 2, 1, 1)
 
-        self.unit_W1 = QLabel(PHoleM58)
+        self.unit_W1 = QLabel(self.widget)
         self.unit_W1.setObjectName(u"unit_W1")
 
         self.gridLayout.addWidget(self.unit_W1, 4, 2, 1, 1)
 
-        self.in_W3 = QLabel(PHoleM58)
+        self.in_W3 = QLabel(self.widget)
         self.in_W3.setObjectName(u"in_W3")
 
         self.gridLayout.addWidget(self.in_W3, 6, 0, 1, 1)
 
-        self.lf_W0 = FloatEdit(PHoleM58)
+        self.lf_W0 = FloatEdit(self.widget)
         self.lf_W0.setObjectName(u"lf_W0")
 
         self.gridLayout.addWidget(self.lf_W0, 3, 1, 1, 1)
 
-        self.in_W1 = QLabel(PHoleM58)
+        self.in_W1 = QLabel(self.widget)
         self.in_W1.setObjectName(u"in_W1")
 
         self.gridLayout.addWidget(self.in_W1, 4, 0, 1, 1)
 
-        self.in_W2 = QLabel(PHoleM58)
+        self.in_W2 = QLabel(self.widget)
         self.in_W2.setObjectName(u"in_W2")
 
         self.gridLayout.addWidget(self.in_W2, 5, 0, 1, 1)
 
-        self.in_R0 = QLabel(PHoleM58)
+        self.in_R0 = QLabel(self.widget)
         self.in_R0.setObjectName(u"in_R0")
 
         self.gridLayout.addWidget(self.in_R0, 7, 0, 1, 1)
 
-        self.lf_W1 = FloatEdit(PHoleM58)
+        self.lf_W1 = FloatEdit(self.widget)
         self.lf_W1.setObjectName(u"lf_W1")
 
         self.gridLayout.addWidget(self.lf_W1, 4, 1, 1, 1)
 
-        self.in_H1 = QLabel(PHoleM58)
+        self.in_H1 = QLabel(self.widget)
         self.in_H1.setObjectName(u"in_H1")
 
         self.gridLayout.addWidget(self.in_H1, 1, 0, 1, 1)
 
-        self.in_H2 = QLabel(PHoleM58)
+        self.in_H2 = QLabel(self.widget)
         self.in_H2.setObjectName(u"in_H2")
 
         self.gridLayout.addWidget(self.in_H2, 2, 0, 1, 1)
 
-        self.lf_W2 = FloatEdit(PHoleM58)
+        self.lf_W2 = FloatEdit(self.widget)
         self.lf_W2.setObjectName(u"lf_W2")
 
         self.gridLayout.addWidget(self.lf_W2, 5, 1, 1, 1)
 
-        self.in_W0 = QLabel(PHoleM58)
+        self.in_W0 = QLabel(self.widget)
         self.in_W0.setObjectName(u"in_W0")
 
         self.gridLayout.addWidget(self.in_W0, 3, 0, 1, 1)
 
-        self.unit_H2 = QLabel(PHoleM58)
+        self.unit_H2 = QLabel(self.widget)
         self.unit_H2.setObjectName(u"unit_H2")
 
         self.gridLayout.addWidget(self.unit_H2, 2, 2, 1, 1)
 
-        self.lf_W3 = FloatEdit(PHoleM58)
+        self.lf_W3 = FloatEdit(self.widget)
         self.lf_W3.setObjectName(u"lf_W3")
 
         self.gridLayout.addWidget(self.lf_W3, 6, 1, 1, 1)
 
-        self.lf_R0 = FloatEdit(PHoleM58)
+        self.lf_R0 = FloatEdit(self.widget)
         self.lf_R0.setObjectName(u"lf_R0")
 
         self.gridLayout.addWidget(self.lf_R0, 7, 1, 1, 1)
 
-        self.lf_H1 = FloatEdit(PHoleM58)
+        self.lf_H1 = FloatEdit(self.widget)
         self.lf_H1.setObjectName(u"lf_H1")
 
         self.gridLayout.addWidget(self.lf_H1, 1, 1, 1, 1)
 
-        self.lf_H2 = FloatEdit(PHoleM58)
+        self.lf_H2 = FloatEdit(self.widget)
         self.lf_H2.setObjectName(u"lf_H2")
 
         self.gridLayout.addWidget(self.lf_H2, 2, 1, 1, 1)
 
-        self.unit_H1 = QLabel(PHoleM58)
+        self.unit_H1 = QLabel(self.widget)
         self.unit_H1.setObjectName(u"unit_H1")
 
         self.gridLayout.addWidget(self.unit_H1, 1, 2, 1, 1)
 
-        self.unit_W3 = QLabel(PHoleM58)
+        self.unit_W3 = QLabel(self.widget)
         self.unit_W3.setObjectName(u"unit_W3")
 
         self.gridLayout.addWidget(self.unit_W3, 6, 2, 1, 1)
 
         self.verticalLayout_2.addLayout(self.gridLayout)
 
-        self.w_mat_0 = WMatSelect(PHoleM58)
+        self.w_mat_0 = WMatSelect(self.widget)
         self.w_mat_0.setObjectName(u"w_mat_0")
         self.w_mat_0.setMinimumSize(QSize(100, 0))
 
         self.verticalLayout_2.addWidget(self.w_mat_0)
 
-        self.w_mat_1 = WMatSelect(PHoleM58)
+        self.w_mat_1 = WMatSelect(self.widget)
         self.w_mat_1.setObjectName(u"w_mat_1")
         self.w_mat_1.setMinimumSize(QSize(100, 0))
 
         self.verticalLayout_2.addWidget(self.w_mat_1)
 
-        self.g_output = QGroupBox(PHoleM58)
+        self.verticalSpacer = QSpacerItem(
+            20, 176, QSizePolicy.Minimum, QSizePolicy.Expanding
+        )
+
+        self.verticalLayout_2.addItem(self.verticalSpacer)
+
+        self.g_output = QGroupBox(self.widget)
         self.g_output.setObjectName(u"g_output")
         self.g_output.setMinimumSize(QSize(200, 0))
         self.verticalLayout = QVBoxLayout(self.g_output)
@@ -221,15 +225,9 @@ class Ui_PHoleM58(object):
 
         self.verticalLayout.addWidget(self.out_magnet_surface)
 
-        self.verticalSpacer = QSpacerItem(
-            20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
-        )
-
-        self.verticalLayout.addItem(self.verticalSpacer)
-
         self.verticalLayout_2.addWidget(self.g_output)
 
-        self.horizontalLayout.addLayout(self.verticalLayout_2)
+        self.horizontalLayout.addWidget(self.widget)
 
         QWidget.setTabOrder(self.lf_H0, self.lf_H1)
         QWidget.setTabOrder(self.lf_H1, self.lf_H2)
@@ -255,29 +253,29 @@ class Ui_PHoleM58(object):
                 u'<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0//EN" "http://www.w3.org/TR/REC-html40/strict.dtd">\n'
                 '<html><head><meta name="qrichtext" content="1" /><style type="text/css">\n'
                 "p, li { white-space: pre-wrap; }\n"
-                "</style></head><body style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
-                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-size:12pt; font-weight:600; text-decoration: underline;">Constraints :</span></p>\n'
-                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-size:14pt;">W1 + W2 &lt; W0</span></p></body></html>',
+                "</style></head><body style=\" font-family:'MS Shell Dlg 2'; font-size:7.8pt; font-weight:400; font-style:normal;\">\n"
+                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:\'MS Shell Dlg 2\'; font-size:12pt; font-weight:600; text-decoration: underline;">Constraints :</span></p>\n'
+                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:\'MS Shell Dlg 2\'; font-size:14pt;">W1 + W2 &lt; W0</span></p></body></html>',
                 None,
             )
         )
-        self.in_H0.setText(QCoreApplication.translate("PHoleM58", u"H0 :", None))
+        self.in_H0.setText(QCoreApplication.translate("PHoleM58", u"H0", None))
         self.unit_R0.setText(QCoreApplication.translate("PHoleM58", u"m", None))
         self.unit_H0.setText(QCoreApplication.translate("PHoleM58", u"m", None))
         self.unit_W2.setText(QCoreApplication.translate("PHoleM58", u"m", None))
         self.unit_W0.setText(QCoreApplication.translate("PHoleM58", u"m", None))
         self.unit_W1.setText(QCoreApplication.translate("PHoleM58", u"m", None))
-        self.in_W3.setText(QCoreApplication.translate("PHoleM58", u"W3 :", None))
-        self.in_W1.setText(QCoreApplication.translate("PHoleM58", u"W1 :", None))
-        self.in_W2.setText(QCoreApplication.translate("PHoleM58", u"W2 :", None))
-        self.in_R0.setText(QCoreApplication.translate("PHoleM58", u"R0 :", None))
-        self.in_H1.setText(QCoreApplication.translate("PHoleM58", u"H1 :", None))
-        self.in_H2.setText(QCoreApplication.translate("PHoleM58", u"H2 :", None))
-        self.in_W0.setText(QCoreApplication.translate("PHoleM58", u"W0 :", None))
+        self.in_W3.setText(QCoreApplication.translate("PHoleM58", u"W3", None))
+        self.in_W1.setText(QCoreApplication.translate("PHoleM58", u"W1", None))
+        self.in_W2.setText(QCoreApplication.translate("PHoleM58", u"W2", None))
+        self.in_R0.setText(QCoreApplication.translate("PHoleM58", u"R0", None))
+        self.in_H1.setText(QCoreApplication.translate("PHoleM58", u"H1", None))
+        self.in_H2.setText(QCoreApplication.translate("PHoleM58", u"H2", None))
+        self.in_W0.setText(QCoreApplication.translate("PHoleM58", u"W0", None))
         self.unit_H2.setText(QCoreApplication.translate("PHoleM58", u"m", None))
         self.lf_R0.setText("")
         self.unit_H1.setText(QCoreApplication.translate("PHoleM58", u"m", None))
-        self.unit_W3.setText(QCoreApplication.translate("PHoleM58", u"rad", None))
+        self.unit_W3.setText(QCoreApplication.translate("PHoleM58", u"[rad]", None))
         self.g_output.setTitle(QCoreApplication.translate("PHoleM58", u"Output", None))
         self.out_slot_surface.setText(
             QCoreApplication.translate("PHoleM58", u"Hole suface : ?", None)
