@@ -8,7 +8,7 @@ from .....Classes.HoleM50 import HoleM50
 from .....Classes.Material import Material
 from .....GUI.Dialog.DMachineSetup.SMHoleMag.Ui_SMHoleMag import Ui_SMHoleMag
 from .....GUI.Dialog.DMachineSetup.SMHoleMag.WHoleMag.WHoleMag import WHoleMag
-from .....Methods.Slot.Slot.check import SlotCheckError
+from .....Methods.Slot.Slot import SlotCheckError
 
 
 class SMHoleMag(Ui_SMHoleMag, QWidget):
@@ -47,6 +47,8 @@ class SMHoleMag(Ui_SMHoleMag, QWidget):
             self.obj = machine.stator
         else:
             self.obj = machine.rotor
+        if self.obj.hole is None:
+            self.obj.hole = list()
 
         # If the hole is not set, initialize it with a HoleM50
         if len(self.obj.hole) == 0:
@@ -156,11 +158,10 @@ class SMHoleMag(Ui_SMHoleMag, QWidget):
 
         # We have to make sure the hole is right before truing to plot it
         error = self.check(self.obj)
-
         if error:  # Error => Display it
             QMessageBox().critical(self, self.tr("Error"), error)
         else:  # No error => Plot the hole (No winding for LamSquirrelCage)
-            self.machine.plot()
+            self.machine.plot(is_show_fig=True)
 
     @staticmethod
     def check(lamination):
