@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 
-from PyQt5.QtCore import pyqtSignal
-from PyQt5.QtWidgets import QMessageBox, QWidget
+from PySide2.QtCore import Signal
+from PySide2.QtWidgets import QMessageBox, QWidget
 
 from ......GUI.Dialog.DMachineSetup.SMHoleMag.PHoleM50.PHoleM50 import PHoleM50
 from ......GUI.Dialog.DMachineSetup.SMHoleMag.PHoleM51.PHoleM51 import PHoleM51
@@ -11,15 +11,15 @@ from ......GUI.Dialog.DMachineSetup.SMHoleMag.PHoleM53.PHoleM53 import PHoleM53
 from ......GUI.Dialog.DMachineSetup.SMHoleMag.PHoleM54.PHoleM54 import PHoleM54
 from ......GUI.Dialog.DMachineSetup.SMHoleMag.PHoleM57.PHoleM57 import PHoleM57
 from ......GUI.Dialog.DMachineSetup.SMHoleMag.PHoleM58.PHoleM58 import PHoleM58
+from ......GUI.Dialog.DMachineSetup.SMHoleMag.PHoleMUD.PHoleMUD import PHoleMUD
 from ......GUI.Dialog.DMachineSetup.SMHoleMag.WHoleMag.Ui_WHoleMag import Ui_WHoleMag
 
 
 class WHoleMag(Ui_WHoleMag, QWidget):
-    """Widget to Setup a single Hole in a list
-    """
+    """Widget to Setup a single Hole in a list"""
 
     # Signal to DMachineSetup to know that the save popup is needed
-    saveNeeded = pyqtSignal()
+    saveNeeded = Signal()
 
     def __init__(self, parent, is_mag, index, matlib):
         """Initialize the GUI according to lamination
@@ -28,14 +28,14 @@ class WHoleMag(Ui_WHoleMag, QWidget):
         ----------
         self : WHoleMag
             A WHoleMag object
-        parent : 
+        parent :
             A parent object containing the lamination (LamHole) to edit
         is_mag : bool
             False: no magnet in the Hole (for the SyRM)
         index : int
             Index of the hole to edit
         matlib : MatLib
-            Material Library 
+            Material Library
         """
 
         # Build the interface according to the .ui file
@@ -51,7 +51,15 @@ class WHoleMag(Ui_WHoleMag, QWidget):
 
         # Adapt the GUI to the current machine
         if is_mag:  # IPMSM
-            self.wid_list = [PHoleM50, PHoleM51, PHoleM52, PHoleM53, PHoleM57, PHoleM58]
+            self.wid_list = [
+                PHoleM50,
+                PHoleM51,
+                PHoleM52,
+                PHoleM53,
+                PHoleM57,
+                PHoleM58,
+                # PHoleMUD,
+            ]
         else:  # SyRM
             self.wid_list = [
                 PHoleM50,
@@ -61,6 +69,7 @@ class WHoleMag(Ui_WHoleMag, QWidget):
                 PHoleM54,
                 PHoleM57,
                 PHoleM58,
+                PHoleMUD,
             ]
         self.type_list = [wid.hole_type for wid in self.wid_list]
         self.name_list = [wid.hole_name for wid in self.wid_list]
@@ -91,8 +100,7 @@ class WHoleMag(Ui_WHoleMag, QWidget):
         self.c_hole_type.currentIndexChanged.connect(self.set_hole_type)
 
     def emit_save(self):
-        """Send a saveNeeded signal to the DMachineSetup
-        """
+        """Send a saveNeeded signal to the DMachineSetup"""
         self.saveNeeded.emit()
 
     def set_hole_type(self, c_index):
@@ -112,15 +120,14 @@ class WHoleMag(Ui_WHoleMag, QWidget):
 
         # Call the corresponding constructor
         Zh = hole.Zh
-        if self.is_mag:  # IPMSM machine
-            magnet = hole.magnet_0
         if self.previous_hole[self.type_list[c_index]] is None:
             # No previous hole of this type
             self.obj.hole[self.index] = self.type_list[c_index]()
             self.obj.hole[self.index]._set_None()  # No default value
             self.obj.hole[self.index].Zh = Zh
-            if self.is_mag:  # IPMSM
-                self.obj.hole[self.index].magnet_0 = magnet
+            if self.is_mag and self.obj.hole[self.index].has_magnet():  # IPMSM
+                magnet = hole.get_magnet_by_id(0)
+                self.obj.hole[self.index].set_magnet_by_id(0, magnet)
             elif self.obj.hole[self.index].has_magnet():  # SyRM
                 self.obj.hole[self.index].remove_magnet()
         else:  # Load the previous hole of this type
