@@ -39,6 +39,7 @@ class Ui_WMachineTable(object):
         self.tab_param.setMaximumSize(QSize(260, 16777215))
         self.tab_param.setHorizontalScrollBarPolicy(Qt.ScrollBarAsNeeded)
         self.tab_param.setSizeAdjustPolicy(QAbstractScrollArea.AdjustToContents)
+        self.tab_param.setEditTriggers(QAbstractItemView.NoEditTriggers)
         self.tab_param.setAlternatingRowColors(True)
         self.tab_param.setColumnCount(2)
         self.tab_param.horizontalHeader().setCascadingSectionResizes(False)
@@ -48,6 +49,11 @@ class Ui_WMachineTable(object):
 
         self.verticalLayout.addWidget(self.tab_param)
 
+        self.b_plot_machine = QPushButton(WMachineTable)
+        self.b_plot_machine.setObjectName(u"b_plot_machine")
+
+        self.verticalLayout.addWidget(self.b_plot_machine)
+
         self.b_mmf = QPushButton(WMachineTable)
         self.b_mmf.setObjectName(u"b_mmf")
 
@@ -76,6 +82,9 @@ class Ui_WMachineTable(object):
         ___qtablewidgetitem1.setText(
             QCoreApplication.translate("WMachineTable", u"Value", None)
         )
+        self.b_plot_machine.setText(
+            QCoreApplication.translate("WMachineTable", u"Plot Machine", None)
+        )
         self.b_mmf.setText(
             QCoreApplication.translate("WMachineTable", u"Plot Stator Unit MMF", None)
         )
