@@ -19,7 +19,7 @@ class Ui_PWSlot13(object):
     def setupUi(self, PWSlot13):
         if not PWSlot13.objectName():
             PWSlot13.setObjectName(u"PWSlot13")
-        PWSlot13.resize(630, 470)
+        PWSlot13.resize(797, 470)
         PWSlot13.setMinimumSize(QSize(630, 470))
         PWSlot13.setMaximumSize(QSize(16777215, 16777215))
         self.horizontalLayout = QHBoxLayout(PWSlot13)
@@ -35,7 +35,7 @@ class Ui_PWSlot13(object):
         self.img_slot.setSizePolicy(sizePolicy)
         self.img_slot.setMaximumSize(QSize(16777215, 16777215))
         self.img_slot.setPixmap(
-            QPixmap(u":/images/images/MachineSetup/WSlot/Slot 13.PNG")
+            QPixmap(u":/images/images/MachineSetup/WSlot/SlotW13.png")
         )
         self.img_slot.setScaledContents(True)
 
@@ -50,7 +50,7 @@ class Ui_PWSlot13(object):
             self.txt_constraint.sizePolicy().hasHeightForWidth()
         )
         self.txt_constraint.setSizePolicy(sizePolicy1)
-        self.txt_constraint.setMaximumSize(QSize(16777215, 70))
+        self.txt_constraint.setMaximumSize(QSize(16777215, 100))
         self.txt_constraint.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
         self.txt_constraint.setTextInteractionFlags(
             Qt.TextSelectableByKeyboard | Qt.TextSelectableByMouse
@@ -60,96 +60,100 @@ class Ui_PWSlot13(object):
 
         self.horizontalLayout.addLayout(self.verticalLayout_2)
 
-        self.verticalLayout = QVBoxLayout()
+        self.widget = QWidget(PWSlot13)
+        self.widget.setObjectName(u"widget")
+        self.widget.setMinimumSize(QSize(250, 0))
+        self.widget.setMaximumSize(QSize(250, 16777215))
+        self.verticalLayout = QVBoxLayout(self.widget)
         self.verticalLayout.setObjectName(u"verticalLayout")
         self.gridLayout = QGridLayout()
         self.gridLayout.setObjectName(u"gridLayout")
-        self.in_W0 = QLabel(PWSlot13)
+        self.in_W0 = QLabel(self.widget)
         self.in_W0.setObjectName(u"in_W0")
 
         self.gridLayout.addWidget(self.in_W0, 0, 0, 1, 1)
 
-        self.lf_W0 = FloatEdit(PWSlot13)
+        self.lf_W0 = FloatEdit(self.widget)
         self.lf_W0.setObjectName(u"lf_W0")
 
         self.gridLayout.addWidget(self.lf_W0, 0, 1, 1, 1)
 
-        self.unit_W0 = QLabel(PWSlot13)
+        self.unit_W0 = QLabel(self.widget)
         self.unit_W0.setObjectName(u"unit_W0")
 
         self.gridLayout.addWidget(self.unit_W0, 0, 2, 1, 1)
 
-        self.in_W1 = QLabel(PWSlot13)
+        self.in_W1 = QLabel(self.widget)
         self.in_W1.setObjectName(u"in_W1")
 
         self.gridLayout.addWidget(self.in_W1, 1, 0, 1, 1)
 
-        self.lf_W1 = FloatEdit(PWSlot13)
+        self.lf_W1 = FloatEdit(self.widget)
         self.lf_W1.setObjectName(u"lf_W1")
 
         self.gridLayout.addWidget(self.lf_W1, 1, 1, 1, 1)
 
-        self.unit_W1 = QLabel(PWSlot13)
+        self.unit_W1 = QLabel(self.widget)
         self.unit_W1.setObjectName(u"unit_W1")
 
         self.gridLayout.addWidget(self.unit_W1, 1, 2, 1, 1)
 
-        self.in_W2 = QLabel(PWSlot13)
+        self.in_W2 = QLabel(self.widget)
         self.in_W2.setObjectName(u"in_W2")
 
         self.gridLayout.addWidget(self.in_W2, 2, 0, 1, 1)
 
-        self.lf_W2 = FloatEdit(PWSlot13)
+        self.lf_W2 = FloatEdit(self.widget)
         self.lf_W2.setObjectName(u"lf_W2")
 
         self.gridLayout.addWidget(self.lf_W2, 2, 1, 1, 1)
 
-        self.unit_W2 = QLabel(PWSlot13)
+        self.unit_W2 = QLabel(self.widget)
         self.unit_W2.setObjectName(u"unit_W2")
 
         self.gridLayout.addWidget(self.unit_W2, 2, 2, 1, 1)
 
-        self.in_W3 = QLabel(PWSlot13)
+        self.in_W3 = QLabel(self.widget)
         self.in_W3.setObjectName(u"in_W3")
 
         self.gridLayout.addWidget(self.in_W3, 3, 0, 1, 1)
 
-        self.lf_W3 = FloatEdit(PWSlot13)
+        self.lf_W3 = FloatEdit(self.widget)
         self.lf_W3.setObjectName(u"lf_W3")
 
         self.gridLayout.addWidget(self.lf_W3, 3, 1, 1, 1)
 
-        self.unit_W3 = QLabel(PWSlot13)
+        self.unit_W3 = QLabel(self.widget)
         self.unit_W3.setObjectName(u"unit_W3")
 
         self.gridLayout.addWidget(self.unit_W3, 3, 2, 1, 1)
 
-        self.in_H0 = QLabel(PWSlot13)
+        self.in_H0 = QLabel(self.widget)
         self.in_H0.setObjectName(u"in_H0")
 
         self.gridLayout.addWidget(self.in_H0, 4, 0, 1, 1)
 
-        self.lf_H0 = FloatEdit(PWSlot13)
+        self.lf_H0 = FloatEdit(self.widget)
         self.lf_H0.setObjectName(u"lf_H0")
 
         self.gridLayout.addWidget(self.lf_H0, 4, 1, 1, 1)
 
-        self.unit_H0 = QLabel(PWSlot13)
+        self.unit_H0 = QLabel(self.widget)
         self.unit_H0.setObjectName(u"unit_H0")
 
         self.gridLayout.addWidget(self.unit_H0, 4, 2, 1, 1)
 
-        self.in_H1 = QLabel(PWSlot13)
+        self.in_H1 = QLabel(self.widget)
         self.in_H1.setObjectName(u"in_H1")
 
         self.gridLayout.addWidget(self.in_H1, 5, 0, 1, 1)
 
-        self.lf_H1 = FloatEdit(PWSlot13)
+        self.lf_H1 = FloatEdit(self.widget)
         self.lf_H1.setObjectName(u"lf_H1")
 
         self.gridLayout.addWidget(self.lf_H1, 5, 1, 1, 1)
 
-        self.c_H1_unit = QComboBox(PWSlot13)
+        self.c_H1_unit = QComboBox(self.widget)
         self.c_H1_unit.addItem("")
         self.c_H1_unit.addItem("")
         self.c_H1_unit.addItem("")
@@ -157,29 +161,35 @@ class Ui_PWSlot13(object):
 
         self.gridLayout.addWidget(self.c_H1_unit, 5, 2, 1, 1)
 
-        self.in_H2 = QLabel(PWSlot13)
+        self.in_H2 = QLabel(self.widget)
         self.in_H2.setObjectName(u"in_H2")
 
         self.gridLayout.addWidget(self.in_H2, 6, 0, 1, 1)
 
-        self.lf_H2 = FloatEdit(PWSlot13)
+        self.lf_H2 = FloatEdit(self.widget)
         self.lf_H2.setObjectName(u"lf_H2")
 
         self.gridLayout.addWidget(self.lf_H2, 6, 1, 1, 1)
 
-        self.unit_H2 = QLabel(PWSlot13)
+        self.unit_H2 = QLabel(self.widget)
         self.unit_H2.setObjectName(u"unit_H2")
 
         self.gridLayout.addWidget(self.unit_H2, 6, 2, 1, 1)
 
         self.verticalLayout.addLayout(self.gridLayout)
 
-        self.w_out = WWSlotOut(PWSlot13)
+        self.verticalSpacer = QSpacerItem(
+            20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
+        )
+
+        self.verticalLayout.addItem(self.verticalSpacer)
+
+        self.w_out = WWSlotOut(self.widget)
         self.w_out.setObjectName(u"w_out")
 
         self.verticalLayout.addWidget(self.w_out)
 
-        self.horizontalLayout.addLayout(self.verticalLayout)
+        self.horizontalLayout.addWidget(self.widget)
 
         QWidget.setTabOrder(self.lf_W0, self.lf_W1)
         QWidget.setTabOrder(self.lf_W1, self.lf_W2)
@@ -212,28 +222,28 @@ class Ui_PWSlot13(object):
                 None,
             )
         )
-        self.in_W0.setText(QCoreApplication.translate("PWSlot13", u"W0 :", None))
+        self.in_W0.setText(QCoreApplication.translate("PWSlot13", u"W0", None))
         self.unit_W0.setText(QCoreApplication.translate("PWSlot13", u"m", None))
-        self.in_W1.setText(QCoreApplication.translate("PWSlot13", u"W1 :", None))
+        self.in_W1.setText(QCoreApplication.translate("PWSlot13", u"W1", None))
         self.unit_W1.setText(QCoreApplication.translate("PWSlot13", u"m", None))
-        self.in_W2.setText(QCoreApplication.translate("PWSlot13", u"W2 :", None))
+        self.in_W2.setText(QCoreApplication.translate("PWSlot13", u"W2", None))
         self.unit_W2.setText(QCoreApplication.translate("PWSlot13", u"m", None))
-        self.in_W3.setText(QCoreApplication.translate("PWSlot13", u"W3 :", None))
+        self.in_W3.setText(QCoreApplication.translate("PWSlot13", u"W3", None))
         self.unit_W3.setText(QCoreApplication.translate("PWSlot13", u"m", None))
-        self.in_H0.setText(QCoreApplication.translate("PWSlot13", u"H0 :", None))
+        self.in_H0.setText(QCoreApplication.translate("PWSlot13", u"H0", None))
         self.unit_H0.setText(QCoreApplication.translate("PWSlot13", u"m", None))
-        self.in_H1.setText(QCoreApplication.translate("PWSlot13", u"H1 :", None))
+        self.in_H1.setText(QCoreApplication.translate("PWSlot13", u"H1", None))
         self.c_H1_unit.setItemText(
-            0, QCoreApplication.translate("PWSlot13", u"m", None)
+            0, QCoreApplication.translate("PWSlot13", u"[m]", None)
         )
         self.c_H1_unit.setItemText(
-            1, QCoreApplication.translate("PWSlot13", u"rad", None)
+            1, QCoreApplication.translate("PWSlot13", u"[rad]", None)
         )
         self.c_H1_unit.setItemText(
-            2, QCoreApplication.translate("PWSlot13", u"deg", None)
+            2, QCoreApplication.translate("PWSlot13", u"[deg]", None)
         )
 
-        self.in_H2.setText(QCoreApplication.translate("PWSlot13", u"H2 :", None))
+        self.in_H2.setText(QCoreApplication.translate("PWSlot13", u"H2", None))
         self.unit_H2.setText(QCoreApplication.translate("PWSlot13", u"m", None))
 
     # retranslateUi
