@@ -35,7 +35,7 @@ class Ui_PWSlot24(object):
         self.img_slot.setSizePolicy(sizePolicy)
         self.img_slot.setMaximumSize(QSize(16777215, 16777215))
         self.img_slot.setPixmap(
-            QPixmap(u":/images/images/MachineSetup/WSlot/Slot 24.PNG")
+            QPixmap(u":/images/images/MachineSetup/WSlot/SlotW24.png")
         )
         self.img_slot.setScaledContents(True)
 
@@ -48,54 +48,64 @@ class Ui_PWSlot24(object):
         sizePolicy1.setVerticalStretch(0)
         sizePolicy1.setHeightForWidth(self.textEdit.sizePolicy().hasHeightForWidth())
         self.textEdit.setSizePolicy(sizePolicy1)
-        self.textEdit.setMaximumSize(QSize(16777215, 60))
+        self.textEdit.setMaximumSize(QSize(16777215, 80))
 
         self.verticalLayout_2.addWidget(self.textEdit)
 
         self.horizontalLayout.addLayout(self.verticalLayout_2)
 
-        self.verticalLayout = QVBoxLayout()
+        self.widget = QWidget(PWSlot24)
+        self.widget.setObjectName(u"widget")
+        self.widget.setMinimumSize(QSize(250, 0))
+        self.widget.setMaximumSize(QSize(250, 16777215))
+        self.verticalLayout = QVBoxLayout(self.widget)
         self.verticalLayout.setObjectName(u"verticalLayout")
         self.gridLayout = QGridLayout()
         self.gridLayout.setObjectName(u"gridLayout")
-        self.in_W3 = QLabel(PWSlot24)
+        self.in_W3 = QLabel(self.widget)
         self.in_W3.setObjectName(u"in_W3")
 
         self.gridLayout.addWidget(self.in_W3, 0, 0, 1, 1)
 
-        self.lf_W3 = FloatEdit(PWSlot24)
+        self.lf_W3 = FloatEdit(self.widget)
         self.lf_W3.setObjectName(u"lf_W3")
 
         self.gridLayout.addWidget(self.lf_W3, 0, 1, 1, 1)
 
-        self.unit_W3 = QLabel(PWSlot24)
+        self.unit_W3 = QLabel(self.widget)
         self.unit_W3.setObjectName(u"unit_W3")
 
         self.gridLayout.addWidget(self.unit_W3, 0, 2, 1, 1)
 
-        self.in_H2 = QLabel(PWSlot24)
+        self.in_H2 = QLabel(self.widget)
         self.in_H2.setObjectName(u"in_H2")
 
         self.gridLayout.addWidget(self.in_H2, 1, 0, 1, 1)
 
-        self.lf_H2 = FloatEdit(PWSlot24)
+        self.lf_H2 = FloatEdit(self.widget)
         self.lf_H2.setObjectName(u"lf_H2")
 
         self.gridLayout.addWidget(self.lf_H2, 1, 1, 1, 1)
 
-        self.unit_H2 = QLabel(PWSlot24)
+        self.unit_H2 = QLabel(self.widget)
         self.unit_H2.setObjectName(u"unit_H2")
 
         self.gridLayout.addWidget(self.unit_H2, 1, 2, 1, 1)
 
         self.verticalLayout.addLayout(self.gridLayout)
 
-        self.w_out = WWSlotOut(PWSlot24)
+        self.verticalSpacer = QSpacerItem(
+            20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
+        )
+
+        self.verticalLayout.addItem(self.verticalSpacer)
+
+        self.w_out = WWSlotOut(self.widget)
         self.w_out.setObjectName(u"w_out")
 
         self.verticalLayout.addWidget(self.w_out)
 
-        self.horizontalLayout.addLayout(self.verticalLayout)
+        self.horizontalLayout.addWidget(self.widget)
 
         self.retranslateUi(PWSlot24)
 
@@ -118,9 +128,9 @@ class Ui_PWSlot24(object):
                 None,
             )
         )
-        self.in_W3.setText(QCoreApplication.translate("PWSlot24", u"W3 :", None))
+        self.in_W3.setText(QCoreApplication.translate("PWSlot24", u"W3", None))
         self.unit_W3.setText(QCoreApplication.translate("PWSlot24", u"m", None))
-        self.in_H2.setText(QCoreApplication.translate("PWSlot24", u"H2 :", None))
+        self.in_H2.setText(QCoreApplication.translate("PWSlot24", u"H2", None))
         self.unit_H2.setText(QCoreApplication.translate("PWSlot24", u"m", None))
 
     # retranslateUi
