@@ -7,7 +7,7 @@ from PySide2.QtWidgets import QWidget
 from ......Classes.SlotW27 import SlotW27
 from ......GUI import gui_option
 from ......GUI.Dialog.DMachineSetup.SWSlot.PWSlot27.Gen_PWSlot27 import Gen_PWSlot27
-from ......Methods.Slot.Slot.check import SlotCheckError
+from ......Methods.Slot.Slot import SlotCheckError
 
 translate = PySide2.QtCore.QCoreApplication.translate
 
@@ -57,7 +57,7 @@ class PWSlot27(Gen_PWSlot27, QWidget):
             self.unit_H2,
         ]
         for wid in wid_list:
-            wid.setText(gui_option.unit.get_m_name())
+            wid.setText("[" + gui_option.unit.get_m_name() + "]")
         # Fill the fields with the machine values (if they're filled)
         self.lf_W0.setValue(self.slot.W0)
         self.lf_W1.setValue(self.slot.W1)
@@ -187,19 +187,19 @@ class PWSlot27(Gen_PWSlot27, QWidget):
 
         # Check that everything is set
         if lam.slot.W0 is None:
-            return translate("You must set W0 !", "PWSlot27 check")
+            return "You must set W0 !"
         elif lam.slot.W1 is None:
-            return translate("You must set W1 !", "PWSlot27 check")
+            return "You must set W1 !"
         elif lam.slot.W2 is None:
-            return translate("You must set W2 !", "PWSlot27 check")
+            return "You must set W2 !"
         elif lam.slot.W3 is None:
-            return translate("You must set W3 !", "PWSlot27 check")
+            return "You must set W3 !"
         elif lam.slot.H0 is None:
-            return translate("You must set H0 !", "PWSlot27 check")
+            return "You must set H0 !"
         elif lam.slot.H1 is None:
-            return translate("You must set H1 !", "PWSlot27 check")
+            return "You must set H1 !"
         elif lam.slot.H2 is None:
-            return translate("You must set H2 !", "PWSlot27 check")
+            return "You must set H2 !"
 
         # Check that everything is set right
         # Constraints
@@ -212,11 +212,7 @@ class PWSlot27(Gen_PWSlot27, QWidget):
         try:
             yoke_height = lam.comp_height_yoke()
         except Exception as error:
-            return translate("Unable to compute yoke height:", "PWSlot27 check") + str(
-                error
-            )
+            return "Unable to compute yoke height:" + str(error)
 
         if yoke_height <= 0:
-            return translate(
-                "The slot height is greater than the lamination !", "PWSlot27 check"
-            )
+            return "The slot height is greater than the lamination !"
