@@ -22,7 +22,7 @@ class SWindCond(Ui_SWindCond, QWidget):
     # Signal to DMachineSetup to know that the save popup is needed
     saveNeeded = Signal()
     # Information for DMachineSetup nav
-    step_name = "Winding Conductor"
+    step_name = "Conductor"
 
     def __init__(self, machine, matlib, is_stator=False):
         """Initialize the GUI according to machine
