@@ -341,7 +341,7 @@ class DXF_Slot(Ui_DXF_Slot, QDialog):
             slot.plot()
             # Add the winding if defined
             if slot.wind_begin_index is not None:
-                surf_wind = slot.get_surface_wind()
+                surf_wind = slot.get_surface_active()
                 surf_wind.plot(fig=plt.gcf(), color=WIND_COLOR, is_show_fig=False)
 
     def save(self):
