@@ -25,7 +25,7 @@ def comp_output_geo(self):
         output.S_slot_wind = 0
     else:
         output.S_slot = self.slot.comp_surface()
-        output.S_slot_wind = self.slot.comp_surface_wind()
+        output.S_slot_wind = self.slot.comp_surface_active()
     # output.S_wind_act = self.winding.conductor.comp_surface_active()
 
     return output
