@@ -22,7 +22,7 @@ def comp_surfaces(self):
     S_dict = LamSlot.comp_surfaces(self)
 
     if self.slot is not None:
-        S_dict["Swind"] = self.get_Zs() * self.slot.comp_surface_wind()
+        S_dict["Swind"] = self.get_Zs() * self.slot.comp_surface_active()
     else:
         S_dict["Swind"] = 0
 
