@@ -2,10 +2,12 @@
 
 import pyvista as pv
 import meshio
-import os
+from os import makedirs, remove
+from os.path import isdir, split
+from pyleecan.definitions import RESULT_DIR
 
 
-def get_mesh_pv(self, path="temp.vtk", indices=None):
+def get_mesh_pv(self, path=RESULT_DIR + "/temp.vtk", indices=None):
     """Return the pyvista mesh object (or submesh).
 
     Parameters
@@ -22,14 +24,18 @@ def get_mesh_pv(self, path="temp.vtk", indices=None):
     """
 
     points = self.get_point()
-    cells, nb_cell, indice_dict = self.get_cell()
+    cells, _, _ = self.get_cell()
 
-    # for key in cells:
+    cells_meshio = list()
     for key in cells:
-        cells_meshio = [(key, cells[key])]  # TODO : Generalize to any cell type
-
+        cells_meshio.append((key, cells[key]))
         # Write .vtk file using meshio
-        meshio.write_points_cells(filename=path, points=points, cells=cells_meshio)
+
+    # Make sure that the file exists
+    if not isdir(split(path)[0]):
+        makedirs(split(path)[0])
+
+    meshio.write_points_cells(filename=path, points=points, cells=cells_meshio)
 
     # Read .vtk file with pyvista
     mesh = pv.read(path)
@@ -38,6 +44,6 @@ def get_mesh_pv(self, path="temp.vtk", indices=None):
     if indices is not None:
         mesh = mesh.extract_points(indices)
 
-    os.remove(path)
+    remove(path)
 
     return mesh
