@@ -11,8 +11,8 @@ from pyleecan.definitions import PACKAGE_NAME
 
 
 def get_group(self, group_names):
-    """Return all attributes of a MeshSolution object with only the cells, points and corresponding solutions of
-    the group. Solutions are converted as SolutionMat.
+    """Return all attributes of a MeshSolution object with only the cells, points
+    and corresponding solutions of the group. Solutions are converted as SolutionMat.
 
      Parameters
      ----------
@@ -39,9 +39,9 @@ def get_group(self, group_names):
     sep_list = list()
     if isinstance(group_names, list):
         for grp in group_names:
-            if (
-                grp == "/"
-            ):  # The groups before and after "/" are stored in different lists to perform the interface.
+            if grp == "/":
+                # The groups before and after "/" are stored in different lists
+                # to perform the interface.
                 is_interface = True
                 group_indices_init = group_indices.copy()
                 group_indices = list()
@@ -50,6 +50,13 @@ def get_group(self, group_names):
                 group_indices.extend(self.group[grp])
                 label = label + grp + "_"
     elif isinstance(group_names, str):
+        if group_names not in self.group:
+            raise KeyError(
+                group_names
+                + " group doesn't exist (available groups: "
+                + str(list(self.group.keys()))
+                + ")"
+            )
         group_indices.extend(self.group[group_names])
         label = label + group_names
 
@@ -80,7 +87,8 @@ def get_group(self, group_names):
 
         mesh_list.append(mesh_new)
 
-    # 3) if interface, create the corresponding new mesh (e.g. with triangle mesh, it creates only segment cells)
+    # 3) if interface, create the corresponding new mesh (e.g. with triangle mesh,
+    #    it creates only segment cells)
     if is_interface:
         mesh_interface = mesh_list[0].interface(mesh_list[1])
         connect_interface, nb_cell_interf, indices_interf = mesh_interface.get_cell()
@@ -93,37 +101,15 @@ def get_group(self, group_names):
     # 4) select the corresponding solutions
     sol_list = list()
     for sol in self.solution:
-        label_sol = sol.label
         type_cell_sol = sol.type_cell
-        field_sol = sol.get_field()
-        axis_dct = sol.get_axis()
 
+        new_sol = None
         if type_cell_sol == "point":
-            axis_dct["indice"] = len(node_indice)
-            new_field_sol = field_sol[:, node_indice, :]
-            new_sol = SolutionMat(
-                label=label_sol,
-                type_cell=type_cell_sol,
-                field=new_field_sol,
-                indice=node_indice,
-                axis=axis_dct,
-            )
-            sol_list.append(new_sol)
-
+            new_sol = sol.get_solution(indice=node_indice)
         elif not is_interface:  # Interface is only available for point solution.
-            if "component" in axis_dct:
-                new_field_sol = field_sol[:, indice_dict[type_cell_sol], :]
-            else:
-                new_field_sol = field_sol[:, indice_dict[type_cell_sol]]
-            axis_dct["indice"] = len(indice_dict[type_cell_sol])
-            new_sol = SolutionMat(
-                label=label_sol,
-                type_cell=type_cell_sol,
-                field=new_field_sol,
-                indice=indice_dict[type_cell_sol],
-                axis=axis_dct,
-            )
+            new_sol = sol.get_solution(indice=indice_dict[type_cell_sol])
 
+        if new_sol is not None:
             sol_list.append(new_sol)
 
     # 5) Create the corresponding MeshSolution object
