@@ -22,6 +22,7 @@ def plot_contour(
     group_names=None,
     save_path=None,
     itime=0,
+    is_show_fig=True,
 ):
     """Plot the contour of a field on a mesh using pyvista plotter.
 
@@ -51,7 +52,8 @@ def plot_contour(
         path to save the figure
     itime : int
         index of the time step to be plotted
-
+    is_show_fig : bool
+        To call show at the end of the method
     Returns
     -------
     """
@@ -100,7 +102,7 @@ def plot_contour(
         )
 
         # Extract time index
-        if len(field.shape) > 1:
+        if len(field.shape) > 2:
             # Extract time index
             if field.shape[1] > 3:
                 field = field[itime, ...]
@@ -108,6 +110,11 @@ def plot_contour(
             if field.shape[-1] == 2 or field.shape[-1] == 3:
                 field = norm(field, axis=-1)
 
+        elif len(field.shape) > 1:
+            # Extract time index
+            if field.shape[1] > 3:
+                field = field[itime, :]
+
         if field_name is None:
             if label is not None:
                 field_name = label
@@ -149,7 +156,7 @@ def plot_contour(
         )
         if self.dimension == 2:
             p.view_xy()
-        if save_path is None:
+        if save_path is None and is_show_fig:
             p.show()
-        else:
+        elif save_path is not None and is_show_fig:
             p.show(interactive=False, screenshot=save_path)
