@@ -3,7 +3,7 @@
 from meshio import read
 from os import remove
 
-
+# TODO investigate on indices, also compare with MeshMat get_cell
 def get_cell(self, indices=None):
     """Return the cells (connectivities).
 
@@ -22,19 +22,23 @@ def get_cell(self, indices=None):
 
     if indices is not None:
         # Extract submesh
-        mesh = self.get_mesh(indices=indices)
+        mesh = self.get_mesh_pv(indices=indices)
         # Write submesh in .vtk file
         mesh.save(self.path + "/temp.vtk")
         # Read mesh file with meshio (pyvista does not provide the correct cell format)
         mesh = read(self.path + "/temp.vtk")
+        # Remove the temporary .vtk file
+        remove(self.path + "/temp.vtk")
 
     else:
         # Read mesh file with meshio (pyvista does not provide the correct cell format)
         mesh = read(self.path + "/" + self.name + "." + self.format)
 
-    cells = mesh.cells
+    cells = {}
+    nb_cell = 0
+    indice_dict = {}
+    for cell in mesh.cells:
+        cells[cell.type] = cell.data
+        nb_cell += cell.data.shape[0]
 
-    if indices is not None:
-        remove(self.path + "/temp.vtk")
-
-    return cells
+    return cells, nb_cell, indice_dict
