@@ -28,7 +28,7 @@ def get_surf(self, indices=None):
 
     # Extract the outer surface of the mesh
     else:
-        mesh = self.get_mesh(indices=indices)
+        mesh = self.get_mesh_pv(indices=indices)
         surf = mesh.extract_geometry()
 
         if self.is_vtk_surf:
