@@ -3,7 +3,7 @@
 import numpy as np
 
 
-def is_exist(self, new_coord):
+def is_exist(self, new_coord, dim=2):
     """Check the existence of a node defined by its coordinates
 
     Parameters
@@ -33,13 +33,23 @@ def is_exist(self, new_coord):
             return True
     else:
         point = np.tile(new_coord, (nb_node, 1))
-        dist_node = np.reshape(
-            np.sqrt(
-                np.square(coords[:, 0] - point[:, 0])
-                + np.square(coords[:, 1] - point[:, 1])
-            ),
-            (nb_node, 1),
-        )
+        if len(new_coord) == 3:
+            dist_node = np.reshape(
+                np.sqrt(
+                    np.square(coords[:, 0] - point[:, 0])
+                    + np.square(coords[:, 1] - point[:, 1])
+                    + np.square(coords[:, 2] - point[:, 2])
+                ),
+                (nb_node, 1),
+            )
+        if len(new_coord) == 2:
+            dist_node = np.reshape(
+                np.sqrt(
+                    np.square(coords[:, 0] - point[:, 0])
+                    + np.square(coords[:, 1] - point[:, 1])
+                ),
+                (nb_node, 1),
+            )
 
         min_node_list = np.argsort(dist_node, axis=0)
 
