@@ -1,5 +1,4 @@
 from numpy import ones
-from ....Classes.ImportMatrixVal import ImportMatrixVal
 
 
 class OutElecError(Exception):
@@ -19,11 +18,11 @@ def get_Nr(self):
     Nr: ndarray
         speed in function of time
     """
-    if self.time is None:
+    if self.Time is None:
         raise OutElecError('You must define "time" property before calling get_Nr')
     if self.N0 is None:
         raise OutElecError('You must define "N0" before calling get_Nr.')
 
     # Same speed for every timestep
-    Nr = self.N0 * ones(self.time.shape[0])
+    Nr = self.N0 * ones(self.Time.get_length(is_oneperiod=False))
     return Nr
