@@ -89,8 +89,7 @@ def plot_2D_Data(
     """
 
     # Get Data object names
-    phys = getattr(self, Data_str.split(".")[0])
-    data = getattr(phys, Data_str.split(".")[1])
+    data = self.get_data_from_str(data_str=Data_str)
 
     # Get fundamental harmonic properties from Output
     if fund_harm_dict is None:
