@@ -20,6 +20,7 @@ def plot_A_time_space(
     save_path=None,
     is_auto_ticks=True,
     component_list=None,
+    is_show_fig=None,
 ):
     """Plots a field as a function of time and space (angle)
 
@@ -48,11 +49,13 @@ def plot_A_time_space(
     colormap : colormap object
         colormap prescribed by user
     save_path : str
-        path and name of the png file to save
+        full path including folder, name and extension of the file to save if save_path is not None
     is_auto_ticks : bool
         in fft, adjust ticks to freqs and wavenumbers (deactivate if too close)
     component_list : list
         list of component names to plot in separate figures
+    is_show_fig : bool
+        True to show figure after plot
     """
 
     # Get Data object names
@@ -76,6 +79,7 @@ def plot_A_time_space(
                 unit=unit,
                 save_path=save_path,
                 is_auto_ticks=is_auto_ticks,
+                is_show_fig=is_show_fig,
             )
 
     else:
@@ -91,4 +95,5 @@ def plot_A_time_space(
             unit=unit,
             save_path=save_path,
             is_auto_ticks=is_auto_ticks,
+            is_show_fig=is_show_fig,
         )
