@@ -10,8 +10,9 @@ def comp_felec(self):
     felec : float
         Electrical frequency [Hz]
     """
-
-    if self.N0 is not None:
+    if self.felec is not None:
+        return self.felec
+    elif self.N0 is not None:
         # Get the phase number for verifications
         if self.parent is None:
             raise InputError(
@@ -31,4 +32,4 @@ def comp_felec(self):
         else:
             return zp * self.N0 / 60
     else:
-        return 1
+        return 50
