@@ -5,7 +5,7 @@ from SciDataTool import DataTime, Data1D, VectorField
 import numpy as np
 
 
-def build_meshsolution(self, Nt_tot, meshFEMM, Time, B, H, mu, groups):
+def build_meshsolution(self, Nt, meshFEMM, Time, B, H, mu, groups):
     """Build the MeshSolution objets from FEMM outputs.
 
     Parameters
@@ -26,12 +26,12 @@ def build_meshsolution(self, Nt_tot, meshFEMM, Time, B, H, mu, groups):
     """
 
     sollist = list()
-    cond = self.is_sliding_band or Nt_tot == 1
+    cond = self.is_sliding_band or Nt == 1
     if cond:
         indices_cell = meshFEMM[0].cell["triangle"].indice
-        Direction = Data1D(name="direction", values=["x", "y", "z"], is_components=True)
+        # Direction = Data1D(name="direction", values=["x", "y", "z"], is_components=True)
         Indices_Cell = Data1D(name="indice", values=indices_cell, is_components=True)
-        Nodirection = Data1D(name="direction", values=["scalar"], is_components=False)
+        # Nodirection = Data1D(name="direction", values=["scalar"], is_components=False)
 
         # Store the results for B
         components = {}
@@ -42,8 +42,9 @@ def build_meshsolution(self, Nt_tot, meshFEMM, Time, B, H, mu, groups):
             symbol="Bx",
             axes=[Time, Indices_Cell],
             values=B[:, :, 0],
+            is_real=True,
         )
-        components["x"] = Bx_data
+        components["comp_x"] = Bx_data
 
         By_data = DataTime(
             name="Magnetic Flux Density By",
@@ -51,8 +52,9 @@ def build_meshsolution(self, Nt_tot, meshFEMM, Time, B, H, mu, groups):
             symbol="By",
             axes=[Time, Indices_Cell],
             values=B[:, :, 1],
+            is_real=True,
         )
-        components["y"] = By_data
+        components["comp_y"] = By_data
 
         if not np.all((B[:, :, 2] == 0)):
             Bz_data = DataTime(
@@ -61,8 +63,9 @@ def build_meshsolution(self, Nt_tot, meshFEMM, Time, B, H, mu, groups):
                 symbol="Bz",
                 axes=[Time, Indices_Cell],
                 values=B[:, :, 2],
+                is_real=True,
             )
-            components["z"] = Bz_data
+            components["comp_z"] = Bz_data
 
         solB = VectorField(
             name="Magnetic Flux Density", symbol="B", components=components
@@ -77,8 +80,9 @@ def build_meshsolution(self, Nt_tot, meshFEMM, Time, B, H, mu, groups):
             symbol="Hx",
             axes=[Time, Indices_Cell],
             values=H[:, :, 0],
+            is_real=True,
         )
-        componentsH["x"] = Hx_data
+        componentsH["comp_x"] = Hx_data
 
         Hy_data = DataTime(
             name="Magnetic Field Hy",
@@ -86,8 +90,9 @@ def build_meshsolution(self, Nt_tot, meshFEMM, Time, B, H, mu, groups):
             symbol="Hy",
             axes=[Time, Indices_Cell],
             values=H[:, :, 1],
+            is_real=True,
         )
-        componentsH["y"] = Hy_data
+        componentsH["comp_y"] = Hy_data
 
         if not np.all((H[:, :, 2] == 0)):
             Hz_data = DataTime(
@@ -96,8 +101,9 @@ def build_meshsolution(self, Nt_tot, meshFEMM, Time, B, H, mu, groups):
                 symbol="Hz",
                 axes=[Time, Indices_Cell],
                 values=H[:, :, 2],
+                is_real=True,
             )
-            componentsH["z"] = Hz_data
+            componentsH["comp_z"] = Hz_data
 
         solH = VectorField(name="Magnetic Field", symbol="H", components=componentsH)
 
@@ -107,6 +113,7 @@ def build_meshsolution(self, Nt_tot, meshFEMM, Time, B, H, mu, groups):
             symbol="\mu",
             axes=[Time, Indices_Cell],
             values=mu,
+            is_real=True,
         )
 
         sollist.append(
