@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 from ....Methods.Simulation.Input import InputError
 
 
@@ -17,9 +16,12 @@ def run(self):
     self.get_logger().info("Starting Magnetic module")
     output = self.parent.parent
 
-    # Compute and store time and angle axes from previous output
+    # Compute and store time and angle axes from elec output
     # and returns additional axes in axes_dict
-    axes_dict = self.comp_time_angle(output)
+    axes_dict = self.comp_axes(output)
 
     # Calculate airgap flux
-    self.comp_flux_airgap(output, axes_dict)
+    out_dict = self.comp_flux_airgap(output, axes_dict)
+
+    # Store magnetic quantities contained in out_dict in OutMag, as Data object if necessary
+    output.mag.store(out_dict, axes_dict)
