@@ -25,6 +25,9 @@ def run(self):
             else:
                 results = self.parent
 
+        # Logger setup
+        self.init_logger(results)
+
         # Compute the reference simulation
         if self.var_simu.ref_simu_index is None:
             self.run_single()
@@ -39,7 +42,18 @@ def run(self):
         else:
             results = self.parent
 
+        # Logger setup
+        if self.index is None:
+            self.init_logger(results)
+        else:
+            self.init_logger(results, is_create=False, is_log_start=False)
+
         # Compute the simulation
         self.run_single()
 
+    if self.index is None:
+        msg = "End of simulation"
+        if self.name not in ["", None]:
+            msg += " " + self.name
+        self.get_logger().info(msg)
     return results
