@@ -17,12 +17,12 @@ def comp_alpha(self):
         Angle of the Hole (cf schematics) [rad]
 
     """
-    Rbo = self.get_Rbo()
+    Rext = self.get_Rext()
 
     alpha = -arctan(
         2
-        * (self.H0 - self.H1 * cos(0.5 * self.W1) + Rbo * cos(0.5 * self.W1) - Rbo)
-        / (2.0 * self.H1 * sin(0.5 * self.W1) - 2 * Rbo * sin(0.5 * self.W1) + self.W0)
+        * (self.H0 - self.H1 * cos(0.5 * self.W1) + Rext * cos(0.5 * self.W1) - Rext)
+        / (2.0 * self.H1 * sin(0.5 * self.W1) - 2 * Rext * sin(0.5 * self.W1) + self.W0)
     )
 
     return alpha
