@@ -32,27 +32,18 @@ def build_geometry(self, alpha=0, delta=0, is_simplified=False):
         st = "_Stator"
     else:
         st = "_Rotor"
-    Rbo = self.get_Rbo()
 
-    alpha1 = self.comp_alpha()
-    Z1 = (Rbo - self.H0) * exp(1j * alpha1 / 2)
-    Z9 = (Rbo - self.H0) * exp(-1j * alpha1 / 2)
-
-    Z0 = (Z1 + Z9) / 2
-    Z5 = Z0 - self.H1
-
-    Z4 = Z5 + 1j * self.W0 / 2
-    Z6 = Z4.conjugate()
-
-    Z3 = Z4 + self.H2
-    Z7 = Z3.conjugate()
-
-    W1 = self.comp_W1()
-    Z2 = Z3 + 1j * W1
-    Z8 = Z2.conjugate()
-
-    Z11 = Z3 + (self.H1 - self.H2)
-    Z10 = Z7 + (self.H1 - self.H2)
+    point_dict = self._comp_point_coordinate()
+    Z1 = point_dict["Z1"]
+    Z2 = point_dict["Z2"]
+    Z3 = point_dict["Z3"]
+    Z4 = point_dict["Z4"]
+    Z6 = point_dict["Z6"]
+    Z7 = point_dict["Z7"]
+    Z8 = point_dict["Z8"]
+    Z9 = point_dict["Z9"]
+    Z10 = point_dict["Z10"]
+    Z11 = point_dict["Z11"]
 
     # Creation of the air curve
     curve_list = list()
