@@ -13,6 +13,9 @@ def has_magnet(self):
     """
 
     has_mag = False
+    if self.magnet_dict is None:
+        self.magnet_dict = dict()
+        return False
     for value in self.magnet_dict.values():
         if value is not None:
             has_mag = True
